@@ -15,7 +15,11 @@ require_once __DIR__ . "/Files/Core/Util/class.pathutil.php";
 
 require_once __DIR__ . "/vendor/autoload.php";
 
+use Files\Backend\AbstractBackend;
+use Files\Backend\BackendStore;
 use Files\Backend\Exception as BackendException;
+use Files\Backend\iFeatureSharing;
+use Files\Core\Account;
 use Files\Core\Exception as AccountException;
 use Files\Core\Util\ArrayUtil;
 use Files\Core\Util\Logger;
@@ -26,6 +30,7 @@ use Files\Core\Util\StringUtil;
  * This module handles all list and change requests for the files browser.
  *
  * @class FilesBrowserModule
+ *
  * @extends ListModule
  */
 class FilesBrowserModule extends FilesListModule {
@@ -45,6 +50,7 @@ class FilesBrowserModule extends FilesListModule {
 	 *
 	 * @return bool true on success or false on failure
 	 */
+	#[Override]
 	public function execute() {
 		$result = false;
 
@@ -54,7 +60,7 @@ class FilesBrowserModule extends FilesListModule {
 					switch ($actionType) {
 						case "checkifexists":
 							$records = $actionData["records"];
-							$destination = isset($actionData["destination"]) ? $actionData["destination"] : false;
+							$destination = $actionData["destination"] ?? false;
 							$result = $this->checkIfExists($records, $destination);
 							$response = [];
 							$response['status'] = true;
@@ -201,13 +207,13 @@ class FilesBrowserModule extends FilesListModule {
 	 * @param string $actionType name of the current action
 	 * @param array  $actionData all parameters contained in this request
 	 *
-	 * @throws BackendException if the backend request fails
-	 *
 	 * @return bool
+	 *
+	 * @throws BackendException if the backend request fails
 	 */
 	public function loadFiles($actionType, $actionData) {
 		$nodeId = $actionData['id'];
-		$onlyFiles = isset($actionData['only_files']) ? $actionData['only_files'] : false;
+		$onlyFiles = $actionData['only_files'] ?? false;
 		$response = [];
 		$nodes = [];
 
@@ -218,7 +224,7 @@ class FilesBrowserModule extends FilesListModule {
 			$accounts = $this->accountStore->getAllAccounts();
 			foreach ($accounts as $account) { // we have to load all accounts and their folders
 				// skip accounts that are not valid
-				if ($account->getStatus() != \Files\Core\Account::STATUS_OK) {
+				if ($account->getStatus() != Account::STATUS_OK) {
 					continue;
 				}
 				// build the real node id for this folder
@@ -268,13 +274,13 @@ class FilesBrowserModule extends FilesListModule {
 	 * Forms the structure needed for frontend
 	 * for the list of folders and files.
 	 *
-	 * @param string                        $nodeId          the name of the current root directory
-	 * @param Files\Backend\AbstractBackend $backendInstance
-	 * @param bool                          $onlyFiles       if true, get only files
-	 *
-	 * @throws BackendException if the backend request fails
+	 * @param string          $nodeId          the name of the current root directory
+	 * @param AbstractBackend $backendInstance
+	 * @param bool            $onlyFiles       if true, get only files
 	 *
 	 * @return array of nodes for current path folder
+	 *
+	 * @throws BackendException if the backend request fails
 	 */
 	public function getFolderContent($nodeId, $backendInstance, $onlyFiles = false) {
 		$nodes = [];
@@ -299,12 +305,12 @@ class FilesBrowserModule extends FilesListModule {
 
 		// FIXME: There is something issue with getting sharing information from owncloud.
 		// check if backend supports sharing and load the information
-		if ($backendInstance->supports(\Files\Backend\BackendStore::FEATURE_SHARING)) {
+		if ($backendInstance->supports(BackendStore::FEATURE_SHARING)) {
 			Logger::debug(self::LOG_CONTEXT, "Checking for shared folders! ({$relNodeId})");
 
 			$time_start = microtime(true);
 
-			/** @var \Files\Backend\iFeatureSharing $backendInstance */
+			/** @var iFeatureSharing $backendInstance */
 			$sharingInfo = $backendInstance->getShares($relNodeId);
 			$time_end = microtime(true);
 			$time = $time_end - $time_start;
@@ -317,7 +323,7 @@ class FilesBrowserModule extends FilesListModule {
 			foreach ($dir as $id => $node) {
 				$type = FILES_FILE;
 
-				if (strcmp($node['resourcetype'], "collection") == 0) { // we have a folder
+				if (strcmp((string) $node['resourcetype'], "collection") == 0) { // we have a folder
 					$type = FILES_FOLDER;
 				}
 
@@ -334,7 +340,7 @@ class FilesBrowserModule extends FilesListModule {
 
 				Logger::debug(self::LOG_CONTEXT, "parsing: " . $id . " in base: " . $nodeId);
 
-				$filename = stringToUTF8Encode(basename($id));
+				$filename = stringToUTF8Encode(basename((string) $id));
 
 				$size = $node['getcontentlength'] === null ? -1 : intval($node['getcontentlength']);
 				$size = $type == FILES_FOLDER ? -1 : $size; // folder's dont have a size
@@ -345,7 +351,7 @@ class FilesBrowserModule extends FilesListModule {
 				$sharedid = [];
 				if (isset($sharingInfo) && count($sharingInfo[$relNodeId]) > 0) {
 					foreach ($sharingInfo[$relNodeId] as $sid => $sdetails) {
-						if ($sdetails["path"] == rtrim($id, "/")) {
+						if ($sdetails["path"] == rtrim((string) $id, "/")) {
 							$shared = true;
 							$sharedid[] = $sid;
 						}
@@ -384,7 +390,7 @@ class FilesBrowserModule extends FilesListModule {
 					'path' => $path,
 					'filename' => $filename,
 					'message_size' => $size,
-					'lastmodified' => strtotime($node['getlastmodified']) * 1000,
+					'lastmodified' => strtotime((string) $node['getlastmodified']) * 1000,
 					'message_class' => "IPM.Files",
 					'isshared' => $shared,
 					'sharedid' => $sharedid,
@@ -447,9 +453,9 @@ class FilesBrowserModule extends FilesListModule {
 	 * @param string $actionType name of the current action
 	 * @param array  $actionData all parameters contained in this request
 	 *
-	 * @throws BackendException if the backend request fails
-	 *
 	 * @return bool
+	 *
+	 * @throws BackendException if the backend request fails
 	 */
 	private function delete($actionType, $actionData) {
 		// TODO: function is duplicate of class.hierarchylistmodule.php of delete function.
@@ -457,7 +463,7 @@ class FilesBrowserModule extends FilesListModule {
 		if (isset($actionData['records']) && is_array($actionData['records'])) {
 			foreach ($actionData['records'] as $record) {
 				$nodeId = $record['folder_id'];
-				$relNodeId = substr($nodeId, strpos($nodeId, '/'));
+				$relNodeId = substr((string) $nodeId, strpos((string) $nodeId, '/'));
 
 				$account = $this->accountFromNode($nodeId);
 
@@ -485,7 +491,7 @@ class FilesBrowserModule extends FilesListModule {
 		else {
 			$nodeId = $actionData['folder_id'];
 
-			$relNodeId = substr($nodeId, strpos($nodeId, '/'));
+			$relNodeId = substr((string) $nodeId, strpos((string) $nodeId, '/'));
 			$response = [];
 
 			$account = $this->accountFromNode($nodeId);
@@ -496,7 +502,7 @@ class FilesBrowserModule extends FilesListModule {
 			try {
 				$result = $initializedBackend->delete($relNodeId);
 			}
-			catch (\Files\Backend\Exception $e) {
+			catch (BackendException) {
 				// TODO: this might fails because the file was already deleted.
 				// fire error message if any other error occurred.
 				Logger::debug(self::LOG_CONTEXT, "deleted a directory that was no longer available");
@@ -541,24 +547,24 @@ class FilesBrowserModule extends FilesListModule {
 	 * @return bool if the backend request failed
 	 */
 	private function move($actionType, $actionData) {
-		$dst = rtrim($actionData['message_action']["destination_folder_id"], '/');
+		$dst = rtrim((string) $actionData['message_action']["destination_folder_id"], '/');
 
-		$overwrite = isset($actionData['message_action']["overwrite"]) ? $actionData['message_action']["overwrite"] : true;
-		$isFolder = isset($actionData['message_action']["isFolder"]) ? $actionData['message_action']["isFolder"] : false;
+		$overwrite = $actionData['message_action']["overwrite"] ?? true;
+		$isFolder = $actionData['message_action']["isFolder"] ?? false;
 
 		$pathPostfix = "";
-		if (substr($actionData['folder_id'], -1) == '/') {
+		if (str_ends_with((string) $actionData['folder_id'], '/')) {
 			$pathPostfix = "/"; // we have a folder...
 		}
 
-		$source = rtrim($actionData['folder_id'], '/');
+		$source = rtrim((string) $actionData['folder_id'], '/');
 		$fileName = basename($source);
 		$destination = $dst . '/' . basename($source);
 
 		// get dst and source account ids
 		// currently only moving within one account is supported
-		$srcAccountID = substr($actionData['folder_id'], 3, (strpos($actionData['folder_id'], '/') - 3)); // parse account id from node id
-		$dstAccountID = substr($actionData['message_action']["destination_folder_id"], 3, (strpos($actionData['message_action']["destination_folder_id"], '/') - 3)); // parse account id from node id
+		$srcAccountID = substr((string) $actionData['folder_id'], 3, strpos((string) $actionData['folder_id'], '/') - 3); // parse account id from node id
+		$dstAccountID = substr((string) $actionData['message_action']["destination_folder_id"], 3, strpos((string) $actionData['message_action']["destination_folder_id"], '/') - 3); // parse account id from node id
 
 		if ($srcAccountID !== $dstAccountID) {
 			$this->sendFeedback(false, [
@@ -641,13 +647,13 @@ class FilesBrowserModule extends FilesListModule {
 	 * @param string $actionType name of the current action
 	 * @param array  $actionData all parameters contained in this request
 	 *
-	 * @throws BackendException if the backend request fails
-	 *
 	 * @return bool
+	 *
+	 * @throws BackendException if the backend request fails
 	 */
 	public function rename($actionType, $actionData) {
 		$messageProps = $this->save($actionData);
-		$notifySubFolders = isset($actionData['message_action']['isFolder']) ? $actionData['message_action']['isFolder'] : true;
+		$notifySubFolders = $actionData['message_action']['isFolder'] ?? true;
 		if (!empty($messageProps)) {
 			$GLOBALS["bus"]->notify(REQUEST_ENTRYID, OBJECT_SAVE, $messageProps);
 			if ($notifySubFolders) {
@@ -662,9 +668,9 @@ class FilesBrowserModule extends FilesListModule {
 	 * @param array $records     which needs to be check for existence
 	 * @param array $destination where the given records needs to be moved, uploaded, or renamed
 	 *
-	 * @throws BackendException if the backend request fails
-	 *
 	 * @return bool True if duplicate found, false otherwise
+	 *
+	 * @throws BackendException if the backend request fails
 	 */
 	private function checkIfExists($records, $destination) {
 		$duplicate = false;
@@ -681,27 +687,27 @@ class FilesBrowserModule extends FilesListModule {
 			// initialize the backend
 			$initializedBackend = $this->initializeBackend($account);
 
-			$relDirname = substr($destination, strpos($destination, '/'));
+			$relDirname = substr((string) $destination, strpos((string) $destination, '/'));
 			Logger::debug(self::LOG_CONTEXT, "Getting content for: " . $relDirname);
 
 			try {
 				$lsdata = $initializedBackend->ls($relDirname); // we can only check files in the same folder, so one request will be enough
 			}
-			catch (Exception $e) {
+			catch (Exception) {
 				// ignore - if file not found -> does not exist :)
 			}
 			if (isset($lsdata) && is_array($lsdata)) {
 				foreach ($records as $record) {
-					$relRecId = substr($record["id"], strpos($record["id"], '/'));
-					Logger::debug(self::LOG_CONTEXT, "Checking rec: " . $relRecId, "Core");
+					$relRecId = substr((string) $record["id"], strpos((string) $record["id"], '/'));
+					Logger::debug(self::LOG_CONTEXT, "Checking rec: " . $relRecId);
 					foreach ($lsdata as $argsid => $args) {
-						if (strcmp($args['resourcetype'], "collection") == 0 && $record["isFolder"] && strcmp(basename($argsid), basename($relRecId)) == 0) { // we have a folder
-							Logger::debug(self::LOG_CONTEXT, "Duplicate folder found: " . $argsid, "Core");
+						if (strcmp((string) $args['resourcetype'], "collection") == 0 && $record["isFolder"] && strcmp(basename($argsid), basename($relRecId)) == 0) { // we have a folder
+							Logger::debug(self::LOG_CONTEXT, "Duplicate folder found: " . $argsid);
 							$duplicate = true;
 							break;
 						}
-						if (strcmp($args['resourcetype'], "collection") != 0 && !$record["isFolder"] && strcmp(basename($argsid), basename($relRecId)) == 0) {
-							Logger::debug(self::LOG_CONTEXT, "Duplicate file found: " . $argsid, "Core");
+						if (strcmp((string) $args['resourcetype'], "collection") != 0 && !$record["isFolder"] && strcmp(basename($argsid), basename($relRecId)) == 0) {
+							Logger::debug(self::LOG_CONTEXT, "Duplicate file found: " . $argsid);
 							$duplicate = true;
 							break;
 						}
@@ -709,7 +715,7 @@ class FilesBrowserModule extends FilesListModule {
 					}
 
 					if ($duplicate) {
-						Logger::debug(self::LOG_CONTEXT, "Duplicate entry: " . $relRecId, "Core");
+						Logger::debug(self::LOG_CONTEXT, "Duplicate entry: " . $relRecId);
 						break;
 					}
 				}
@@ -742,11 +748,11 @@ class FilesBrowserModule extends FilesListModule {
 		$initializedBackend = $this->initializeBackend($account);
 
 		foreach ($ids as $file) {
-			$filename = basename($file);
+			$filename = basename((string) $file);
 			$tmpname = $attachment_state->getAttachmentTmpPath($filename);
 
 			// download file from the backend
-			$relRecId = substr($file, strpos($file, '/'));
+			$relRecId = substr((string) $file, strpos((string) $file, '/'));
 			$http_status = $initializedBackend->get_file($relRecId, $tmpname);
 
 			$filesize = filesize($tmpname);
@@ -798,9 +804,9 @@ class FilesBrowserModule extends FilesListModule {
 
 		if ($actionData["type"] === "attachment") {
 			foreach ($actionData["items"] as $item) {
-				list($tmpname, $filename) = $this->prepareAttachmentForUpload($item);
+				[$tmpname, $filename] = $this->prepareAttachmentForUpload($item);
 
-				$dirName = substr($actionData["destdir"], strpos($actionData["destdir"], '/'));
+				$dirName = substr((string) $actionData["destdir"], strpos((string) $actionData["destdir"], '/'));
 				$filePath = $dirName . $filename;
 
 				Logger::debug(self::LOG_CONTEXT, "Uploading to: " . $filePath . " tmpfile: " . $tmpname);
@@ -813,9 +819,9 @@ class FilesBrowserModule extends FilesListModule {
 		}
 		elseif ($actionData["type"] === "mail") {
 			foreach ($actionData["items"] as $item) {
-				list($tmpname, $filename) = $this->prepareEmailForUpload($item);
+				[$tmpname, $filename] = $this->prepareEmailForUpload($item);
 
-				$dirName = substr($actionData["destdir"], strpos($actionData["destdir"], '/'));
+				$dirName = substr((string) $actionData["destdir"], strpos((string) $actionData["destdir"], '/'));
 				$filePath = $dirName . $filename;
 
 				Logger::debug(self::LOG_CONTEXT, "Uploading to: " . $filePath . " tmpfile: " . $tmpname);
@@ -846,10 +852,10 @@ class FilesBrowserModule extends FilesListModule {
 	/**
 	 * Update the cache of selected directory.
 	 *
-	 * @param Files\Backend\AbstractBackend $backendInstance
-	 * @param string                        $dirName         The directory name
-	 * @param $filePath The file path
-	 * @param $actionData The action data
+	 * @param AbstractBackend $backendInstance
+	 * @param string          $dirName         The directory name
+	 * @param                 $filePath        The file path
+	 * @param                 $actionData      The action data
 	 *
 	 * @throws BackendException
 	 */
@@ -871,7 +877,6 @@ class FilesBrowserModule extends FilesListModule {
 	 * It will store the attachment to the TMP folder and return its temporary
 	 * path and filename as array.
 	 *
-	 * @param $items
 	 * @param mixed $item
 	 *
 	 * @return array (tmpname, filename) or false on error
@@ -904,11 +909,11 @@ class FilesBrowserModule extends FilesListModule {
 		// Check if storeid and entryid isset
 		if ($storeid && $entryid) {
 			// Open the store
-			$store = $GLOBALS["mapisession"]->openMessageStore(hex2bin($storeid));
+			$store = $GLOBALS["mapisession"]->openMessageStore(hex2bin((string) $storeid));
 
 			if ($store) {
 				// Open the message
-				$message = mapi_msgstore_openentry($store, hex2bin($entryid));
+				$message = mapi_msgstore_openentry($store, hex2bin((string) $entryid));
 
 				if ($message) {
 					$attachment = false;
@@ -926,7 +931,7 @@ class FilesBrowserModule extends FilesListModule {
 						}
 
 						// Open the attachment
-						$attachment = mapi_message_openattach($message, (int) $attachNum[(count($attachNum) - 1)]);
+						$attachment = mapi_message_openattach($message, (int) $attachNum[count($attachNum) - 1]);
 					}
 
 					// Check if the attachment is opened
@@ -1016,8 +1021,6 @@ class FilesBrowserModule extends FilesListModule {
 	/**
 	 * Store the email as eml to a temporary directory and return its temporary filename.
 	 *
-	 * @param string $actionType
-	 * @param array $actionData
 	 * @param mixed $item
 	 *
 	 * @return array (tmpname, filename) or false on error
@@ -1049,9 +1052,9 @@ class FilesBrowserModule extends FilesListModule {
 			$messageProps = mapi_getprops($message, [PR_SUBJECT, PR_MESSAGE_CLASS]);
 
 			$isSupportedMessage = (
-				(stripos($messageProps[PR_MESSAGE_CLASS], 'IPM.Note') === 0) ||
-				(stripos($messageProps[PR_MESSAGE_CLASS], 'Report.IPM.Note') === 0) ||
-				(stripos($messageProps[PR_MESSAGE_CLASS], 'IPM.Schedule') === 0)
+				(stripos((string) $messageProps[PR_MESSAGE_CLASS], 'IPM.Note') === 0) ||
+				(stripos((string) $messageProps[PR_MESSAGE_CLASS], 'Report.IPM.Note') === 0) ||
+				(stripos((string) $messageProps[PR_MESSAGE_CLASS], 'IPM.Schedule') === 0)
 			);
 
 			if ($isSupportedMessage) {
@@ -1092,9 +1095,6 @@ class FilesBrowserModule extends FilesListModule {
 	/**
 	 * Get sharing information from the backend.
 	 *
-	 * @param $actionType
-	 * @param $actionData
-	 *
 	 * @return bool
 	 */
 	private function getSharingInformation($actionType, $actionData) {
@@ -1119,7 +1119,7 @@ class FilesBrowserModule extends FilesListModule {
 
 		$relRecords = [];
 		foreach ($records as $record) {
-			$relRecords[] = substr($record, strpos($record, '/')); // remove account id
+			$relRecords[] = substr((string) $record, strpos((string) $record, '/')); // remove account id
 		}
 
 		try {
@@ -1152,9 +1152,6 @@ class FilesBrowserModule extends FilesListModule {
 	/**
 	 * Create a new share.
 	 *
-	 * @param $actionType
-	 * @param $actionData
-	 *
 	 * @return bool
 	 */
 	private function createNewShare($actionType, $actionData) {
@@ -1179,7 +1176,7 @@ class FilesBrowserModule extends FilesListModule {
 
 		$sharingRecords = [];
 		foreach ($records as $record) {
-			$path = substr($record, strpos($record, '/')); // remove account id
+			$path = substr((string) $record, strpos((string) $record, '/')); // remove account id
 			$sharingRecords[$path] = $shareOptions; // add options
 		}
 
@@ -1214,9 +1211,6 @@ class FilesBrowserModule extends FilesListModule {
 	/**
 	 * Update a existing share.
 	 *
-	 * @param $actionType
-	 * @param $actionData
-	 *
 	 * @return bool
 	 */
 	private function updateExistingShare($actionType, $actionData) {
@@ -1270,9 +1264,6 @@ class FilesBrowserModule extends FilesListModule {
 	/**
 	 * Delete one or more shares.
 	 *
-	 * @param $actionType
-	 * @param $actionData
-	 *
 	 * @return bool
 	 */
 	private function deleteExistingShare($actionType, $actionData) {
@@ -1330,7 +1321,7 @@ class FilesBrowserModule extends FilesListModule {
 		$account = $this->accountStore->getAccount($accountID);
 		// initialize the backend
 		$initializedBackend = $this->initializeBackend($account, true);
-		$relNodeId = substr($nodeId, strpos($nodeId, '/'));
+		$relNodeId = substr((string) $nodeId, strpos((string) $nodeId, '/'));
 
 		// remove the trailing slash for the cache key
 		$cachePath = rtrim($relNodeId, '/');
