@@ -6,6 +6,7 @@ require_once __DIR__ . "/class.fileslistmodule.php";
  * This module handles all list and change requests for the files browser.
  *
  * @class HierarchyListModule
+ *
  * @extends FilesListModule
  */
 class HierarchyListModule extends FilesListModule {
@@ -22,6 +23,7 @@ class HierarchyListModule extends FilesListModule {
 	/**
 	 * @return bool|void
 	 */
+	#[Override]
 	public function execute() {
 		$result = false;
 		foreach ($this->data as $actionType => $actionData) {
@@ -95,7 +97,7 @@ class HierarchyListModule extends FilesListModule {
 	 * @param mixed $action
 	 */
 	public function hierarchyList($action) {
-		$isReload = isset($action['reload']) ? $action['reload'] : false;
+		$isReload = $action['reload'] ?? false;
 		$data = $this->getHierarchyList($isReload);
 		$this->addActionData("list", $data);
 		$GLOBALS["bus"]->addData($this->getResponseData());
@@ -117,12 +119,11 @@ class HierarchyListModule extends FilesListModule {
 	}
 
 	/**
-	 * @param $actionData
-	 *
-	 * @throws \Files\Backend\Exception
-	 *
 	 * @return array|void
+	 *
+	 * @throws Files\Backend\Exception
 	 */
+	#[Override]
 	public function save($actionData) {
 		$messageProps = parent::save($actionData);
 		if (!empty($messageProps)) {
@@ -138,19 +139,18 @@ class HierarchyListModule extends FilesListModule {
 	/**
 	 * Deletes the selected files on the backend server.
 	 *
-	 * @param string $actionType name of the current action
-	 * @param array  $actionData all parameters contained in this request
-	 *
-	 * @throws BackendException if the backend request fails
+	 * @param array $actionData all parameters contained in this request
 	 *
 	 * @return bool
+	 *
+	 * @throws BackendException if the backend request fails
 	 */
 	public function delete($actionData) {
 		// TODO: Do we need this if block code?
 		if (isset($actionData['records']) && is_array($actionData['records'])) {
 			foreach ($actionData['records'] as $record) {
 				$nodeId = $record['entryid'];
-				$relNodeId = substr($nodeId, strpos($nodeId, '/'));
+				$relNodeId = substr((string) $nodeId, strpos((string) $nodeId, '/'));
 
 				$account = $this->accountFromNode($nodeId);
 
@@ -175,7 +175,7 @@ class HierarchyListModule extends FilesListModule {
 		}
 		else {
 			$nodeId = $actionData['folder_id'];
-			$relNodeId = substr($nodeId, strpos($nodeId, '/'));
+			$relNodeId = substr((string) $nodeId, strpos((string) $nodeId, '/'));
 
 			$account = $this->accountFromNode($nodeId);
 			$accountId = $account->getId();
@@ -186,7 +186,7 @@ class HierarchyListModule extends FilesListModule {
 			try {
 				$initializedBackend->delete($relNodeId);
 			}
-			catch (\Files\Backend\Exception $e) {
+			catch (Files\Backend\Exception) {
 				// TODO: this might fails because the file was already deleted.
 				// fire error message if any other error occurred.
 				// Logger::debug(self::LOG_CONTEXT, "deleted a directory that was no longer available");
