@@ -18,6 +18,7 @@ use OCSAPI\Exception\ConnectionException;
 use OCSAPI\Exception\FileNotFoundException;
 use OCSAPI\ocsclient;
 use OCSAPI\ocsshare;
+use Sabre\DAV\Client;
 use Sabre\DAV\Exception;
 use Sabre\HTTP\ClientException;
 
@@ -26,6 +27,7 @@ use Sabre\HTTP\ClientException;
  * It requires the Webdav File Backend!
  *
  * @class   Backend
+ *
  * @extends AbstractBackend
  */
 class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing {
@@ -136,7 +138,7 @@ class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing {
 				"fields" => $this->formFields,
 				"formConfig" => $this->formConfig,
 			],
-			"data" => [ // here we can specify the default values.
+			"data" => [
 				"server_address" => $_SERVER['HTTP_HOST'],
 				"server_ssl" => true,
 				"server_port" => "443",
@@ -149,10 +151,11 @@ class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing {
 	/**
 	 * Opens the connection to the webdav server.
 	 *
-	 * @throws BackendException if connection is not successful
-	 *
 	 * @return bool true if action succeeded
+	 *
+	 * @throws BackendException if connection is not successful
 	 */
+	#[\Override]
 	public function open() {
 		// check if curl is available
 		$serverHasCurl = function_exists('curl_version');
@@ -167,7 +170,7 @@ class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing {
 			'baseUri' => $this->webdavUrl(),
 			'userName' => $this->user,
 			'password' => $this->pass,
-			'authType' => \Sabre\DAV\Client::AUTH_BASIC,
+			'authType' => Client::AUTH_BASIC,
 		];
 
 		try {
@@ -205,9 +208,9 @@ class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing {
 	 * @param bool   $overwrite Overwrite if collection exists in $dst_path
 	 * @param bool   $coll      set this to true if you want to copy a folder
 	 *
-	 * @throws BackendException if request is not successful
-	 *
 	 * @return bool true if action succeeded
+	 *
+	 * @throws BackendException if request is not successful
 	 */
 	private function copy($src_path, $dst_path, $overwrite, $coll) {
 		$time_start = microtime(true);
@@ -262,59 +265,21 @@ class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing {
 		$msg = _('Unknown error');
 		$contactAdmin = _('Please contact your system administrator.');
 
-		switch ($error) {
-			case CURLE_BAD_PASSWORD_ENTERED:
-			case self::WD_ERR_UNAUTHORIZED:
-				$msg = _('Unauthorized. Wrong username or password.');
-				break;
-
-			case CURLE_SSL_CONNECT_ERROR:
-			case CURLE_COULDNT_RESOLVE_HOST:
-			case CURLE_COULDNT_CONNECT:
-			case CURLE_OPERATION_TIMEOUTED:
-			case self::WD_ERR_UNREACHABLE:
-				$msg = _('File server is not reachable. Please verify the file server URL.');
-				break;
-
-			case self::WD_ERR_FORBIDDEN:
-				$msg = _('You don\'t have enough permissions to view this file or folder.');
-				break;
-
-			case self::WD_ERR_NOTFOUND:
-				$msg = _('The file or folder is not available anymore.');
-				break;
-
-			case self::WD_ERR_TIMEOUT:
-				$msg = _('Connection to the file server timed out. Please check again later.');
-				break;
-
-			case self::WD_ERR_LOCKED:
-				$msg = _('This file is locked by another user. Please try again later.');
-				break;
-
-			case self::WD_ERR_FAILED_DEPENDENCY:
-				$msg = _('The request failed.') . ' ' . $contactAdmin;
-				break;
-
-			case self::WD_ERR_INTERNAL:
-				// This is a general error, might be thrown due to a wrong IP, but we don't know.
-				$msg = _('The file server encountered an internal problem.') . ' ' . $contactAdmin;
-				break;
-
-			case self::WD_ERR_TMP:
-				$msg = _('We could not write to temporary directory.') . ' ' . $contactAdmin;
-				break;
-
-			case self::WD_ERR_FEATURES:
-				$msg = _('We could not retrieve list of server features.') . ' ' . $contactAdmin;
-				break;
-
-			case self::WD_ERR_NO_CURL:
-				$msg = _('PHP-Curl is not available.') . ' ' . $contactAdmin;
-				break;
-		}
-
-		return $msg;
+		return match ($error) {
+			CURLE_BAD_PASSWORD_ENTERED, self::WD_ERR_UNAUTHORIZED => _('Unauthorized. Wrong username or password.'),
+			CURLE_SSL_CONNECT_ERROR, CURLE_COULDNT_RESOLVE_HOST, CURLE_COULDNT_CONNECT, CURLE_OPERATION_TIMEOUTED, self::WD_ERR_UNREACHABLE => _('File server is not reachable. Please verify the file server URL.'),
+			self::WD_ERR_FORBIDDEN => _('You don\'t have enough permissions to view this file or folder.'),
+			self::WD_ERR_NOTFOUND => _('The file or folder is not available anymore.'),
+			self::WD_ERR_TIMEOUT => _('Connection to the file server timed out. Please check again later.'),
+			self::WD_ERR_LOCKED => _('This file is locked by another user. Please try again later.'),
+			self::WD_ERR_FAILED_DEPENDENCY => _('The request failed.') . ' ' . $contactAdmin,
+			// This is a general error, might be thrown due to a wrong IP, but we don't know.
+			self::WD_ERR_INTERNAL => _('The file server encountered an internal problem.') . ' ' . $contactAdmin,
+			self::WD_ERR_TMP => _('We could not write to temporary directory.') . ' ' . $contactAdmin,
+			self::WD_ERR_FEATURES => _('We could not retrieve list of server features.') . ' ' . $contactAdmin,
+			self::WD_ERR_NO_CURL => _('PHP-Curl is not available.') . ' ' . $contactAdmin,
+			default => $msg,
+		};
 	}
 
 	/**
@@ -349,6 +314,7 @@ class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing {
 	 *
 	 * @return string
 	 */
+	#[\Override]
 	public function getServerVersion() {
 		// check if curl is available
 		$serverHasCurl = function_exists('curl_version');
@@ -399,8 +365,6 @@ class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing {
 	 *  )
 	 * )
 	 *
-	 * @param $path
-	 *
 	 * @return array
 	 */
 	public function getShares($path) {
@@ -495,7 +459,7 @@ class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing {
 				try {
 					$shares = $this->ocs_client->loadShareByPath($patharray[0]);
 				}
-				catch (FileNotFoundException $e) {
+				catch (FileNotFoundException) {
 					$shares = false;
 				}
 
@@ -542,7 +506,6 @@ class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing {
 	 *      "id1" => options1 (ONLY if $update = true)
 	 * )
 	 *
-	 * @param $shareparams
 	 * @param bool $update
 	 *
 	 * @return bool
@@ -586,11 +549,9 @@ class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing {
 	/**
 	 * Disable sharing for the given files/folders.
 	 *
-	 * @param $idarray
-	 *
-	 * @throws \OCSAPI\Exception\ConnectionException
-	 *
 	 * @return bool
+	 *
+	 * @throws ConnectionException
 	 */
 	public function unshare($idarray) {
 		foreach ($idarray as $id) {
