@@ -36,26 +36,6 @@ class ocsclient {
 	public const OCS_PATH = "/ocs/v1.php/apps/files_sharing/api/v1";
 	public const OCS_TIMEOUT = 10;
 
-	/**
-	 * @var string Server base URL
-	 */
-	private $baseurl = "";
-
-	/**
-	 * @var string Username
-	 */
-	private $user = "";
-
-	/**
-	 * @var string Password
-	 */
-	private $pass = "";
-
-	/**
-	 * @var bool Allow self signed certs
-	 */
-	private $allowSelfSignedCerts = false;
-
 	/**
 	 * @var bool Defines if the store has been loaded
 	 */
@@ -93,25 +73,33 @@ class ocsclient {
 	/**
 	 * Constructor.
 	 *
-	 * @param $baseurl
-	 * @param $user
-	 * @param $pass
-	 * @param $allowSelfSignedCerts
+	 * @param string $baseurl
+	 * @param string $user
+	 * @param string $pass
+	 * @param bool   $allowSelfSignedCerts
 	 *
 	 * @throws ConnectionException
 	 */
-	public function __construct($baseurl, $user, $pass, $allowSelfSignedCerts = false) {
+	public function __construct(/**
+	 * @var string Server base URL
+	 */
+		private $baseurl, /**
+	 * @var string Username
+	 */
+		private $user, /**
+	 * @var string Password
+	 */
+		private $pass, /**
+	 * @var bool Allow self signed certs
+	 */
+		private $allowSelfSignedCerts = false
+	) {
 		// check if curl is available
 		$serverHasCurl = function_exists('curl_version');
 		if (!$serverHasCurl) {
 			throw new ConnectionException("Curl not found!");
 		}
 
-		$this->baseurl = $baseurl;
-		$this->user = $user;
-		$this->pass = $pass;
-		$this->allowSelfSignedCerts = $allowSelfSignedCerts;
-
 		$this->shares = [];
 		$this->sharesByPath = [];
 	}
@@ -139,13 +127,13 @@ class ocsclient {
 	/**
 	 * Execute curl request with parameters.
 	 *
-	 * @param $url string URL for the request
+	 * @param       $url         string URL for the request
 	 * @param mixed $curlOptions
 	 *
+	 * @return curl responsedata
+	 *
 	 * @throws ConnectionException
 	 * @throws InvalidResponseException
-	 *
-	 * @return curl responsedata
 	 */
 	private function doCurlRequest($url, $curlOptions) {
 		$ch = curl_init();
@@ -210,36 +198,29 @@ class ocsclient {
 	/**
 	 * Loads only one specific share defined by ID.
 	 *
-	 * @param $id
+	 * @return ocsshare or FALSE
 	 *
 	 * @throws ConnectionException
 	 * @throws InvalidResponseException
-	 *
-	 * @return ocsshare or FALSE
 	 */
 	public function loadShareByID($id) {
 		$url = $this->getOCSUrl() . "/" . $id;
 		$this->parseListingResponse($this->doCurlGetRequest($url));
 		$this->loaded = true;
-		if (isset($this->shares[$id])) {
-			return $this->shares[$id];
-		}
 
-		return false;
+		return $this->shares[$id] ?? false;
 	}
 
 	/**
 	 * Loads one or more shares defined by path.
 	 *
-	 * @param $path
+	 * @return ocsshare[] or FALSE
 	 *
 	 * @throws ConnectionException
 	 * @throws InvalidResponseException
-	 *
-	 * @return ocsshare[] or FALSE
 	 */
 	public function loadShareByPath($path) {
-		$path = rtrim($path, "/");
+		$path = rtrim((string) $path, "/");
 		$url = $this->getOCSUrl() . "?path=" . urlencode($path);
 		$this->parseListingResponse($this->doCurlGetRequest($url));
 		$this->loaded = true;
@@ -261,13 +242,13 @@ class ocsclient {
 	 *
 	 * @param mixed $search
 	 *
+	 * @return [] or FALSE
+	 *
 	 * @throws ConnectionException
 	 * @throws InvalidResponseException
-	 *
-	 * @return [] or FALSE
 	 */
 	public function getRecipients($search) {
-		$url = $this->baseurl . self::OCS_PATH . "/sharees?itemType=file&search=" . urlencode($search);
+		$url = $this->baseurl . self::OCS_PATH . "/sharees?itemType=file&search=" . urlencode((string) $search);
 
 		$ch = curl_init();
 		curl_setopt($ch, CURLOPT_URL, $url);
@@ -284,7 +265,7 @@ class ocsclient {
 			try {
 				$xmldata = new \SimpleXMLElement($responsedata);
 			}
-			catch (\Exception $e) {
+			catch (\Exception) {
 				throw new InvalidResponseException($responsedata);
 			}
 
@@ -314,8 +295,6 @@ class ocsclient {
 	/**
 	 * Returns one ocsshare specified by ID. Or FALSE if the ID was not found or store is not loaded yet.
 	 *
-	 * @param $id
-	 *
 	 * @return ocsshare or bool
 	 */
 	public function getShareByID($id) {
@@ -323,18 +302,12 @@ class ocsclient {
 			return false;
 		}
 
-		if (isset($this->shares[$id])) {
-			return $this->shares[$id];
-		}
-
-		return false;
+		return $this->shares[$id] ?? false;
 	}
 
 	/**
 	 * Returns one or many ocsshare specified by Path. Or FALSE if path was not found or store is not loaded yet.
 	 *
-	 * @param $path
-	 *
 	 * @return ocsshare[] or bool
 	 */
 	public function getShareByPath($path) {
@@ -365,24 +338,21 @@ class ocsclient {
 	 * Options has to include shareType (int),  ‘0’ = user; ‘1’ = group; ‘3’ = public link;
 	 * and shareWith for shareType 0 or 1.
 	 *
-	 * @param $path
-	 * @param $options
+	 * @return ocsshare
 	 *
 	 * @throws ConnectionException
 	 * @throws InvalidResponseException
-	 *
-	 * @return ocsshare
 	 */
 	public function createShare($path, $options) {
 		$url = $this->getOCSUrl();
 
 		// post variables
 		$fields = [
-			'path' => urlencode($path),
+			'path' => urlencode((string) $path),
 		];
 
 		foreach ($options as $key => $value) {
-			$fields[$key] = urlencode($value);
+			$fields[$key] = urlencode((string) $value);
 		}
 		// url-ify the data for the POST
 		$fields_string = "";
@@ -401,20 +371,16 @@ class ocsclient {
 	/**
 	 * Update one value of the given share. ATTENTION: updating the password will change the share id.
 	 *
-	 * @param $id
-	 * @param $key
-	 * @param $value
+	 * @return ocsshare Returns a empty share
 	 *
 	 * @throws ConnectionException
 	 * @throws InvalidResponseException
-	 *
-	 * @return ocsshare Returns a empty share
 	 */
 	public function updateShare($id, $key, $value) {
 		$url = $this->getOCSUrl() . "/" . $id;
 
 		// post variables
-		$fields_string = $key . '=' . urlencode($value);
+		$fields_string = $key . '=' . urlencode((string) $value);
 		$curlExtraOptions = [
 			CURLOPT_CUSTOMREQUEST => "PUT",
 			CURLOPT_POSTFIELDS => $fields_string,
@@ -437,12 +403,10 @@ class ocsclient {
 	/**
 	 * Delete the given share.
 	 *
-	 * @param $id
+	 * @return ocsshare Returns a empty share
 	 *
 	 * @throws ConnectionException
 	 * @throws InvalidResponseException
-	 *
-	 * @return ocsshare Returns a empty share
 	 */
 	public function deleteShare($id) {
 		$url = $this->getOCSUrl() . "/" . $id;
@@ -457,22 +421,20 @@ class ocsclient {
 	/**
 	 * Parse the response of a create or modify request.
 	 *
-	 * @param $response
+	 * @return ocsshare
 	 *
 	 * @throws FileNotFoundException
 	 * @throws InvalidArgumentException
 	 * @throws InvalidRequestException
 	 * @throws InvalidResponseException
 	 * @throws PermissionDeniedException
-	 *
-	 * @return ocsshare
 	 */
 	private function parseModificationResponse($response) {
 		if ($response) {
 			try {
 				$xmldata = new \SimpleXMLElement($response);
 			}
-			catch (\Exception $e) {
+			catch (\Exception) {
 				throw new InvalidResponseException($response);
 			}
 
@@ -502,8 +464,6 @@ class ocsclient {
 	/**
 	 * Parse the request response.
 	 *
-	 * @param $response
-	 *
 	 * @throws FileNotFoundException
 	 * @throws InvalidArgumentException
 	 * @throws InvalidRequestException
@@ -518,7 +478,7 @@ class ocsclient {
 		try {
 			$xmldata = new \SimpleXMLElement($response);
 		}
-		catch (\Exception $e) {
+		catch (\Exception) {
 			throw new InvalidResponseException($response);
 		}
 
@@ -539,15 +499,13 @@ class ocsclient {
 	/**
 	 * Parse the response meta block and its error codes.
 	 *
-	 * @param $response
+	 * @return bool
 	 *
 	 * @throws FileNotFoundException
 	 * @throws InvalidArgumentException
 	 * @throws InvalidRequestException
 	 * @throws InvalidResponseException
 	 * @throws PermissionDeniedException
-	 *
-	 * @return bool
 	 */
 	private function parseResponseMeta($response) {
 		if ($response) {
@@ -559,26 +517,13 @@ class ocsclient {
 				return true;
 			}
 
-			switch ($statuscode) {
-				case 400:
-					throw new InvalidArgumentException($message);
-					break;
-
-				case 403:
-					throw new PermissionDeniedException($message);
-					break;
-
-				case 404:
-					throw new FileNotFoundException($message);
-					break;
-
-				case 999:
-					throw new InvalidRequestException($message);
-					break;
-
-				default:
-					throw new InvalidResponseException($message);
-			}
+			match ($statuscode) {
+				400 => throw new InvalidArgumentException($message),
+				403 => throw new PermissionDeniedException($message),
+				404 => throw new FileNotFoundException($message),
+				999 => throw new InvalidRequestException($message),
+				default => throw new InvalidResponseException($message),
+			};
 		}
 		else {
 			throw new InvalidResponseException("Response contains no meta block.");
