@@ -132,7 +132,7 @@ class PluginMDMModule extends Module {
 		$ret = file_get_contents(PLUGIN_MDM_ADMIN_API_WIPE_ENDPOINT . $GLOBALS["mapisession"]->getUserName() . "?devices=" . $deviceid, false, stream_context_create($opts));
 		$ret = json_decode($ret, true);
 
-		return strncasecmp('success', $ret['message'], 7) === 0;
+		return strncasecmp('success', (string) $ret['message'], 7) === 0;
 	}
 
 	/**
@@ -205,6 +205,7 @@ class PluginMDMModule extends Module {
 	 *
 	 * @return bool true on success or false on failure
 	 */
+	#[Override]
 	public function execute() {
 		foreach ($this->data as $actionType => $actionData) {
 			if (isset($actionType)) {
@@ -346,39 +347,18 @@ class PluginMDMModule extends Module {
 	/**
 	 * Function which is use to get general type like Mail,Calendar,Contacts,etc. from folder type.
 	 *
-	 * @param int    $type foldertype for a folder already known to the mobile
-	 * @param string $name folder name
+	 * @param int $type foldertype for a folder already known to the mobile
 	 *
 	 * @return string general folder type
 	 */
 	public function getSyncFolderType($type) {
-		switch ($type) {
-			case SYNC_FOLDER_TYPE_APPOINTMENT:
-			case SYNC_FOLDER_TYPE_USER_APPOINTMENT:
-				$folderType = "Calendars";
-				break;
-
-			case SYNC_FOLDER_TYPE_CONTACT:
-			case SYNC_FOLDER_TYPE_USER_CONTACT:
-				$folderType = "Contacts";
-				break;
-
-			case SYNC_FOLDER_TYPE_TASK:
-			case SYNC_FOLDER_TYPE_USER_TASK:
-				$folderType = "Tasks";
-				break;
-
-			case SYNC_FOLDER_TYPE_NOTE:
-			case SYNC_FOLDER_TYPE_USER_NOTE:
-				$folderType = "Notes";
-				break;
-
-			default:
-				$folderType = "Emails";
-				break;
-		}
-
-		return $folderType;
+		return match ($type) {
+			SYNC_FOLDER_TYPE_APPOINTMENT, SYNC_FOLDER_TYPE_USER_APPOINTMENT => "Calendars",
+			SYNC_FOLDER_TYPE_CONTACT, SYNC_FOLDER_TYPE_USER_CONTACT => "Contacts",
+			SYNC_FOLDER_TYPE_TASK, SYNC_FOLDER_TYPE_USER_TASK => "Tasks",
+			SYNC_FOLDER_TYPE_NOTE, SYNC_FOLDER_TYPE_USER_NOTE => "Notes",
+			default => "Emails",
+		};
 	}
 
 	/**
@@ -398,9 +378,9 @@ class PluginMDMModule extends Module {
 		foreach ($items as $item) {
 			foreach ($stores as $store) {
 				try {
-					$entryid = mapi_msgstore_entryidfromsourcekey($store, hex2bin($item->folderid));
+					$entryid = mapi_msgstore_entryidfromsourcekey($store, hex2bin((string) $item->folderid));
 				}
-				catch (MAPIException $me) {
+				catch (MAPIException) {
 					continue;
 				}
 			}
@@ -432,8 +412,8 @@ class PluginMDMModule extends Module {
 	 */
 	public function additionalFolderAdd($entryId, $folder) {
 		$client = $this->getSoapClient();
-		$containerClass = isset($folder[PR_CONTAINER_CLASS]) ? $folder[PR_CONTAINER_CLASS] : "IPF.Note";
-		$folderId = bin2hex($folder[PR_SOURCE_KEY]);
+		$containerClass = $folder[PR_CONTAINER_CLASS] ?? "IPF.Note";
+		$folderId = bin2hex((string) $folder[PR_SOURCE_KEY]);
 		$userName = $folder["user"];
 		$folderName = $userName === "SYSTEM" ? $folder[PR_DISPLAY_NAME] : $folder[PR_DISPLAY_NAME] . " - " . $userName;
 		$folderType = $this->getFolderTypeFromContainerClass($containerClass);
@@ -460,7 +440,7 @@ class PluginMDMModule extends Module {
 				$hierarchyFolders = $this->getHierarchyList();
 				foreach ($addFolders as $folder) {
 					foreach ($hierarchyFolders as $hierarchyFolder) {
-						$folderEntryid = bin2hex($hierarchyFolder[PR_ENTRYID]);
+						$folderEntryid = bin2hex((string) $hierarchyFolder[PR_ENTRYID]);
 						if ($folderEntryid === $folder["entryid"]) {
 							$this->additionalFolderAdd($entryid, $hierarchyFolder);
 
@@ -595,25 +575,25 @@ class PluginMDMModule extends Module {
 			switch ($from) {
 				case "inbox":
 					if (isset($inboxProps[$tag])) {
-						$storeData["props"][$key] = bin2hex($inboxProps[$tag]);
+						$storeData["props"][$key] = bin2hex((string) $inboxProps[$tag]);
 					}
 					break;
 
 				case "store":
 					if (isset($msgstore_props[$tag])) {
-						$storeData["props"][$key] = bin2hex($msgstore_props[$tag]);
+						$storeData["props"][$key] = bin2hex((string) $msgstore_props[$tag]);
 					}
 					break;
 
 				case "root":
 					if (isset($rootProps[$tag])) {
-						$storeData["props"][$key] = bin2hex($rootProps[$tag]);
+						$storeData["props"][$key] = bin2hex((string) $rootProps[$tag]);
 					}
 					break;
 
 				case "additional":
 					if (isset($additional_ren_entryids[$tag])) {
-						$storeData["props"][$key] = bin2hex($additional_ren_entryids[$tag]);
+						$storeData["props"][$key] = bin2hex((string) $additional_ren_entryids[$tag]);
 					}
 					break;
 			}
@@ -743,36 +723,21 @@ class PluginMDMModule extends Module {
 	 * @return int folder type
 	 */
 	public function getFolderTypeFromContainerClass($containerClass) {
-		switch ($containerClass) {
-			case "IPF.Note":
-				return SYNC_FOLDER_TYPE_USER_MAIL;
-
-			case "IPF.Appointment":
-				return SYNC_FOLDER_TYPE_USER_APPOINTMENT;
-
-			case "IPF.Contact":
-				return SYNC_FOLDER_TYPE_USER_CONTACT;
-
-			case "IPF.StickyNote":
-				return SYNC_FOLDER_TYPE_USER_NOTE;
-
-			case "IPF.Task":
-				return SYNC_FOLDER_TYPE_USER_TASK;
-
-			case "IPF.Journal":
-				return SYNC_FOLDER_TYPE_USER_JOURNAL;
-
-			default:
-				return SYNC_FOLDER_TYPE_UNKNOWN;
-		}
+		return match ($containerClass) {
+			"IPF.Note" => SYNC_FOLDER_TYPE_USER_MAIL,
+			"IPF.Appointment" => SYNC_FOLDER_TYPE_USER_APPOINTMENT,
+			"IPF.Contact" => SYNC_FOLDER_TYPE_USER_CONTACT,
+			"IPF.StickyNote" => SYNC_FOLDER_TYPE_USER_NOTE,
+			"IPF.Task" => SYNC_FOLDER_TYPE_USER_TASK,
+			"IPF.Journal" => SYNC_FOLDER_TYPE_USER_JOURNAL,
+			default => SYNC_FOLDER_TYPE_UNKNOWN,
+		};
 	}
 
 	/**
 	 * Returns MAPIFolder object which contains the state information.
 	 * Creates this folder if it is not available yet.
 	 *
-	 * @param string $devid the device id
-	 *
 	 * @return MAPIFolder
 	 */
 	public function getStoreStateFolder() {
