@@ -377,7 +377,7 @@ Zarafa.plugins.smime.dialogs.ChangePassphrasePanel = Ext.extend(Ext.Panel, {
 	 */
 	onChangePassphraseRequest: function(response) {
 		if (response.code === Zarafa.plugins.smime.CHANGE_CERTIFICATE_SUCCESS) {
-			container.getNotifier().notify('info.saved', _('S/MIME Message'), _('Passphrase changed succesfully'));
+			container.getNotifier().notify('info.saved', _('S/MIME Message'), _('Passphrase changed successfully'));
 			this.dialog.close();
 		} else {
 			this.wrong_passphrase.show();
@@ -2398,7 +2398,7 @@ Zarafa.plugins.smime.SmimeText = function () {
 			case 5:
 				return _('Verification with Certificate Authority failed');
 			case 6:
-				return _('Message decrypted succesfully');
+				return _('Message decrypted successfully');
 			case 7:
 				return _('Message decryption failed');
 			case 8:
