@@ -8,12 +8,12 @@ define('CHANGE_PASSPHRASE_WRONG', 3);
 
 class PluginSmimeModule extends Module {
 	private $store;
+
 	/**
 	 * Constructor.
 	 *
-	 * @param int    $id            unique id
-	 * @param string $folderentryid Entryid of the folder. Data will be selected from this folder.
-	 * @param array  $data          list of all actions
+	 * @param int   $id   unique id
+	 * @param array $data list of all actions
 	 */
 	public function __construct($id, $data) {
 		$this->store = $GLOBALS['mapisession']->getDefaultMessageStore();
@@ -25,71 +25,76 @@ class PluginSmimeModule extends Module {
 	 *
 	 * @return bool true on success or false on failure
 	 */
+	#[Override]
 	public function execute() {
-		foreach ($this->data as $actionType => $actionData) try {
-			if (!isset($actionType))
-				continue;
-			switch ($actionType) {
-			case 'certificate':
-				$data = $this->verifyCertificate($actionData);
-				$response = [
-					'type' => 3,
-					'status' => $data['status'],
-					'message' => $data['message'],
-					'data' => $data['data'],
-				];
-				$this->addActionData('certificate', $response);
-				$GLOBALS['bus']->addData($this->getResponseData());
-				break;
-
-			case 'passphrase':
-				$data = $this->verifyPassphrase($actionData);
-				$response = [
-					'type' => 3,
-					'status' => $data['status'],
-				];
-				$this->addActionData('passphrase', $response);
-				$GLOBALS['bus']->addData($this->getResponseData());
-				break;
-
-			case 'changepassphrase':
-				$data = $this->changePassphrase($actionData);
-				if ($data === CHANGE_PASSPHRASE_SUCCESS) {
-					// Reset cached passphrase.
-					$encryptionStore = EncryptionStore::getInstance();
-					withPHPSession(function () use ($encryptionStore) {
-						$encryptionStore->add('smime', '');
-					});
+		foreach ($this->data as $actionType => $actionData) {
+			try {
+				if (!isset($actionType)) {
+					continue;
 				}
-				$response = [
-					'type' => 3,
-					'code' => $data,
-				];
-				$this->addActionData('changepassphrase', $response);
-				$GLOBALS['bus']->addData($this->getResponseData());
-				break;
 
-			case 'list':
-				$data = $this->getPublicCertificates();
-				$this->addActionData('list', $data);
-				$GLOBALS['bus']->addData($this->getResponseData());
-				break;
+				switch ($actionType) {
+					case 'certificate':
+						$data = $this->verifyCertificate($actionData);
+						$response = [
+							'type' => 3,
+							'status' => $data['status'],
+							'message' => $data['message'],
+							'data' => $data['data'],
+						];
+						$this->addActionData('certificate', $response);
+						$GLOBALS['bus']->addData($this->getResponseData());
+						break;
 
-			case 'delete':
-				// FIXME: handle multiple deletes? Separate function?
-				$entryid = $actionData['entryid'];
-				$root = mapi_msgstore_openentry($this->store);
-				mapi_folder_deletemessages($root, [hex2bin($entryid)]);
+					case 'passphrase':
+						$data = $this->verifyPassphrase($actionData);
+						$response = [
+							'type' => 3,
+							'status' => $data['status'],
+						];
+						$this->addActionData('passphrase', $response);
+						$GLOBALS['bus']->addData($this->getResponseData());
+						break;
 
-				$this->sendFeedback(true);
-				break;
+					case 'changepassphrase':
+						$data = $this->changePassphrase($actionData);
+						if ($data === CHANGE_PASSPHRASE_SUCCESS) {
+							// Reset cached passphrase.
+							$encryptionStore = EncryptionStore::getInstance();
+							withPHPSession(function () use ($encryptionStore) {
+								$encryptionStore->add('smime', '');
+							});
+						}
+						$response = [
+							'type' => 3,
+							'code' => $data,
+						];
+						$this->addActionData('changepassphrase', $response);
+						$GLOBALS['bus']->addData($this->getResponseData());
+						break;
 
-			default:
-				$this->handleUnknownActionType($actionType);
+					case 'list':
+						$data = $this->getPublicCertificates();
+						$this->addActionData('list', $data);
+						$GLOBALS['bus']->addData($this->getResponseData());
+						break;
+
+					case 'delete':
+						// FIXME: handle multiple deletes? Separate function?
+						$entryid = $actionData['entryid'];
+						$root = mapi_msgstore_openentry($this->store);
+						mapi_folder_deletemessages($root, [hex2bin((string) $entryid)]);
+
+						$this->sendFeedback(true);
+						break;
+
+					default:
+						$this->handleUnknownActionType($actionType);
+				}
+			}
+			catch (Exception $e) {
+				$this->sendFeedback(false, parent::errorDetailsFromException($e));
 			}
-		}
-		catch (Exception $e) {
-			$this->sendFeedback(false, parent::errorDetailsFromException($e));
 		}
 	}
 
@@ -114,14 +119,14 @@ class PluginSmimeModule extends Module {
 
 		// No certificates
 		if (!$privateCerts || count($privateCerts) === 0) {
-			$message = _('No certificate avaliable');
+			$message = _('No certificate available');
 		}
 		else {
 			// For each certificate in MAPI store
 			$smtpAddress = $GLOBALS['mapisession']->getSMTPAddress();
 			for ($i = 0, $cnt = count($privateCerts); $i < $cnt; ++$i) {
 				// Check if certificate is still valid
-				// TODO: create a more generic function which verifyies if the certificate is valid
+				// TODO: create a more generic function which verifies if the certificate is valid
 				// And remove possible duplication from plugin.smime.php->onUploadCertificate
 				if ($privateCerts[$i][PR_MESSAGE_DELIVERY_TIME] < time()) { // validTo
 					$message = _('Private certificate has expired, unable to sign email');
@@ -129,7 +134,7 @@ class PluginSmimeModule extends Module {
 				elseif ($privateCerts[$i][PR_CLIENT_SUBMIT_TIME] >= time()) { // validFrom
 					$message = _('Private certificate is not valid yet, unable to sign email');
 				}
-				elseif (strcasecmp($privateCerts[$i][PR_SUBJECT], $smtpAddress) !== 0) {
+				elseif (strcasecmp((string) $privateCerts[$i][PR_SUBJECT], (string) $smtpAddress) !== 0) {
 					$message = _('Private certificate does not match email address');
 				}
 				else {
@@ -217,7 +222,7 @@ class PluginSmimeModule extends Module {
 		$certs = mapi_table_queryallrows($table, [PR_SUBJECT, PR_ENTRYID, PR_MESSAGE_DELIVERY_TIME, PR_CLIENT_SUBMIT_TIME, PR_MESSAGE_CLASS, PR_SENDER_NAME, PR_SENDER_EMAIL_ADDRESS, PR_SUBJECT_PREFIX, PR_RECEIVED_BY_NAME, PR_INTERNET_MESSAGE_ID], $restrict);
 		foreach ($certs as $cert) {
 			$item = [];
-			$item['entryid'] = bin2hex($cert[PR_ENTRYID]);
+			$item['entryid'] = bin2hex((string) $cert[PR_ENTRYID]);
 			$item['email'] = $cert[PR_SUBJECT];
 			$item['validto'] = $cert[PR_MESSAGE_DELIVERY_TIME];
 			$item['validfrom'] = $cert[PR_CLIENT_SUBMIT_TIME];
@@ -226,7 +231,7 @@ class PluginSmimeModule extends Module {
 			$item['issued_to'] = $cert[PR_SUBJECT_PREFIX];
 			$item['fingerprint_sha1'] = $cert[PR_RECEIVED_BY_NAME];
 			$item['fingerprint_md5'] = $cert[PR_INTERNET_MESSAGE_ID];
-			$item['type'] = strtolower($cert[PR_MESSAGE_CLASS]) == 'webapp.security.public' ? 'public' : 'private';
+			$item['type'] = strtolower((string) $cert[PR_MESSAGE_CLASS]) == 'webapp.security.public' ? 'public' : 'private';
 			array_push($items, ['props' => $item]);
 		}
 		$data['page']['start'] = 0;
@@ -263,7 +268,7 @@ class PluginSmimeModule extends Module {
 		}
 		$privateCert = mapi_msgstore_openentry($this->store, $mapiCert[PR_ENTRYID]);
 
-		$msgBody = base64_encode($cert);
+		$msgBody = base64_encode((string) $cert);
 		$stream = mapi_openproperty($privateCert, PR_BODY, IID_IStream, 0, MAPI_CREATE | MAPI_MODIFY);
 		mapi_stream_setsize($stream, strlen($msgBody));
 		mapi_stream_write($stream, $msgBody);
@@ -276,15 +281,14 @@ class PluginSmimeModule extends Module {
 	/**
 	 * Generate a new  PKCS#12 certificate store file with a new passphrase.
 	 *
-	 * @param array  $certs          the original certificate
-	 * @param string $passphrase     the passphrase
-	 * @param mixed  $new_passphrase
+	 * @param array $certs          the original certificate
+	 * @param mixed $new_passphrase
 	 *
 	 * @return mixed boolean or string certificate
 	 */
 	public function pkcs12_change_passphrase($certs, $new_passphrase) {
 		$cert = "";
-		$extracerts = isset($certs['extracerts']) ? $certs['extracerts'] : [];
+		$extracerts = $certs['extracerts'] ?? [];
 		if (openssl_pkcs12_export($certs['cert'], $cert, $certs['pkey'], $new_passphrase, ['extracerts' => $extracerts])) {
 			return $cert;
 		}
