@@ -236,7 +236,7 @@ class Pluginsmime extends Plugin {
 					file_put_contents($tmpUserCert, $userCert);
 				}
 			}
-			catch (MAPIException $e) {
+			catch (MAPIException) {
 				$msg = "[smime] Unable to open PR_SENT_REPRESENTING_ENTRYID. Maybe %s was does not exists or deleted from server.";
 				Log::write(LOGLEVEL_ERROR, sprintf($msg, $userProps[PR_SENT_REPRESENTING_NAME]));
 				error_log("[smime] Unable to open PR_SENT_REPRESENTING_NAME: " . print_r($userProps[PR_SENT_REPRESENTING_NAME], true));
@@ -268,7 +268,7 @@ class Pluginsmime extends Plugin {
 					$searchKeys = mapi_getprops($message, [PR_SEARCH_KEY, PR_SENT_REPRESENTING_SEARCH_KEY]);
 					$searchKey = $searchKeys[PR_SEARCH_KEY] ?? $searchKeys[PR_SENT_REPRESENTING_SEARCH_KEY];
 					if ($searchKey) {
-						$sk = strtolower(explode(':', $searchKey)[1]);
+						$sk = strtolower(explode(':', (string) $searchKey)[1]);
 						$emailAddr = trim($sk);
 					}
 				}
@@ -292,7 +292,7 @@ class Pluginsmime extends Plugin {
 		if (count($userCerts) > 0) {
 			// Try to verify a certificate in the MAPI store
 			foreach ($userCerts as $userCert) {
-				$userCert = base64_decode($userCert);
+				$userCert = base64_decode((string) $userCert);
 				// Save signed message in a random file
 				$tmpfname = tempnam(sys_get_temp_dir(), true);
 				file_put_contents($tmpfname, $eml);
@@ -386,13 +386,12 @@ class Pluginsmime extends Plugin {
 		unlink($tmpUserCert);
 	}
 
-	function join_xph(&$prop, $msg)
-	{
+	public function join_xph(&$prop, $msg) {
 		$a = mapi_getprops($msg, [PR_TRANSPORT_MESSAGE_HEADERS]);
 		$a = $a === false ? "" : ($a[PR_TRANSPORT_MESSAGE_HEADERS] ?? "");
 		$prop[PR_TRANSPORT_MESSAGE_HEADERS] =
-			"# Outer headers:\n".($prop[PR_TRANSPORT_MESSAGE_HEADERS] ?? "").
-			"# Inner headers:\n".$a;
+			"# Outer headers:\n" . ($prop[PR_TRANSPORT_MESSAGE_HEADERS] ?? "") .
+			"# Inner headers:\n" . $a;
 	}
 
 	/**
@@ -417,7 +416,7 @@ class Pluginsmime extends Plugin {
 		fwrite($fp, "Content-Type: application/pkcs7-mime; name=\"smime.p7m\"; smime-type=enveloped-data\n");
 		fwrite($fp, "Content-Transfer-Encoding: base64\nContent-Disposition: attachment; filename=\"smime.p7m\"\n");
 		fwrite($fp, "Content-Description: S/MIME Encrypted Message\n\n");
-		fwrite($fp, chunk_split(base64_encode($data['data']), 72) . "\n");
+		fwrite($fp, chunk_split(base64_encode((string) $data['data']), 72) . "\n");
 		fclose($fp);
 		if (isset($pass) && !empty($pass)) {
 			$certs = readPrivateCert($this->getStore(), $pass, false);
@@ -444,7 +443,7 @@ class Pluginsmime extends Plugin {
 			$content = file_get_contents($tmpDecrypted);
 			// Handle OL empty body Outlook Signed & Encrypted mails.
 			// The S/MIME plugin has to extract the body from the signed message.
-			if (strpos($content, 'signed-data') !== false) {
+			if (str_contains($content, 'signed-data')) {
 				$this->message['type'] = 'encryptsigned';
 				$olcert = tempnam(sys_get_temp_dir(), true);
 				$olmsg = tempnam(sys_get_temp_dir(), true);
@@ -467,7 +466,7 @@ class Pluginsmime extends Plugin {
 
 			// mapi_inetmapi_imtomapi removes the PR_MESSAGE_CLASS = 'IPM.Note.SMIME.MultipartSigned'
 			// So we need to check if the message was also signed by looking at the MIME_TAG in the eml
-			if (strpos($content, 'multipart/signed') !== false || strpos($content, 'signed-data') !== false) {
+			if (str_contains($content, 'multipart/signed') || str_contains($content, 'signed-data')) {
 				$this->message['type'] = 'encryptsigned';
 				$this->verifyMessage($data['message'], $content);
 			}
@@ -596,7 +595,7 @@ class Pluginsmime extends Plugin {
 
 		$certificate = file_get_contents($tmpname);
 		$emailAddress = $GLOBALS['mapisession']->getSMTPAddress();
-		list($message, $publickey, $publickeyData, $imported) = validateUploadedPKCS($certificate, $passphrase, $emailAddress);
+		[$message, $publickey, $publickeyData, $imported] = validateUploadedPKCS($certificate, $passphrase, $emailAddress);
 
 		// All checks completed successful
 		// Store private cert in users associated store (check for duplicates)
@@ -666,8 +665,8 @@ class Pluginsmime extends Plugin {
 		if (!isset($messageClass)) {
 			return;
 		}
-		if (stripos($messageClass, 'IPM.Note.deferSMIME') === false &&
-			stripos($messageClass, 'IPM.Note.SMIME') === false) {
+		if (stripos((string) $messageClass, 'IPM.Note.deferSMIME') === false &&
+			stripos((string) $messageClass, 'IPM.Note.SMIME') === false) {
 			return;
 		}
 
@@ -988,10 +987,9 @@ class Pluginsmime extends Plugin {
 		return !empty($rows);
 	}
 
-	public function clear_openssl_error()
-	{
+	public function clear_openssl_error() {
 		while (@openssl_error_string() !== false)
-			/* nothing */;
+		/* nothing */;
 	}
 
 	/**
@@ -1003,11 +1001,14 @@ class Pluginsmime extends Plugin {
 	 */
 	public function extract_openssl_error() {
 		$this->openssl_error = "";
-		while (($s = @openssl_error_string()) !== false)
-			if (strlen($this->openssl_error) == 0)
+		while (($s = @openssl_error_string()) !== false) {
+			if (strlen($this->openssl_error) == 0) {
 				$this->openssl_error = $s;
-			else
-				$this->openssl_error .= "\n".$s;
+			}
+			else {
+				$this->openssl_error .= "\n" . $s;
+			}
+		}
 		$openssl_error_code = 0;
 		if ($this->openssl_error) {
 			$openssl_error_list = explode(":", $this->openssl_error);
@@ -1188,7 +1189,7 @@ class Pluginsmime extends Plugin {
 		}
 
 		$messageProps = mapi_getprops($mapiMessage, [PR_SENT_REPRESENTING_ENTRYID, PR_SENDER_ENTRYID]);
-		$senderEntryID = isset($messageProps[PR_SENT_REPRESENTING_ENTRYID]) ? $messageProps[PR_SENT_REPRESENTING_ENTRYID] : $messageProps[PR_SENDER_ENTRYID];
+		$senderEntryID = $messageProps[PR_SENT_REPRESENTING_ENTRYID] ?? $messageProps[PR_SENDER_ENTRYID];
 
 		try {
 			$senderUser = mapi_ab_openentry($GLOBALS["mapisession"]->getAddressbook(), $senderEntryID);
@@ -1196,7 +1197,7 @@ class Pluginsmime extends Plugin {
 				$userprops = mapi_getprops($senderUser, [PR_ADDRTYPE, PR_DISPLAY_NAME, PR_EMAIL_ADDRESS, PR_SMTP_ADDRESS, PR_OBJECT_TYPE, PR_RECIPIENT_TYPE, PR_DISPLAY_TYPE, PR_DISPLAY_TYPE_EX, PR_ENTRYID]);
 
 				$senderStructure = [];
-				$senderStructure["props"]['entryid'] = isset($userprops[PR_ENTRYID]) ? bin2hex($userprops[PR_ENTRYID]) : '';
+				$senderStructure["props"]['entryid'] = isset($userprops[PR_ENTRYID]) ? bin2hex((string) $userprops[PR_ENTRYID]) : '';
 				$senderStructure["props"]['display_name'] = $userprops[PR_DISPLAY_NAME] ?? '';
 				$senderStructure["props"]['email_address'] = $userprops[PR_EMAIL_ADDRESS] ?? '';
 				$senderStructure["props"]['smtp_address'] = $userprops[PR_SMTP_ADDRESS] ?? '';
