@@ -6,13 +6,10 @@
  */
 class ConfigCheck {
 	public $result;
-	public $haltOnError;
 	public $siteconfig;
 	public $phpini;
 
-	public function __construct($haltOnError = true) {
-		$this->haltOnError = $haltOnError;
-
+	public function __construct(public $haltOnError = true) {
 		$this->result = true;
 
 		// here we check our settings, changes to the config and
@@ -26,8 +23,7 @@ class ConfigCheck {
 
 		# Replicate value logic from php-src/ext/zlib/zlib.c
 		$sv = ini_get("zlib.output_compression");
-		$sv = strcasecmp($sv, "on") == 0 ? 1 :
-			  (strcasecmp($sv, "off") == 0 ? 0 : intval($sv));
+		$sv = strcasecmp($sv, "on") == 0 ? 1 : (strcasecmp($sv, "off") == 0 ? 0 : intval($sv));
 		if ($sv != 0) {
 			$this->error_config("zlib.output_compression", "off", "With this option enabled, it could occur that XMLHTTP requests will fail");
 		}
@@ -61,7 +57,7 @@ class ConfigCheck {
 			?>
 				<p style="font-weight: bold;">grommunio Web can't start because of incompatible configuration.</p>
 				<p>Please correct above errors, a good start is by checking your '<tt><?php echo $this->get_php_ini(); ?></tt>' file.</p>
-				<p>You can disable this configuration check by editing the file '<tt><?php echo dirname($_SERVER["SCRIPT_FILENAME"]); ?>/config.php</tt>', but this is not recommended.</p>
+				<p>You can disable this configuration check by editing the file '<tt><?php echo dirname((string) $_SERVER["SCRIPT_FILENAME"]); ?>/config.php</tt>', but this is not recommended.</p>
 			<?php
 			exit;
 		}
@@ -79,7 +75,7 @@ class ConfigCheck {
 			printf("<div style=\"color: #f00;\">%s</div><div style=\"font-size: smaller; margin-left: 20px;\">%s</div>\n", $string, $help);
 		}
 		else {
-			trigger_error(strip_tags($string), E_USER_NOTICE);
+			trigger_error(strip_tags((string) $string), E_USER_NOTICE);
 		}
 		$this->result = false;
 	}
@@ -260,7 +256,7 @@ class ConfigCheck {
 	public function checkPHPsetting($setting, $value_needed, $help_msg = "") {
 		$result = true;
 		$inival = ini_get($setting);
-		if (strcmp($inival, $value_needed) != 0) {
+		if (strcmp($inival, (string) $value_needed) != 0) {
 			$this->error_config($setting, $value_needed, $help_msg . " (Current value: \"{$inival}\")");
 			$result = false;
 		}
@@ -280,22 +276,11 @@ class ConfigCheck {
 		$result = true;
 
 		// convert $value_needed
-		switch ($value_needed) {
-			case "on":
-			case "yes":
-			case "true":
-				$value = 1;
-				break;
-
-			case "off":
-			case "no":
-			case "false":
-				$value = 0;
-				break;
-
-			default:
-				$value = $value_needed;
-		}
+		$value = match ($value_needed) {
+			"on", "yes", "true" => 1,
+			"off", "no", "false" => 0,
+			default => $value_needed,
+		};
 
 		if (ini_get($setting) != $value) {
 			$this->error_security($setting, $value_needed, $help_msg);
@@ -327,14 +312,14 @@ class ConfigCheck {
 		}
 
 		if (is_dir($dir)) {
-			$states = strtolower($states);
-			if (strpos($states, "r") !== false) {
+			$states = strtolower((string) $states);
+			if (str_contains($states, "r")) {
 				if (!is_readable($dir)) {
 					$this->error_directory($dir, "isn't readable", $help_msg);
 					$result = false;
 				}
 			}
-			if (strpos($states, "w") !== false) {
+			if (str_contains($states, "w")) {
 				if (!is_writable($dir)) {
 					$this->error_directory($dir, "isn't writable", $help_msg);
 					$result = false;
