@@ -29,6 +29,7 @@ class IndexSqlite extends SQLite3 {
 		$this->username = $username ?? $GLOBALS["mapisession"]->getSMTPAddress();
 		$this->session = $session ?? $GLOBALS["mapisession"]->getSession();
 		$this->store = $store ?? $GLOBALS["mapisession"]->getDefaultMessageStore();
+
 		try {
 			$this->open(SQLITE_INDEX_PATH . '/' . $this->username . '/index.sqlite3', SQLITE3_OPEN_READONLY);
 			$this->openResult = 0;
@@ -58,13 +59,14 @@ class IndexSqlite extends SQLite3 {
 			// abort if the entryid is not available
 			else {
 				error_log(sprintf("No entryid available, not possible to link the message %d.", $row['message_id']));
+
 				return;
 			}
 		}
 		if (isset($message_classes)) {
 			$found = false;
 			foreach ($message_classes as $message_class) {
-				if (strncasecmp($row['message_class'], $message_class, strlen($message_class)) == 0) {
+				if (strncasecmp((string) $row['message_class'], (string) $message_class, strlen((string) $message_class)) == 0) {
 					$found = true;
 					break;
 				}
@@ -89,7 +91,7 @@ class IndexSqlite extends SQLite3 {
 		try {
 			mapi_linkmessage($this->session, $search_entryid, $row['entryid']);
 		}
-		catch (Exception $e) {
+		catch (Exception) {
 			return;
 		}
 		++$this->count;
@@ -160,7 +162,7 @@ class IndexSqlite extends SQLite3 {
 		else {
 			$first = true;
 			foreach ($search_patterns as $key => $search_pattern) {
-				switch($key) {
+				switch ($key) {
 					case 'message_classes':
 					case 'date_start':
 					case 'date_end':
@@ -168,6 +170,7 @@ class IndexSqlite extends SQLite3 {
 					case 'has_attachments':
 					case 'categories':
 						break;
+
 					default:
 						if (!is_null($search_pattern)) {
 							if ($first === true) {
@@ -208,7 +211,7 @@ class IndexSqlite extends SQLite3 {
 	}
 
 	private function quote_words($search_string) {
-		return '"' . preg_replace("/(\\s+)/", '*" "', trim($search_string)) . '"*';
+		return '"' . preg_replace("/(\\s+)/", '*" "', trim((string) $search_string)) . '"*';
 	}
 
 	/**
