@@ -74,7 +74,7 @@ class Language {
 		if (isset($GLOBALS['translations'])) {
 			return;
 		}
-		$lang = (empty($lang) || substr($lang, 0, 1) == '.' || $lang == "C") ? LANG : $lang; // default language fix
+		$lang = (empty($lang) || str_starts_with($lang, '.') || $lang == "C") ? LANG : $lang; // default language fix
 
 		if ($this->is_language($lang)) {
 			$this->lang = $lang;
@@ -205,6 +205,7 @@ class Language {
 			if (empty($translations)) {
 				@shm_remove_var($memid, 0);
 				@shm_detach($memid);
+
 				return ['grommunio_web' => []];
 			}
 			@shm_detach($memid);
@@ -213,8 +214,10 @@ class Language {
 		}
 		$handle = opendir(LANGUAGE_DIR);
 		if ($handle == false) {
-			if ($memid)
+			if ($memid) {
 				@shm_detach($memid);
+			}
+
 			return ['grommunio_web' => []];
 		}
 		$last_id = 1;
@@ -240,8 +243,9 @@ class Language {
 				}
 			}
 			$cache_table[$entry] = $last_id;
-			if ($memid)
+			if ($memid) {
 				@shm_put_var($memid, $last_id, $translations);
+			}
 			if (strcmp($entry, $this->getSelected()) == 0) {
 				$ret_val = $translations;
 			}
@@ -395,14 +399,14 @@ class Language {
 				$translation_data[$i]['msgid'] = $orig_str['str'];	// unpack converts to array :S
 
 				// Find context in the original string
-				if (strpos($translation_data[$i]['msgid'], "\004") !== false) {
-					$contextSplit = explode("\004", $translation_data[$i]['msgid']);
+				if (str_contains((string) $translation_data[$i]['msgid'], "\004")) {
+					$contextSplit = explode("\004", (string) $translation_data[$i]['msgid']);
 					$translation_data[$i]['msgctxt'] = $contextSplit[0];
 					$translation_data[$i]['msgid'] = $contextSplit[1];
 				}
 				// Find plural forms in the original string
-				if (strpos($translation_data[$i]['msgid'], "\0") !== false) {
-					$original = explode("\0", $translation_data[$i]['msgid']);
+				if (str_contains((string) $translation_data[$i]['msgid'], "\0")) {
+					$original = explode("\0", (string) $translation_data[$i]['msgid']);
 					$translation_data[$i]['msgid'] = $original[0];
 					$translation_data[$i]['msgid_plural'] = $original[1];
 				}
@@ -428,7 +432,7 @@ class Language {
 				// have only one plural form won't have this
 				// (e.g. Japanese)
 				if ($translation_data[$i]['msgid_plural'] !== false) {
-					$translation_data[$i]['msgstr'] = explode("\0", $translation_data[$i]['msgstr']);
+					$translation_data[$i]['msgstr'] = explode("\0", (string) $translation_data[$i]['msgstr']);
 				}
 			}
 			else {
