@@ -49,7 +49,7 @@ class Theming {
 				continue;
 			}
 
-			$themes[$info->getFileName()] = isset($themeProps['display-name']) ? $themeProps['display-name'] : $info->getFileName();
+			$themes[$info->getFileName()] = $themeProps['display-name'] ?? $info->getFileName();
 		}
 
 		return $themes;
@@ -112,7 +112,7 @@ class Theming {
 	 * @param string $theme the name of the theme for which the css will be returned.
 	 *                      Note: This is the directory name of the theme plugin.
 	 *
-	 * 	 * @return String|Boolean
+	 * 	 * @return bool|string
 	 */
 	public static function getFavicon($theme) {
 		$themePath = constant('THEME_PATH_' . DEBUG_LOADER);
@@ -166,8 +166,8 @@ class Theming {
 			$iterator->rewind();
 			while ($iterator->valid()) {
 				$fileName = $iterator->getFilename();
-				if (!$iterator->isDir() && (strtolower($iterator->getExtension()) === 'css' || substr($fileName, -8) === '.css.php')) {
-					$cssFiles[] = substr($iterator->key(), strlen(BASE_PATH));
+				if (!$iterator->isDir() && (strtolower($iterator->getExtension()) === 'css' || str_ends_with($fileName, '.css.php'))) {
+					$cssFiles[] = substr((string) $iterator->key(), strlen(BASE_PATH));
 				}
 				$iterator->next();
 			}
@@ -215,7 +215,7 @@ class Theming {
 	public static function getPrimaryIconColor() {
 		$val = Theming::getThemeProperty('icons-primary-color');
 
-		return $val !== null ? $val : false;
+		return $val ?? false;
 	}
 
 	/**
@@ -230,7 +230,7 @@ class Theming {
 	public static function getSecondaryIconColor() {
 		$val = Theming::getThemeProperty('icons-secondary-color');
 
-		return $val !== null ? $val : false;
+		return $val ?? false;
 	}
 
 	/**
@@ -358,7 +358,7 @@ class Theming {
 
 		if ($themeProps['primary-color']) {
 			if (!$themeProps['primary-color:hover']) {
-				list(, , $l) = Colors::rgb2hsl(Colors::colorString2Object($themeProps['primary-color']));
+				[, , $l] = Colors::rgb2hsl(Colors::colorString2Object($themeProps['primary-color']));
 				if ($l > 20) {
 					$themeProps['primary-color:hover'] = Colors::darker($themeProps['primary-color'], 10);
 				}
@@ -411,7 +411,7 @@ class Theming {
 		$styles = '<style>';
 		foreach ($themeProps as $k => $v) {
 			if ($v && isset(Theming::$styles[$k])) {
-				$styles .= str_replace("{{{$k}}}", htmlspecialchars($v), Theming::$styles[$k]);
+				$styles .= str_replace("{{{$k}}}", htmlspecialchars((string) $v), Theming::$styles[$k]);
 			}
 		}
 		$styles .= '</style>' . "\n";
@@ -430,7 +430,7 @@ class Theming {
 					if (empty($stylesheet)) {
 						continue;
 					}
-					$styles .= "\t\t" . '<link rel="stylesheet" type="text/css" href="' . htmlspecialchars(Theming::fixUrl($stylesheet, $theme)) . '" />' . "\n";
+					$styles .= "\t\t" . '<link rel="stylesheet" type="text/css" href="' . htmlspecialchars((string) Theming::fixUrl($stylesheet, $theme)) . '" />' . "\n";
 				}
 			}
 		}
