@@ -1,4 +1,5 @@
 <?php
+
 /**
  * DownloadBase.
  *
@@ -68,7 +69,7 @@ abstract class DownloadBase {
 		}
 
 		if ($this->storeId) {
-			$this->store = $GLOBALS['mapisession']->openMessageStore(hex2bin($this->storeId));
+			$this->store = $GLOBALS['mapisession']->openMessageStore(hex2bin((string) $this->storeId));
 		}
 
 		if ($this->allAsZip) {
@@ -79,7 +80,7 @@ abstract class DownloadBase {
 		else {
 			if (isset($data['entryid'])) {
 				$this->entryId = sanitizeValue($data['entryid'], '', ID_REGEX);
-				$this->message = mapi_msgstore_openentry($this->store, hex2bin($this->entryId));
+				$this->message = mapi_msgstore_openentry($this->store, hex2bin((string) $this->entryId));
 			}
 		}
 	}
@@ -155,36 +156,15 @@ abstract class DownloadBase {
 		$messageClass = '';
 
 		// Convert message class into human readable format, so user can easily understand the display message.
-		switch ($this->getTrimmedMessageClass($mapiMessageClass)) {
-			case 'Appointment':
-				$messageClass = _('Appointment');
-				break;
-
-			case 'StickyNote':
-				$messageClass = _('Sticky Note');
-				break;
-
-			case 'Contact':
-				$messageClass = _('Contact');
-				break;
-
-			case 'DistList':
-				$messageClass = _('Distribution list');
-				break;
-
-			case 'Task':
-				$messageClass = _('Task');
-				break;
-
-			case 'TaskRequest':
-				$messageClass = _('Task Request');
-				break;
-
-			default:
-				$messageClass = $mapiMessageClass;
-		}
-
-		return $messageClass;
+		return match ($this->getTrimmedMessageClass($mapiMessageClass)) {
+			'Appointment' => _('Appointment'),
+			'StickyNote' => _('Sticky Note'),
+			'Contact' => _('Contact'),
+			'DistList' => _('Distribution list'),
+			'Task' => _('Task'),
+			'TaskRequest' => _('Task Request'),
+			default => $mapiMessageClass,
+		};
 	}
 
 	/**
