@@ -192,7 +192,7 @@ class FileLoader {
 	 */
 	public function printFiles($files, $template = '{file}', $base = false, $concatVersion = true) {
 		foreach ($files as $file) {
-			$file = $base === true ? basename($file) : $file;
+			$file = $base === true ? basename((string) $file) : $file;
 			if ($concatVersion) {
 				$file = $file . "?version=" . $this->getVersion();
 			}
@@ -273,7 +273,7 @@ class FileLoader {
 		while (($file = readdir($dir)) !== false) {
 			$filepath = $path . '/' . $file;
 			// Skip entries like ".", ".." and ".svn"
-			if (substr($file, 0, 1) != "." && !in_array($filepath, $excludeFiles)) {
+			if (!str_starts_with($file, ".") && !in_array($filepath, $excludeFiles)) {
 				// Make sure we have files to include
 				$info = pathinfo($filepath, PATHINFO_EXTENSION);
 
@@ -350,10 +350,10 @@ class FileLoader {
 			preg_match_all('(@extends\W([^\n\r]*))', $content, $extends);
 			preg_match_all('(@class\W([^\n\r]*))', $content, $class);
 			preg_match_all('(#dependsFile\W([^\n\r\*]+))', $content, $dependsFile);
-			$core = (strpos($content, '#core') !== false) ? true : false;
+			$core = (str_contains($content, '#core')) ? true : false;
 
 			for ($j = 0, $lenJ = count($coreFiles); $j < $lenJ; ++$j) {
-				if (strpos($filename, $coreFiles[$j]) === 0) {
+				if (str_starts_with((string) $filename, (string) $coreFiles[$j])) {
 					$core = true;
 					break;
 				}
@@ -379,7 +379,7 @@ class FileLoader {
 			// First get the extended class dependencies. We also have to convert them into files names using the $classFileLookup.
 			for ($i = 0, $len = count($fileData['extends']); $i < $len; ++$i) {
 				// The check if it extends the Zarafa namespace is needed because we do not index other namespaces.
-				if (substr($fileData['extends'][$i], 0, strlen('Zarafa')) == 'Zarafa') {
+				if (str_starts_with($fileData['extends'][$i], 'Zarafa')) {
 					if (isset($libFileLookup[$fileData['extends'][$i]])) {
 						// The @extends is found in the library file.
 						// No need to update the dependencies
@@ -564,7 +564,7 @@ class FileLoader {
 			ob_start();
 		}
 
-		list($extjsFiles, $webappFiles, $pluginFiles, $remoteFiles) = $this->getJsFiles();
+		[$extjsFiles, $webappFiles, $pluginFiles, $remoteFiles] = $this->getJsFiles();
 
 		$jsTemplate = "\t\t<script src=\"{file}\"></script>";
 		$this->printFiles($extjsFiles, $jsTemplate);
@@ -623,7 +623,7 @@ class FileLoader {
 	 * return boolean False if cache is outdated
 	 */
 	private function cacheExists() {
-		list($extjsFiles, $webappFiles, $pluginFiles, $remoteFiles) = $this->getJsFiles();
+		[$extjsFiles, $webappFiles, $pluginFiles, $remoteFiles] = $this->getJsFiles();
 		$files = [$extjsFiles, $webappFiles, $pluginFiles, $remoteFiles];
 		$md5 = md5(json_encode($files));
 
