@@ -29,6 +29,7 @@ class AddressbookItemModule extends ItemModule {
 	 * @param string $entryid entryid of the message
 	 * @param array  $action  the action data, sent by the client
 	 */
+	#[Override]
 	public function open($store, $entryid, $action) {
 		if ($entryid) {
 			$data = [];
@@ -49,6 +50,7 @@ class AddressbookItemModule extends ItemModule {
 						// unwrap ab entry id
 						$entryid = substr($entryid, 28);
 					}
+
 					try {
 						$contactItem = $GLOBALS['operations']->openMessage($GLOBALS['mapisession']->getDefaultMessageStore(), $entryid);
 					}
@@ -56,7 +58,7 @@ class AddressbookItemModule extends ItemModule {
 						if (!empty($action['store_entryid'])) {
 							$e->setHandled();
 							$me->setHandled();
-							$userStore = $GLOBALS['mapisession']->openMessageStore(hex2bin($action['store_entryid']));
+							$userStore = $GLOBALS['mapisession']->openMessageStore(hex2bin((string) $action['store_entryid']));
 							$contactItem = $GLOBALS['operations']->openMessage($userStore, $entryid);
 						}
 					}
