@@ -27,6 +27,7 @@ class AddressbookListModule extends ListModule {
 	/**
 	 * Executes all the actions in the $data variable.
 	 */
+	#[Override]
 	public function execute() {
 		foreach ($this->data as $actionType => $action) {
 			if (isset($actionType)) {
@@ -39,25 +40,14 @@ class AddressbookListModule extends ListModule {
 						$subActionType = $action['subActionType'];
 					}
 
-					switch ($actionType) {
-						case 'list':
-							switch ($subActionType) {
-								case 'hierarchy':
-									$this->getHierarchy($action);
-									break;
-
-								case 'globaladdressbook':
-									$this->GABUsers($action, $subActionType);
-									break;
-
-								default:
-									$this->handleUnknownActionType($actionType);
-							}
-							break;
-
-						default:
-							$this->handleUnknownActionType($actionType);
-					}
+					match ($actionType) {
+						'list' => match ($subActionType) {
+							'hierarchy' => $this->getHierarchy($action),
+							'globaladdressbook' => $this->GABUsers($action, $subActionType),
+							default => $this->handleUnknownActionType($actionType),
+						},
+						default => $this->handleUnknownActionType($actionType),
+					};
 				}
 				catch (MAPIException $e) {
 					$this->processException($e, $actionType, $store, $parententryid, $entryid, $action);
@@ -93,9 +83,11 @@ class AddressbookListModule extends ListModule {
 		if (($folderType !== 'gab' || ENABLE_FULL_GAB) || !empty($searchstring)) {
 			$table = null;
 			$ab = $GLOBALS['mapisession']->getAddressbook(false, true);
-			$entryid = !empty($action['entryid']) ? hex2bin($action['entryid']) : mapi_ab_getdefaultdir($ab);
+			$entryid = !empty($action['entryid']) ? hex2bin((string) $action['entryid']) : mapi_ab_getdefaultdir($ab);
+
 			try {
 				$dir = mapi_ab_openentry($ab, $entryid);
+
 				/**
 				 * @TODO: 'All Address Lists' on IABContainer gives MAPI_E_INVALID_PARAMETER,
 				 * as it contains subfolders only. When #7344 is fixed, MAPI will return error here,
@@ -103,12 +95,13 @@ class AddressbookListModule extends ListModule {
 				 */
 				$table = mapi_folder_getcontentstable($dir, MAPI_DEFERRED_ERRORS);
 			}
-			catch (MAPIException $e) {
+			catch (MAPIException) {
 				// for the shared and public contact folders open the store
 				// and get the contents of the folder
 				if ($isSharedFolder) {
 					$sharedStore = $GLOBALS["mapisession"]->openMessageStore(
-						hex2bin($action["sharedFolder"]["store_entryid"]));
+						hex2bin((string) $action["sharedFolder"]["store_entryid"])
+					);
 					$sharedContactsFolder = mapi_msgstore_openentry($sharedStore, $entryid);
 					$table = mapi_folder_getcontentstable($sharedContactsFolder, MAPI_DEFERRED_ERRORS);
 					$this->properties = $GLOBALS['properties']->getContactProperties();
@@ -143,33 +136,28 @@ class AddressbookListModule extends ListModule {
 					$user_data = array_shift($rows);
 					$abprovidertype = 0;
 					$item = [];
-					$entryid = bin2hex($user_data[$this->properties['entryid']]);
+					$entryid = bin2hex((string) $user_data[$this->properties['entryid']]);
 					$item['entryid'] = $entryid;
-					$item['display_name'] = isset($user_data[$this->properties['display_name']]) ? $user_data[$this->properties['display_name']] : "";
-					$item['object_type'] = isset($user_data[$this->properties['object_type']]) ? $user_data[$this->properties['object_type']] : "";
-					$item['display_type'] = isset($user_data[PR_DISPLAY_TYPE]) ? $user_data[PR_DISPLAY_TYPE] : "";
-					$item['title'] = isset($user_data[PR_TITLE]) ? $user_data[PR_TITLE] : "";
-					$item['company_name'] = isset($user_data[PR_COMPANY_NAME]) ? $user_data[PR_COMPANY_NAME] : "";
+					$item['display_name'] = $user_data[$this->properties['display_name']] ?? "";
+					$item['object_type'] = $user_data[$this->properties['object_type']] ?? "";
+					$item['display_type'] = $user_data[PR_DISPLAY_TYPE] ?? "";
+					$item['title'] = $user_data[PR_TITLE] ?? "";
+					$item['company_name'] = $user_data[PR_COMPANY_NAME] ?? "";
 
 					// Test whether the GUID in the entryid is from the Contact Provider
-					if ($GLOBALS['entryid']->hasContactProviderGUID(bin2hex($user_data[$this->properties['entryid']]))) {
+					if ($GLOBALS['entryid']->hasContactProviderGUID(bin2hex((string) $user_data[$this->properties['entryid']]))) {
 						// Use the original_display_name property to fill in the fileas column
 						$item['fileas'] = $user_data[$this->properties['original_display_name']] ?? $item['display_name'];
-						$item['address_type'] = isset($user_data[$this->properties['address_type']]) ? $user_data[$this->properties['address_type']] : 'SMTP';
+						$item['address_type'] = $user_data[$this->properties['address_type']] ?? 'SMTP';
 						// necessary to display the proper icon
 						if ($item['address_type'] === 'MAPIPDL') {
 							$item['display_type_ex'] = DTE_FLAG_ACL_CAPABLE | DT_MAILUSER | DT_DISTLIST;
 						}
 
-						switch ($user_data[PR_DISPLAY_TYPE]) {
-							case DT_PRIVATE_DISTLIST:
-								$item['email_address'] = '';
-								break;
-
-							case DT_MAILUSER:
-							default:
-								$item['email_address'] = $user_data[$this->properties['email_address']];
-						}
+						$item['email_address'] = match ($user_data[PR_DISPLAY_TYPE]) {
+							DT_PRIVATE_DISTLIST => '',
+							default => $user_data[$this->properties['email_address']],
+						};
 					}
 					elseif ($isSharedFolder && $sharedStore) {
 						// do not display private items
@@ -178,7 +166,7 @@ class AddressbookListModule extends ListModule {
 						}
 						// do not display items without an email address
 						// a shared contact is either a single contact item or a distribution list
-						$isContact = strcasecmp($user_data[$this->properties['message_class']], 'IPM.Contact') === 0;
+						$isContact = strcasecmp((string) $user_data[$this->properties['message_class']], 'IPM.Contact') === 0;
 						if ($isContact &&
 							empty($user_data[$this->properties["email_address_1"]]) &&
 							empty($user_data[$this->properties["email_address_2"]]) &&
@@ -188,8 +176,8 @@ class AddressbookListModule extends ListModule {
 						$item['display_type_ex'] = $isContact ? DT_MAILUSER : DT_MAILUSER | DT_PRIVATE_DISTLIST;
 						$item['display_type'] = $isContact ? DT_MAILUSER : DT_DISTLIST;
 						$item['fileas'] = $item['display_name'];
-						$item['surname'] = isset($user_data[PR_SURNAME]) ? $user_data[PR_SURNAME] : '';
-						$item['given_name'] = isset($user_data[$this->properties['given_name']]) ? $user_data[$this->properties['given_name']] : '';
+						$item['surname'] = $user_data[PR_SURNAME] ?? '';
+						$item['given_name'] = $user_data[$this->properties['given_name']] ?? '';
 						$item['object_type'] = $user_data[PR_ICON_INDEX] == 512 ? MAPI_MAILUSER : MAPI_DISTLIST;
 						$item['store_entryid'] = $action["sharedFolder"]["store_entryid"];
 						$item['is_shared'] = true;
@@ -202,6 +190,7 @@ class AddressbookListModule extends ListModule {
 						if (!empty($user_data[$this->properties["email_address_type_3"]])) {
 							$abprovidertype |= 4;
 						}
+
 						switch ($abprovidertype) {
 							case 1:
 							case 3:
@@ -211,12 +200,14 @@ class AddressbookListModule extends ListModule {
 								$item['address_type'] = $user_data[$this->properties["email_address_type_1"]];
 								$item['email_address'] = $user_data[$this->properties["email_address_1"]];
 								break;
+
 							case 2:
 							case 6:
 								$item['entryid'] .= '02';
 								$item['address_type'] = $user_data[$this->properties["email_address_type_2"]];
 								$item['email_address'] = $user_data[$this->properties["email_address_2"]];
 								break;
+
 							case 4:
 								$item['entryid'] .= '03';
 								$item['address_type'] = $user_data[$this->properties["email_address_type_3"]];
@@ -226,13 +217,13 @@ class AddressbookListModule extends ListModule {
 					}
 					else {
 						// If display_type_ex is not set we can overwrite it with display_type
-						$item['display_type_ex'] = isset($user_data[PR_DISPLAY_TYPE_EX]) ? $user_data[PR_DISPLAY_TYPE_EX] : $user_data[PR_DISPLAY_TYPE];
+						$item['display_type_ex'] = $user_data[PR_DISPLAY_TYPE_EX] ?? $user_data[PR_DISPLAY_TYPE];
 						$item['fileas'] = $item['display_name'];
-						$item['mobile_telephone_number'] = isset($user_data[PR_MOBILE_TELEPHONE_NUMBER]) ? $user_data[PR_MOBILE_TELEPHONE_NUMBER] : '';
-						$item['home_telephone_number'] = isset($user_data[PR_HOME_TELEPHONE_NUMBER]) ? $user_data[PR_HOME_TELEPHONE_NUMBER] : '';
-						$item['pager_telephone_number'] = isset($user_data[PR_PAGER_TELEPHONE_NUMBER]) ? $user_data[PR_PAGER_TELEPHONE_NUMBER] : '';
-						$item['surname'] = isset($user_data[PR_SURNAME]) ? $user_data[PR_SURNAME] : '';
-						$item['given_name'] = isset($user_data[$this->properties['given_name']]) ? $user_data[$this->properties['given_name']] : '';
+						$item['mobile_telephone_number'] = $user_data[PR_MOBILE_TELEPHONE_NUMBER] ?? '';
+						$item['home_telephone_number'] = $user_data[PR_HOME_TELEPHONE_NUMBER] ?? '';
+						$item['pager_telephone_number'] = $user_data[PR_PAGER_TELEPHONE_NUMBER] ?? '';
+						$item['surname'] = $user_data[PR_SURNAME] ?? '';
+						$item['given_name'] = $user_data[$this->properties['given_name']] ?? '';
 
 						switch ($user_data[PR_DISPLAY_TYPE]) {
 							case DT_ORGANIZATION:
@@ -246,7 +237,7 @@ class AddressbookListModule extends ListModule {
 								// The account property is used to fill in the fileas column, private dislist does not have that
 								$item['fileas'] = $user_data[$this->properties['account']];
 
-							// no break
+								// no break
 							case DT_PRIVATE_DISTLIST:
 								$item['email_address'] = $user_data[$this->properties['email_address']] ?? $user_data[$this->properties['account']];
 								// FIXME: shouldn't be needed, but atm this gives us an undefined offset error which makes the unittests fail.
@@ -260,17 +251,17 @@ class AddressbookListModule extends ListModule {
 								// The account property is used to fill in the fileas column, remote mailuser does not have that
 								$item['fileas'] = $user_data[$this->properties['account']];
 
-							// no break
+								// no break
 							case DT_REMOTE_MAILUSER:
 							default:
 								$item['email_address'] = $user_data[$this->properties['email_address']];
 								$item['smtp_address'] = $user_data[$this->properties['smtp_address']];
 
-								$item['address_type'] = isset($user_data[$this->properties['address_type']]) ? $user_data[$this->properties['address_type']] : 'SMTP';
-								$item['department_name'] = isset($user_data[$this->properties['department_name']]) ? $user_data[$this->properties['department_name']] : '';
-								$item['office_telephone_number'] = isset($user_data[$this->properties['office_telephone_number']]) ? $user_data[$this->properties['office_telephone_number']] : '';
-								$item['office_location'] = isset($user_data[$this->properties['office_location']]) ? $user_data[$this->properties['office_location']] : '';
-								$item['primary_fax_number'] = isset($user_data[$this->properties['primary_fax_number']]) ? $user_data[$this->properties['primary_fax_number']] : '';
+								$item['address_type'] = $user_data[$this->properties['address_type']] ?? 'SMTP';
+								$item['department_name'] = $user_data[$this->properties['department_name']] ?? '';
+								$item['office_telephone_number'] = $user_data[$this->properties['office_telephone_number']] ?? '';
+								$item['office_location'] = $user_data[$this->properties['office_location']] ?? '';
+								$item['primary_fax_number'] = $user_data[$this->properties['primary_fax_number']] ?? '';
 								break;
 						}
 					}
@@ -296,7 +287,7 @@ class AddressbookListModule extends ListModule {
 					}
 
 					if (!empty($user_data[$this->properties['search_key']])) {
-						$item['search_key'] = bin2hex($user_data[$this->properties['search_key']]);
+						$item['search_key'] = bin2hex((string) $user_data[$this->properties['search_key']]);
 					}
 					else {
 						// contacts folders are not returning search keys, this should be fixed in Gromox
@@ -325,6 +316,7 @@ class AddressbookListModule extends ListModule {
 								$item['entryid'] = $entryid . '02';
 								array_push($items, ['props' => $item]);
 								break;
+
 							case 5:
 							case 6:
 								$item['address_type'] = $user_data[$this->properties["email_address_type_3"]];
@@ -333,6 +325,7 @@ class AddressbookListModule extends ListModule {
 								$item['entryid'] = $entryid . '03';
 								array_push($items, ['props' => $item]);
 								break;
+
 							case 7:
 								$item['address_type'] = $user_data[$this->properties["email_address_type_2"]];
 								$item['email_address'] = $user_data[$this->properties["email_address_2"]];
@@ -350,11 +343,9 @@ class AddressbookListModule extends ListModule {
 				}
 
 				function sorter($direction, $key) {
-					return function($a, $b) use ($direction, $key) {
-						return $direction == 'ASC' ?
+					return fn ($a, $b) => $direction == 'ASC' ?
 							strcasecmp($a['props'][$key] ?? '', $b['props'][$key] ?? '') :
 							strcasecmp($b['props'][$key] ?? '', $a['props'][$key] ?? '');
-					};
 				}
 				usort($items, sorter($sortingDir, $sortingField));
 
@@ -871,8 +862,8 @@ class AddressbookListModule extends ListModule {
 
 			$this->addFolder($folders, [
 				"display_name" => $item[PR_DISPLAY_NAME] ?? '',
-				"entryid" => bin2hex($item[PR_ENTRYID]),
-				"parent_entryid" => bin2hex($item[PR_PARENT_ENTRYID]),
+				"entryid" => bin2hex((string) $item[PR_ENTRYID]),
+				"parent_entryid" => bin2hex((string) $item[PR_PARENT_ENTRYID]),
 				"depth" => $item[PR_DEPTH],
 				"type" => $item[PR_AB_PROVIDER_ID] == MUIDECSAB ? "gab" : 'contacts',
 				"object_type" => MAPI_ABCONT,
@@ -894,8 +885,8 @@ class AddressbookListModule extends ListModule {
 			$sharedUserSetting = [];
 			if ($sharedStoreProps[PR_MDB_PROVIDER] == ZARAFA_STORE_DELEGATE_GUID) {
 				$eidObj = $GLOBALS["entryid"]->createMsgStoreEntryIdObj($sharedEntryId);
-				if (array_key_exists(strtolower($eidObj['MailboxDN']), $shareUserSettings)) {
-					$sharedUserSetting = $shareUserSettings[strtolower($eidObj['MailboxDN'])];
+				if (array_key_exists(strtolower((string) $eidObj['MailboxDN']), $shareUserSettings)) {
+					$sharedUserSetting = $shareUserSettings[strtolower((string) $eidObj['MailboxDN'])];
 				}
 				$sharedContactFolders = $GLOBALS["mapisession"]->getContactFoldersForABContactProvider($sharedStore);
 				for ($i = 0, $len = count($sharedContactFolders); $i < $len; ++$i) {
@@ -906,21 +897,20 @@ class AddressbookListModule extends ListModule {
 						// Do not show contacts' folders in the AB list view for which
 						// the user has permissions, but hasn't added them to the folder hierarchy.
 						if (!empty($sharedUserSetting) &&
-						    !isset($sharedUserSetting['all']) &&
-						    !isset($sharedUserSetting['contact']) &&
-						    in_array($mainUserEntryId, array_column($grants, 'userid'))) {
+							!isset($sharedUserSetting['all']) &&
+							!isset($sharedUserSetting['contact']) &&
+							in_array($mainUserEntryId, array_column($grants, 'userid'))) {
 							continue;
 						}
 						if (isset($sharedUserSetting['all']) ||
-						    isset($sharedUserSetting['contact']) ||
-						    in_array($mainUserEntryId, array_column($grants, 'userid')))
-						{
+							isset($sharedUserSetting['contact']) ||
+							in_array($mainUserEntryId, array_column($grants, 'userid'))) {
 							$this->addFolder($folders, [
 								// Postfix display name of every contact folder with respective owner name
 								// it is mandatory to keep display-name different
 								"display_name" => $sharedContactFolders[$i][PR_DISPLAY_NAME] . " - " . $sharedStoreProps[PR_MAILBOX_OWNER_NAME],
-								"entryid" => bin2hex($sharedContactFolders[$i][PR_ENTRYID]),
-								"parent_entryid" => bin2hex($sharedContactFolders[$i][PR_PARENT_ENTRYID]),
+								"entryid" => bin2hex((string) $sharedContactFolders[$i][PR_ENTRYID]),
+								"parent_entryid" => bin2hex((string) $sharedContactFolders[$i][PR_PARENT_ENTRYID]),
 								"depth" => $sharedContactFolders[$i][PR_DEPTH],
 								"type" => 'sharedcontacts',
 								"object_type" => MAPI_ABCONT,
@@ -948,8 +938,8 @@ class AddressbookListModule extends ListModule {
 				// Postfix display name of every contact folder with respective owner name
 				// it is mandatory to keep display-name different
 				"display_name" => $publicContactFolders[$i][PR_DISPLAY_NAME] . ' - ' . $publicStoreProps[PR_DISPLAY_NAME],
-				"entryid" => bin2hex($publicContactFolders[$i][PR_ENTRYID]),
-				"parent_entryid" => bin2hex($publicContactFolders[$i][PR_PARENT_ENTRYID]),
+				"entryid" => bin2hex((string) $publicContactFolders[$i][PR_ENTRYID]),
+				"parent_entryid" => bin2hex((string) $publicContactFolders[$i][PR_PARENT_ENTRYID]),
 				// only indent folders which have a parent folder already in the list
 				"depth" => $publicContactFolders[$i][PR_DEPTH] > 1 && in_array($publicContactFolders[$i][PR_PARENT_ENTRYID], $knownParents) ?
 					$publicContactFolders[$i][PR_DEPTH] : 1,
@@ -970,7 +960,7 @@ class AddressbookListModule extends ListModule {
 	}
 
 	/**
-	 * Returns the field which will be used to sort the ab items
+	 * Returns the field which will be used to sort the ab items.
 	 *
 	 * @param array  $action
 	 * @param array  $map
@@ -1135,9 +1125,9 @@ class AddressbookListModule extends ListModule {
 	/**
 	 * Returns the hiding users/groups restriction for the ab items.
 	 *
-	 * @param bool   $hide_users
-	 * @param bool   $hide_groups
-	 * @param bool   $hide_companies
+	 * @param bool $hide_users
+	 * @param bool $hide_groups
+	 * @param bool $hide_companies
 	 *
 	 * @return array
 	 */
@@ -1169,4 +1159,4 @@ class AddressbookListModule extends ListModule {
 
 		return $userGroupRestriction;
 	}
-}
\ No newline at end of file
+}
