@@ -35,6 +35,7 @@ class AdvancedSearchListModule extends ListModule {
 	/**
 	 * Executes all the actions in the $data variable.
 	 */
+	#[Override]
 	public function execute() {
 		foreach ($this->data as $actionType => $action) {
 			if (isset($actionType)) {
@@ -75,7 +76,7 @@ class AdvancedSearchListModule extends ListModule {
 						$this->processException($e, $actionType);
 					}
 					else {
-						if (DEBUG_LOADER === 'LOAD_SOURCE') {
+						if (DEBUG_LOADER === 0) {
 							// Log all info we can get about this error to the error log of the web server
 							error_log("Error in search: \n" . var_export($e, true) . "\n\n" . var_export(debug_backtrace(), true));
 						}
@@ -95,6 +96,7 @@ class AdvancedSearchListModule extends ListModule {
 	 * @param array  $action     the action data, sent by the client
 	 * @param string $actionType the action type, sent by the client
 	 */
+	#[Override]
 	public function messageList($store, $entryid, $action, $actionType) {
 		$this->searchFolderList = false; // Set to indicate this is not the search result, but a normal folder content
 		$data = [];
@@ -109,7 +111,7 @@ class AdvancedSearchListModule extends ListModule {
 			$limit = $action['restriction']['limit'] ?? 1000;
 
 			$isSearchFolder = isset($action['search_folder_entryid']);
-			$entryid = $isSearchFolder ? hex2bin($action['search_folder_entryid']) : $entryid;
+			$entryid = $isSearchFolder ? hex2bin((string) $action['search_folder_entryid']) : $entryid;
 
 			if ($actionType == 'search') {
 				$rows = [[PR_ENTRYID => $entryid]];
@@ -272,8 +274,9 @@ class AdvancedSearchListModule extends ListModule {
 	 * @param object $action     the action data, sent by the client
 	 * @param string $actionType the action type, sent by the client
 	 */
+	#[Override]
 	public function search($store, $entryid, $action, $actionType) {
-		$useSearchFolder = isset($action["use_searchfolder"]) ? $action["use_searchfolder"] : false;
+		$useSearchFolder = $action["use_searchfolder"] ?? false;
 		if (!$useSearchFolder) {
 			/*
 			 * store doesn't support search folders so we can't use this
@@ -320,23 +323,17 @@ class AdvancedSearchListModule extends ListModule {
 		if ($searchFolder === false) {
 			if ($store_props[PR_MDB_PROVIDER] == ZARAFA_STORE_DELEGATE_GUID) {
 				$this->messageList($store, $entryid, $action, "search");
+
 				return true;
 			}
 			// if error in creating search folder then send error to client
 			$errorInfo = [];
 
-			switch (mapi_last_hresult()) {
-				case MAPI_E_NO_ACCESS:
-					$errorInfo["error_message"] = _("Unable to perform search query, no permissions to create search folder.");
-					break;
-
-				case MAPI_E_NOT_FOUND:
-					$errorInfo["error_message"] = _("Unable to perform search query, search folder not found.");
-					break;
-
-				default:
-					$errorInfo["error_message"] = _("Unable to perform search query, store might not support searching.");
-			}
+			$errorInfo["error_message"] = match (mapi_last_hresult()) {
+				MAPI_E_NO_ACCESS => _("Unable to perform search query, no permissions to create search folder."),
+				MAPI_E_NOT_FOUND => _("Unable to perform search query, search folder not found."),
+				default => _("Unable to perform search query, store might not support searching."),
+			};
 
 			$errorInfo["original_error_message"] = _("Error in creating search folder.");
 
@@ -372,7 +369,7 @@ class AdvancedSearchListModule extends ListModule {
 				$entryids = [];
 				$entryIdsCount = count($this->sessionData['searchOriginalEntryids']);
 				for ($index = 0; $index < $entryIdsCount; ++$index) {
-					$entryids[] = hex2bin($this->sessionData['searchOriginalEntryids'][$index]);
+					$entryids[] = hex2bin((string) $this->sessionData['searchOriginalEntryids'][$index]);
 				}
 			}
 			else {
@@ -399,10 +396,12 @@ class AdvancedSearchListModule extends ListModule {
 		// Sort
 		$this->parseSortOrder($action);
 		// Initialize search patterns with default values
-		$search_patterns = array_fill_keys(['sender', 'sending', 'recipients',
-			'subject', 'content', 'attachments', 'others', 'message_classes',
-			'date_start', 'date_end', 'unread', 'has_attachments', 'categories'],
-			null);
+		$search_patterns = array_fill_keys(
+			['sender', 'sending', 'recipients',
+				'subject', 'content', 'attachments', 'others', 'message_classes',
+				'date_start', 'date_end', 'unread', 'has_attachments', 'categories'],
+			null
+		);
 		$this->parsePatterns($this->restriction, $search_patterns);
 		if (isset($search_patterns['message_classes']) &&
 			count($search_patterns['message_classes']) >= 7) {
@@ -410,7 +409,7 @@ class AdvancedSearchListModule extends ListModule {
 		}
 
 		if ($store_props[PR_MDB_PROVIDER] == ZARAFA_STORE_DELEGATE_GUID) {
-			$eidObj = $GLOBALS["entryid"]->createMsgStoreEntryIdObj(hex2bin($action['store_entryid']));
+			$eidObj = $GLOBALS["entryid"]->createMsgStoreEntryIdObj(hex2bin((string) $action['store_entryid']));
 			$username = $eidObj['ServerShortname'];
 			$session = $GLOBALS["mapisession"]->getSession();
 
@@ -422,12 +421,12 @@ class AdvancedSearchListModule extends ListModule {
 			$indexDB = new IndexSqlite();
 		}
 
-		$search_result = $indexDB->search(hex2bin($searchFolderEntryId), $search_patterns, $entryid, $recursive);
+		$search_result = $indexDB->search(hex2bin((string) $searchFolderEntryId), $search_patterns, $entryid, $recursive);
 		// Use the query search if search in index fails or is not available.
 		if ($search_result == false) {
 			// Search in the inbox instead of Top of Information Store
 			if (isset($store_props[PR_IPM_SUBTREE_ENTRYID]) &&
-				$GLOBALS['entryid']->compareEntryIds(bin2hex($entryid), bin2hex($store_props[PR_IPM_SUBTREE_ENTRYID]))) {
+				$GLOBALS['entryid']->compareEntryIds(bin2hex($entryid), bin2hex((string) $store_props[PR_IPM_SUBTREE_ENTRYID]))) {
 				$inbox = mapi_msgstore_getreceivefolder($store);
 				$inboxProps = mapi_getprops($inbox, [PR_ENTRYID]);
 				$entryid = $inboxProps[PR_ENTRYID];
@@ -439,7 +438,7 @@ class AdvancedSearchListModule extends ListModule {
 		unset($action["restriction"]);
 
 		// Get the table and merge the arrays
-		$table = $GLOBALS["operations"]->getTable($store, hex2bin($searchFolderEntryId), $this->properties, $this->sort, $this->start);
+		$table = $GLOBALS["operations"]->getTable($store, hex2bin((string) $searchFolderEntryId), $this->properties, $this->sort, $this->start);
 		// Create the data array, which will be send back to the client
 		$data = [];
 		$data = array_merge($data, $table);
