@@ -2,7 +2,7 @@
 
 /**
  * Appointment ItemModule
- * Module which openes, creates, saves and deletes an item. It
+ * Module which opens, creates, saves and deletes an item. It
  * extends the Module class.
  */
 class AppointmentItemModule extends ItemModule {
@@ -50,6 +50,7 @@ class AppointmentItemModule extends ItemModule {
 		$this->tzdefObj = false;
 	}
 
+	#[Override]
 	public function open($store, $entryid, $action) {
 		if ($store && $entryid) {
 			$data = [];
@@ -80,10 +81,11 @@ class AppointmentItemModule extends ItemModule {
 
 			if (!empty($action["timezone_iana"])) {
 				$this->tziana = $action["timezone_iana"];
+
 				try {
 					$this->tzdef = mapi_ianatz_to_tzdef($action['timezone_iana']);
 				}
-				catch (Exception $e) {
+				catch (Exception) {
 				}
 			}
 
@@ -232,6 +234,7 @@ class AppointmentItemModule extends ItemModule {
 	 * @param string     $entryid       entryid of the message
 	 * @param array      $action        the action data, sent by the client
 	 */
+	#[Override]
 	public function handleException(&$e, $actionType = null, $store = null, $parententryid = null, $entryid = null, $action = null) {
 		if (is_null($e->displayMessage)) {
 			switch ($actionType) {
@@ -248,7 +251,7 @@ class AppointmentItemModule extends ItemModule {
 						$e->setTitle(_('Insufficient privileges'));
 
 						// Need this notification to refresh the calendar.
-						$GLOBALS['bus']->notify(bin2hex($parententryid), TABLE_DELETE, $messageProps);
+						$GLOBALS['bus']->notify(bin2hex((string) $parententryid), TABLE_DELETE, $messageProps);
 					}
 					break;
 			}
@@ -265,6 +268,7 @@ class AppointmentItemModule extends ItemModule {
 	 * @param array     $action        Action array containing json request
 	 * @param string    $actionType    The action type which triggered this action
 	 */
+	#[Override]
 	public function save($store, $parententryid, $entryid, $action, $actionType = 'save') {
 		$result = false;
 
@@ -286,27 +290,13 @@ class AppointmentItemModule extends ItemModule {
 			$errorMsg = _('Two occurrences cannot occur on the same day');
 		}
 		elseif (is_array($messageProps) && isset($messageProps['error'])) {
-			switch ($messageProps['error']) {
-				case 1:
-					$errorMsg = sprintf(_('You marked \'%s\' as a resource. You cannot schedule a meeting with \'%s\' because you do not have the appropriate permissions for that account. Either enter the name as a required or optional attendee or talk to your administrator about giving you permission to schedule \'%s\'.'), $messageProps['displayname'], $messageProps['displayname'], $messageProps['displayname']);
-					break;
-
-				case 2:
-					$errorMsg = sprintf(_('\'%s\' has declined your meeting because \'%s\' does not automatically accept meeting requests.'), $messageProps['displayname'], $messageProps['displayname']);
-					break;
-
-				case 3:
-					$errorMsg = sprintf(_('\'%s\' has declined your meeting because it is recurring. You must book each meeting separately with this resource.'), $messageProps['displayname']);
-					break;
-
-				case 4:
-					$errorMsg = sprintf(_('\'%s\' is already booked for this specified time. You must use another time or find another resource.'), $messageProps['displayname']);
-					break;
-
-				default:
-					$errorMsg = _('Meeting was not scheduled.');
-					break;
-			}
+			$errorMsg = match ($messageProps['error']) {
+				1 => sprintf(_('You marked \'%s\' as a resource. You cannot schedule a meeting with \'%s\' because you do not have the appropriate permissions for that account. Either enter the name as a required or optional attendee or talk to your administrator about giving you permission to schedule \'%s\'.'), $messageProps['displayname'], $messageProps['displayname'], $messageProps['displayname']),
+				2 => sprintf(_('\'%s\' has declined your meeting because \'%s\' does not automatically accept meeting requests.'), $messageProps['displayname'], $messageProps['displayname']),
+				3 => sprintf(_('\'%s\' has declined your meeting because it is recurring. You must book each meeting separately with this resource.'), $messageProps['displayname']),
+				4 => sprintf(_('\'%s\' is already booked for this specified time. You must use another time or find another resource.'), $messageProps['displayname']),
+				default => _('Meeting was not scheduled.'),
+			};
 		}
 		else {
 			// Recurring but non-existing exception (same as normal open, but add basedate, startdate and enddate)
@@ -382,7 +372,7 @@ class AppointmentItemModule extends ItemModule {
 		// all-day events).
 		$isTzdefstartSet = isset($calendaritem['props']['tzdefstart']);
 		$tzdefstart = $isTzdefstartSet ?
-			hex2bin($calendaritem['props']['tzdefstart']) :
+			hex2bin((string) $calendaritem['props']['tzdefstart']) :
 			mapi_ianatz_to_tzdef("Etc/UTC");
 
 		// Compare the timezone definitions of the client and the appointment.
@@ -401,12 +391,12 @@ class AppointmentItemModule extends ItemModule {
 				$this->tzdefObj = $GLOBALS['entryid']->createTimezoneDefinitionObject($this->tzdef);
 			}
 			$this->tzEffRuleIdx = getEffectiveTzreg($this->tzdefObj['rules']);
-			
+
 			$appTzDefStart = $GLOBALS['entryid']->createTimezoneDefinitionObject($tzdefstart);
-			
+
 			// Find TZRULE_FLAG_EFFECTIVE_TZREG rule for the appointment's timezone
 			$appTzEffRuleIdx = getEffectiveTzreg($appTzDefStart['rules']);
-			
+
 			if (is_null($this->tzEffRuleIdx) && !is_null($appTzEffRuleIdx)) {
 				return;
 			}
