@@ -2,7 +2,7 @@
 
 /**
  * Contact ItemModule
- * Module which openes, creates, saves and deletes an item. It
+ * Module which opens, creates, saves and deletes an item. It
  * extends the Module class.
  */
 class ContactItemModule extends ItemModule {
@@ -27,6 +27,7 @@ class ContactItemModule extends ItemModule {
 	 * @param string $entryid entryid of the message
 	 * @param array  $action  the action data, sent by the client
 	 */
+	#[Override]
 	public function open($store, $entryid, $action) {
 		$data = [];
 		$orEntryid = $entryid;
@@ -77,7 +78,7 @@ class ContactItemModule extends ItemModule {
 			// Check if message is distlist then we need to use different set of properties
 			$props = mapi_getprops($message, [PR_MESSAGE_CLASS]);
 
-			if (stripos($props[PR_MESSAGE_CLASS], 'IPM.Distlist') !== false) {
+			if (stripos((string) $props[PR_MESSAGE_CLASS], 'IPM.Distlist') !== false) {
 				// for distlist we need to use different set of properties
 				$this->properties = $GLOBALS['properties']->getDistListProperties();
 			}
@@ -88,7 +89,7 @@ class ContactItemModule extends ItemModule {
 			// Check if message is distlist then we need to use different set of properties
 			$props = mapi_getprops($message, [PR_MESSAGE_CLASS]);
 
-			if (stripos($props[PR_MESSAGE_CLASS], 'IPM.Distlist') !== false) {
+			if (stripos((string) $props[PR_MESSAGE_CLASS], 'IPM.Distlist') !== false) {
 				// for distlist we need to use different set of properties
 				$this->properties = $GLOBALS['properties']->getDistListProperties();
 			}
@@ -123,6 +124,7 @@ class ContactItemModule extends ItemModule {
 	 * @param string $entryid       entryid of the message
 	 * @param array  $action        the action data, sent by the client
 	 */
+	#[Override]
 	public function save($store, $parententryid, $entryid, $action) {
 		$properiesToDelete = []; // create an array of properties which should be deleted
 		// this array is passed to $GLOBALS['operations']->saveMessage() function
@@ -176,7 +178,7 @@ class ContactItemModule extends ItemModule {
 						$parts = [];
 						$parts['distlist_guid'] = WAB_GUID;
 						$parts['distlist_type'] = $item['distlist_type'];
-						$parts['entryid'] = hex2bin($item['entryid']);
+						$parts['entryid'] = hex2bin((string) $item['entryid']);
 						$member = pack('VA16CA*', 0, $parts['distlist_guid'], $parts['distlist_type'], $parts['entryid']);
 					}
 
@@ -316,7 +318,7 @@ class ContactItemModule extends ItemModule {
 
 			$messageProps = [];
 
-			$result = $GLOBALS['operations']->saveMessage($store, $entryid, $parententryid, $props, $messageProps, [], isset($action['attachments']) ? $action['attachments'] : [], $properiesToDelete);
+			$result = $GLOBALS['operations']->saveMessage($store, $entryid, $parententryid, $props, $messageProps, [], $action['attachments'] ?? [], $properiesToDelete);
 
 			if ($result) {
 				$GLOBALS['bus']->notify(bin2hex($parententryid), TABLE_SAVE, $messageProps);
@@ -339,7 +341,7 @@ class ContactItemModule extends ItemModule {
 	 */
 	public function copyGABRecordProps(&$action) {
 		$addrbook = $GLOBALS["mapisession"]->getAddressbook();
-		$abitem = mapi_ab_openentry($addrbook, hex2bin($action["message_action"]["source_entryid"]));
+		$abitem = mapi_ab_openentry($addrbook, hex2bin((string) $action["message_action"]["source_entryid"]));
 		$abItemProps = mapi_getprops($abitem, [
 			PR_COMPANY_NAME,
 			PR_ASSISTANT,
@@ -353,18 +355,18 @@ class ContactItemModule extends ItemModule {
 			PR_COUNTRY,
 			PR_MOBILE_TELEPHONE_NUMBER,
 		]);
-		$action["props"]["company_name"] = isset($abItemProps[PR_COMPANY_NAME]) ? $abItemProps[PR_COMPANY_NAME] : '';
-		$action["props"]["assistant"] = isset($abItemProps[PR_ASSISTANT]) ? $abItemProps[PR_ASSISTANT] : '';
-		$action["props"]["business_telephone_number"] = isset($abItemProps[PR_BUSINESS_TELEPHONE_NUMBER]) ? $abItemProps[PR_BUSINESS_TELEPHONE_NUMBER] : '';
-		$action["props"]["business2_telephone_number"] = isset($abItemProps[PR_BUSINESS2_TELEPHONE_NUMBER]) ? $abItemProps[PR_BUSINESS2_TELEPHONE_NUMBER] : '';
-		$action["props"]["home2_telephone_number"] = isset($abItemProps[PR_HOME2_TELEPHONE_NUMBER]) ? $abItemProps[PR_HOME2_TELEPHONE_NUMBER] : '';
-		$action["props"]["home_address_street"] = isset($abItemProps[PR_STREET_ADDRESS]) ? $abItemProps[PR_STREET_ADDRESS] : '';
-		$action["props"]["home_address_city"] = isset($abItemProps[PR_LOCALITY]) ? $abItemProps[PR_LOCALITY] : '';
-		$action["props"]["home_address_state"] = isset($abItemProps[PR_STATE_OR_PROVINCE]) ? $abItemProps[PR_STATE_OR_PROVINCE] : '';
-		$action["props"]["home_address_postal_code"] = isset($abItemProps[PR_POSTAL_CODE]) ? $abItemProps[PR_POSTAL_CODE] : '';
-		$action["props"]["home_address_country"] = isset($abItemProps[PR_COUNTRY]) ? $abItemProps[PR_COUNTRY] : '';
+		$action["props"]["company_name"] = $abItemProps[PR_COMPANY_NAME] ?? '';
+		$action["props"]["assistant"] = $abItemProps[PR_ASSISTANT] ?? '';
+		$action["props"]["business_telephone_number"] = $abItemProps[PR_BUSINESS_TELEPHONE_NUMBER] ?? '';
+		$action["props"]["business2_telephone_number"] = $abItemProps[PR_BUSINESS2_TELEPHONE_NUMBER] ?? '';
+		$action["props"]["home2_telephone_number"] = $abItemProps[PR_HOME2_TELEPHONE_NUMBER] ?? '';
+		$action["props"]["home_address_street"] = $abItemProps[PR_STREET_ADDRESS] ?? '';
+		$action["props"]["home_address_city"] = $abItemProps[PR_LOCALITY] ?? '';
+		$action["props"]["home_address_state"] = $abItemProps[PR_STATE_OR_PROVINCE] ?? '';
+		$action["props"]["home_address_postal_code"] = $abItemProps[PR_POSTAL_CODE] ?? '';
+		$action["props"]["home_address_country"] = $abItemProps[PR_COUNTRY] ?? '';
 
-		$action["props"]["cellular_telephone_number"] = isset($abItemProps[PR_MOBILE_TELEPHONE_NUMBER]) ? $abItemProps[PR_MOBILE_TELEPHONE_NUMBER] : '';
+		$action["props"]["cellular_telephone_number"] = $abItemProps[PR_MOBILE_TELEPHONE_NUMBER] ?? '';
 
 		// Set the home_address property value
 		$props = ["street", "city", "state", "postal_code", "country"];
@@ -390,6 +392,7 @@ class ContactItemModule extends ItemModule {
 	 * @param string $entryid       entryid of the message
 	 * @param array  $action        the action data, sent by the client
 	 */
+	#[Override]
 	public function delete($store, $parententryid, $entryid, $action) {
 		$message = false;
 		if (!$store && !$parententryid && $entryid) {
@@ -409,11 +412,11 @@ class ContactItemModule extends ItemModule {
 
 				// if any of the appointment entryid exists then delete it
 				if (!empty($props[$this->properties['birthday_eventid']])) {
-					$this->deleteSpecialDateAppointment($store, bin2hex($props[$this->properties['birthday_eventid']]));
+					$this->deleteSpecialDateAppointment($store, bin2hex((string) $props[$this->properties['birthday_eventid']]));
 				}
 
 				if (!empty($props[$this->properties['anniversary_eventid']])) {
-					$this->deleteSpecialDateAppointment($store, bin2hex($props[$this->properties['anniversary_eventid']]));
+					$this->deleteSpecialDateAppointment($store, bin2hex((string) $props[$this->properties['anniversary_eventid']]));
 				}
 			}
 			catch (MAPIException $e) {
@@ -456,8 +459,8 @@ class ContactItemModule extends ItemModule {
 
 		$root = mapi_msgstore_openentry($store);
 		$rootProps = mapi_getprops($root, [PR_IPM_APPOINTMENT_ENTRYID, PR_STORE_ENTRYID]);
-		$parentEntryId = bin2hex($rootProps[PR_IPM_APPOINTMENT_ENTRYID]);
-		$storeEntryId = bin2hex($rootProps[PR_STORE_ENTRYID]);
+		$parentEntryId = bin2hex((string) $rootProps[PR_IPM_APPOINTMENT_ENTRYID]);
+		$storeEntryId = bin2hex((string) $rootProps[PR_STORE_ENTRYID]);
 
 		$actionProps = $action['props'];
 		$subject = !empty($actionProps['subject']) ? $actionProps['subject'] : _('Untitled');
@@ -556,7 +559,7 @@ class ContactItemModule extends ItemModule {
 		// Save appointment (saveAppointment takes care of creating/modifying exceptions to recurring
 		// items if necessary)
 		try {
-			$messageProps = $GLOBALS['operations']->saveAppointment($store, hex2bin($entryid), hex2bin($parentEntryId), $data);
+			$messageProps = $GLOBALS['operations']->saveAppointment($store, hex2bin((string) $entryid), hex2bin($parentEntryId), $data);
 		}
 		catch (MAPIException $e) {
 			// if the appointment is deleted then create a new one
@@ -569,7 +572,7 @@ class ContactItemModule extends ItemModule {
 		// Notify the bus if the save was OK
 		if ($messageProps && !(is_array($messageProps) && isset($messageProps['error']))) {
 			$GLOBALS['bus']->notify($parentEntryId, TABLE_SAVE, $messageProps);
-			$result = bin2hex($messageProps[PR_ENTRYID]);
+			$result = bin2hex((string) $messageProps[PR_ENTRYID]);
 		}
 
 		return $result;
@@ -589,13 +592,13 @@ class ContactItemModule extends ItemModule {
 
 		$props = [];
 		$props[PR_PARENT_ENTRYID] = $parentEntryId;
-		$props[PR_ENTRYID] = hex2bin($entryid);
+		$props[PR_ENTRYID] = hex2bin((string) $entryid);
 		$props[PR_STORE_ENTRYID] = $storeEntryId;
 
 		$result = $GLOBALS['operations']->deleteMessages($store, $parentEntryId, $props[PR_ENTRYID]);
 
 		if ($result) {
-			$GLOBALS['bus']->notify(bin2hex($parentEntryId), TABLE_DELETE, $props);
+			$GLOBALS['bus']->notify(bin2hex((string) $parentEntryId), TABLE_DELETE, $props);
 		}
 	}
 
