@@ -16,6 +16,8 @@ class CreateMailItemModule extends ItemModule {
 		parent::__construct($id, $data);
 
 		$this->properties = $GLOBALS['properties']->getMailProperties();
+		$useHtmlPreview = $GLOBALS['settings']->get('zarafa/v1/contexts/mail/use_html_email_preview', USE_HTML_EMAIL_PREVIEW);
+		$this->plaintext = !$useHtmlPreview;
 	}
 
 	/**
@@ -273,7 +275,7 @@ class CreateMailItemModule extends ItemModule {
 						$data['item'] = $GLOBALS['operations']->getEmbeddedMessageProps($store, $message, $this->properties, $savedMsg, $attachNum);
 					}
 					else {
-						$data = $GLOBALS['operations']->getMessageProps($store, $savedMsg, $this->properties);
+						$data = $GLOBALS['operations']->getMessageProps($store, $savedMsg, $this->properties, $this->plaintext);
 					}
 
 					/*
