@@ -21,18 +21,15 @@ class ExpandDistlistModule extends Module {
 	/**
 	 * Executes all the actions in the $data variable.
 	 */
+	#[Override]
 	public function execute() {
 		foreach ($this->data as $actionType => $action) {
 			if (isset($actionType)) {
 				try {
-					switch ($actionType) {
-						case 'expand':
-							$this->expand($action);
-							break;
-
-						default:
-							$this->handleUnknownActionType($actionType);
-					}
+					match ($actionType) {
+						'expand' => $this->expand($action),
+						default => $this->handleUnknownActionType($actionType),
+					};
 				}
 				catch (MAPIException $e) {
 					$this->processException($e, $actionType);
@@ -69,7 +66,7 @@ class ExpandDistlistModule extends Module {
 				$memberProps = Conversion::mapMAPI2XML($this->properties, $rows[$i]);
 				$isDistlist = $memberProps['props']['object_type'] == MAPI_DISTLIST;
 				if ($isDistlist && $isRecurse === true) {
-					$data = array_merge($data, $this->expandDist(hex2bin($memberProps['entryid']), [], $isRecurse));
+					$data = array_merge($data, $this->expandDist(hex2bin((string) $memberProps['entryid']), [], $isRecurse));
 				}
 				else {
 					$data[] = $memberProps;
@@ -102,7 +99,7 @@ class ExpandDistlistModule extends Module {
 	 */
 	public function expand($action) {
 		// Get the distribution list entryid from request
-		$entryid = hex2bin($action["entryid"]);
+		$entryid = hex2bin((string) $action["entryid"]);
 		$this->addrbook = $GLOBALS["mapisession"]->getAddressbook();
 
 		if ($entryid) {
