@@ -39,12 +39,13 @@ class HierarchyModule extends Module {
 	 *
 	 * @return array list of entryids
 	 */
+	#[Override]
 	public function getEntryID() {
 		$entryids = [];
 		$storelist = $GLOBALS["mapisession"]->getAllMessageStores();
 
 		foreach ($storelist as $entryid => $store) {
-			$entryids[] = bin2hex($entryid);
+			$entryids[] = bin2hex((string) $entryid);
 		}
 
 		return $entryids;
@@ -53,10 +54,13 @@ class HierarchyModule extends Module {
 	/**
 	 * Executes all the actions in the $data variable.
 	 */
+	#[Override]
 	public function execute() {
 		foreach ($this->data as $actionType => $action) {
-			if (!isset($actionType))
+			if (!isset($actionType)) {
 				continue;
+			}
+
 			try {
 				$store = $this->getActionStore($action);
 				$parententryid = $this->getActionParentEntryID($action);
@@ -64,291 +68,291 @@ class HierarchyModule extends Module {
 				$this->store_entryid = $action["store_entryid"] ?? '';
 
 				switch ($actionType) {
-				case "keepalive":
-					/*
-					 * as we haven't done any processing here but still we need to send
-					 * success message to client so client can know that there isn't any problem
-					 * on server side (this will also make bus class happy as it will cry when
-					 * there isn't any data to send to client).
-					 */
-					$this->sendFeedback(true);
-					break;
-
-				case "destroysession":
-					// This actiontype should never get this far, but should already have been
-					// intercepted by the Session class.
-					// Nevertheless implement processing here for unforeseen cases.
-					$this->sendFeedback(true);
-					break;
-
-				case "list":
-					$this->hierarchyList();
-					break;
-
-				case "open":
-					$folder = mapi_msgstore_openentry($store, $entryid);
-					$data = $this->getFolderProps($store, $folder);
-
-					// return response
-					$this->addActionData("item", $data);
-					$GLOBALS["bus"]->addData($this->getResponseData());
-					break;
-
-				case "foldersize":
-					$folders = [];
-
-					$folder = mapi_msgstore_openentry($store, $entryid);
-					$data = $this->getFolderProps($store, $folder);
-
-					$info = $this->getFolderSize($store, $folder, '', $folders);
-
-					// It could be that the $props already contains the data,
-					// this happens when the folder is the IPM_SUBTREE and the
-					// folder size is read directly from the store. Adjust
-					// total_size accordingly.
-					if (isset($data["props"]["store_size"])) {
-						if (!isset($data["props"]["message_size"])) {
-							$data["props"]["message_size"] = $data["props"]["store_size"];
-						}
-						$data["props"]["total_message_size"] = $data["props"]["store_size"] + $info["total_size"];
-					}
-					else {
-						$data["props"]["message_size"] = $info["size"];
-						$data["props"]["total_message_size"] = $info["total_size"];
-					}
-					$data["folders"] = [
-						"item" => $folders,
-					];
-
-					// return response
-					$this->addActionData("item", $data);
-					$GLOBALS["bus"]->addData($this->getResponseData());
-					break;
-
-				case "delete":
-					if (!$store || !$parententryid || !$entryid)
-						break;
-					if (!isset($action["message_action"], $action["message_action"]["action_type"]) ||
-					    $action["message_action"]["action_type"] !== "removefavorites") {
-						$this->deleteFolder($store, $parententryid, $entryid, $action);
-						break;
-					}
-					if (!isset($action["message_action"]["isSearchFolder"]) ||
-					    !$action["message_action"]["isSearchFolder"]) {
-						$this->removeFromFavorite($entryid);
-						break;
-					}
-					$result = $this->deleteSearchFolder($store, $parententryid, $entryid, $action);
-					dump($result, '$result');
-					if ($result) {
+					case "keepalive":
+						/*
+						 * as we haven't done any processing here but still we need to send
+						 * success message to client so client can know that there isn't any problem
+						 * on server side (this will also make bus class happy as it will cry when
+						 * there isn't any data to send to client).
+						 */
 						$this->sendFeedback(true);
-					}
-					break;
-
-				case "save":
-					if (!$store || !$parententryid)
 						break;
-					if ($entryid) {
-						// The "message_action" object has been set, check the action_type field for
-						// the exact action which must be taken.
-						// Supported actions:
-						//   - copy: Copy the folder to the new destination folder
-						//   - move: Move the folder to the new destination folder
-						//   - emptyfolder: Delete all items within the folder
-						//   - readflags: Mark all items within the folder as read
-						//   - addtofavorites: Add the folder to "favorites"
-						if (!isset($action["message_action"]["isSearchFolder"])) {
-							$folder = mapi_msgstore_openentry($store, $entryid);
-							$data = $this->getFolderProps($store, $folder);
-						}
-						if (isset($action["message_action"], $action["message_action"]["action_type"])) {
-							switch ($action["message_action"]["action_type"]) {
-							case "copy":
-							case "move":
-								$destentryid = false;
-								if (isset($action["message_action"]["destination_parent_entryid"])) {
-									$destentryid = hex2bin($action["message_action"]["destination_parent_entryid"]);
-								}
 
-								$deststore = $store;
-								if (isset($action["message_action"]["destination_store_entryid"])) {
-									$deststore = $GLOBALS['mapisession']->openMessageStore(hex2bin($action["message_action"]["destination_store_entryid"]));
-								}
+					case "destroysession":
+						// This actiontype should never get this far, but should already have been
+						// intercepted by the Session class.
+						// Nevertheless implement processing here for unforeseen cases.
+						$this->sendFeedback(true);
+						break;
 
-								if ($destentryid && $deststore) {
-									$this->copyFolder($store, $parententryid, $entryid, $destentryid, $deststore, $action["message_action"]["action_type"] == "move");
-								}
-								if ($data["props"]["container_class"] === "IPF.Contact") {
-									$GLOBALS["bus"]->notify(ADDRESSBOOK_ENTRYID, OBJECT_SAVE);
-								}
-								break;
+					case "list":
+						$this->hierarchyList();
+						break;
 
-							case "emptyfolder":
-								$this->emptyFolder($store, $entryid);
-								break;
+					case "open":
+						$folder = mapi_msgstore_openentry($store, $entryid);
+						$data = $this->getFolderProps($store, $folder);
 
-							case "readflags":
-								$this->setReadFlags($store, $entryid);
-								break;
+						// return response
+						$this->addActionData("item", $data);
+						$GLOBALS["bus"]->addData($this->getResponseData());
+						break;
 
-							case "addtofavorites":
-								if (isset($action["message_action"]["isSearchFolder"]) && $action["message_action"]["isSearchFolder"]) {
-									$searchStoreEntryId = $action["message_action"]["search_store_entryid"];
-									// Set display name to search folder.
-									$searchStore = $GLOBALS["mapisession"]->openMessageStore(hex2bin($searchStoreEntryId));
-									$searchFolder = mapi_msgstore_openentry($searchStore, $entryid);
-									mapi_setprops($searchFolder, [
-										PR_DISPLAY_NAME => $action["props"]["display_name"],
-									]);
-									mapi_savechanges($searchFolder);
-									$this->createLinkedSearchFolder($searchFolder);
-								}
-								else {
-									$this->addToFavorite($store, $entryid);
-								}
-								break;
+					case "foldersize":
+						$folders = [];
+
+						$folder = mapi_msgstore_openentry($store, $entryid);
+						$data = $this->getFolderProps($store, $folder);
+
+						$info = $this->getFolderSize($store, $folder, '', $folders);
+
+						// It could be that the $props already contains the data,
+						// this happens when the folder is the IPM_SUBTREE and the
+						// folder size is read directly from the store. Adjust
+						// total_size accordingly.
+						if (isset($data["props"]["store_size"])) {
+							if (!isset($data["props"]["message_size"])) {
+								$data["props"]["message_size"] = $data["props"]["store_size"];
 							}
+							$data["props"]["total_message_size"] = $data["props"]["store_size"] + $info["total_size"];
 						}
 						else {
-							// save folder
-							$folder = mapi_msgstore_openentry($store, hex2bin($action["entryid"]));
-							$this->save($store, $folder, $action);
-							if ($data["props"]["container_class"] === "IPF.Contact") {
-								$GLOBALS["bus"]->notify(ADDRESSBOOK_ENTRYID, OBJECT_SAVE);
-							}
-							$this->sendFeedback(true, []);
+							$data["props"]["message_size"] = $info["size"];
+							$data["props"]["total_message_size"] = $info["total_size"];
 						}
-					}
-					else {
-						// no entryid, create new folder
-						if ($store && $parententryid && isset($action["props"]["display_name"], $action["props"]["container_class"])) {
+						$data["folders"] = [
+							"item" => $folders,
+						];
+
+						// return response
+						$this->addActionData("item", $data);
+						$GLOBALS["bus"]->addData($this->getResponseData());
+						break;
+
+					case "delete":
+						if (!$store || !$parententryid || !$entryid) {
+							break;
+						}
+						if (!isset($action["message_action"], $action["message_action"]["action_type"]) ||
+							$action["message_action"]["action_type"] !== "removefavorites") {
+							$this->deleteFolder($store, $parententryid, $entryid, $action);
+							break;
+						}
+						if (!isset($action["message_action"]["isSearchFolder"]) ||
+							!$action["message_action"]["isSearchFolder"]) {
+							$this->removeFromFavorite($entryid);
+							break;
+						}
+						$result = $this->deleteSearchFolder($store, $parententryid, $entryid, $action);
+						dump($result, '$result');
+						if ($result) {
+							$this->sendFeedback(true);
+						}
+						break;
+
+					case "save":
+						if (!$store || !$parententryid) {
+							break;
+						}
+						if ($entryid) {
+							// The "message_action" object has been set, check the action_type field for
+							// the exact action which must be taken.
+							// Supported actions:
+							//   - copy: Copy the folder to the new destination folder
+							//   - move: Move the folder to the new destination folder
+							//   - emptyfolder: Delete all items within the folder
+							//   - readflags: Mark all items within the folder as read
+							//   - addtofavorites: Add the folder to "favorites"
+							if (!isset($action["message_action"]["isSearchFolder"])) {
+								$folder = mapi_msgstore_openentry($store, $entryid);
+								$data = $this->getFolderProps($store, $folder);
+							}
 							if (isset($action["message_action"], $action["message_action"]["action_type"])) {
-								// We need to create new search folder under the favorites folder
-								// based on give search folder info.
-								if ($action["message_action"]["action_type"] === "addtofavorites") {
-									$storeEntryId = $action["message_action"]["search_store_entryid"];
-									$searchFolderEntryId = $action["message_action"]["search_folder_entryid"];
+								switch ($action["message_action"]["action_type"]) {
+									case "copy":
+									case "move":
+										$destentryid = false;
+										if (isset($action["message_action"]["destination_parent_entryid"])) {
+											$destentryid = hex2bin($action["message_action"]["destination_parent_entryid"]);
+										}
 
-									// Get the search folder and search criteria using $storeEntryId and $searchFolderEntryId.
-									$Store = $GLOBALS["mapisession"]->openMessageStore(hex2bin($storeEntryId));
-									$searchFolder = mapi_msgstore_openentry($Store, hex2bin($searchFolderEntryId));
-									$searchCriteria = mapi_folder_getsearchcriteria($searchFolder);
+										$deststore = $store;
+										if (isset($action["message_action"]["destination_store_entryid"])) {
+											$deststore = $GLOBALS['mapisession']->openMessageStore(hex2bin($action["message_action"]["destination_store_entryid"]));
+										}
 
-									// Get FINDERS_ROOT folder from store.
-									$finderRootFolder = mapi_getprops($Store, [PR_FINDER_ENTRYID]);
-									$searchFolderRoot = mapi_msgstore_openentry($Store, $finderRootFolder[PR_FINDER_ENTRYID]);
+										if ($destentryid && $deststore) {
+											$this->copyFolder($store, $parententryid, $entryid, $destentryid, $deststore, $action["message_action"]["action_type"] == "move");
+										}
+										if ($data["props"]["container_class"] === "IPF.Contact") {
+											$GLOBALS["bus"]->notify(ADDRESSBOOK_ENTRYID, OBJECT_SAVE);
+										}
+										break;
 
-									// Create new search folder in FINDERS_ROOT folder and set the search
-									// criteria in newly created search folder.
-									$newSearchFolder = mapi_folder_createfolder($searchFolderRoot, $action["props"]["display_name"], '', 0, FOLDER_SEARCH);
-									$subfolder_flag = 0;
-									if (isset($action["subfolders"]) && $action["subfolders"] == "true") {
-										$subfolder_flag = RECURSIVE_SEARCH;
-									}
-									mapi_folder_setsearchcriteria($newSearchFolder, $searchCriteria['restriction'], $searchCriteria['folderlist'], $subfolder_flag);
+									case "emptyfolder":
+										$this->emptyFolder($store, $entryid);
+										break;
 
-									// Sleep for 1 seconds initially, since it usually takes ~  1 seconds to fill the search folder.
-									sleep(1);
-									$this->createLinkedSearchFolder($newSearchFolder);
+									case "readflags":
+										$this->setReadFlags($store, $entryid);
+										break;
+
+									case "addtofavorites":
+										if (isset($action["message_action"]["isSearchFolder"]) && $action["message_action"]["isSearchFolder"]) {
+											$searchStoreEntryId = $action["message_action"]["search_store_entryid"];
+											// Set display name to search folder.
+											$searchStore = $GLOBALS["mapisession"]->openMessageStore(hex2bin((string) $searchStoreEntryId));
+											$searchFolder = mapi_msgstore_openentry($searchStore, $entryid);
+											mapi_setprops($searchFolder, [
+												PR_DISPLAY_NAME => $action["props"]["display_name"],
+											]);
+											mapi_savechanges($searchFolder);
+											$this->createLinkedSearchFolder($searchFolder);
+										}
+										else {
+											$this->addToFavorite($store, $entryid);
+										}
+										break;
 								}
 							}
 							else {
-								$this->addFolder($store, $parententryid, $action["props"]["display_name"], $action["props"]["container_class"]);
+								// save folder
+								$folder = mapi_msgstore_openentry($store, hex2bin((string) $action["entryid"]));
+								$this->save($store, $folder, $action);
+								if ($data["props"]["container_class"] === "IPF.Contact") {
+									$GLOBALS["bus"]->notify(ADDRESSBOOK_ENTRYID, OBJECT_SAVE);
+								}
+								$this->sendFeedback(true, []);
 							}
 						}
-						if ($action["props"]["container_class"] === "IPF.Contact") {
-							$GLOBALS["bus"]->notify(ADDRESSBOOK_ENTRYID, OBJECT_SAVE);
-						}
-					}
-					break;
+						else {
+							// no entryid, create new folder
+							if ($store && $parententryid && isset($action["props"]["display_name"], $action["props"]["container_class"])) {
+								if (isset($action["message_action"], $action["message_action"]["action_type"])) {
+									// We need to create new search folder under the favorites folder
+									// based on give search folder info.
+									if ($action["message_action"]["action_type"] === "addtofavorites") {
+										$storeEntryId = $action["message_action"]["search_store_entryid"];
+										$searchFolderEntryId = $action["message_action"]["search_folder_entryid"];
 
-				case "closesharedfolder":
-					if (isset($action["folder_type"]) && $action["folder_type"] != "all") {
-						// We're closing a Shared folder, check if we still have other
-						// folders for the same user opened, if not we can safely close
-						// the usrstore.
-						$stores = $GLOBALS["settings"]->get("zarafa/v1/contexts/hierarchy/shared_stores/" . strtolower(bin2hex($action["user_name"])));
-						if (!isset($stores) || empty($stores) || (count($stores) == 1 && isset($stores[$action["folder_type"]]))) {
-							$entryid = $GLOBALS["mapisession"]->removeUserStore($action["user_name"]);
+										// Get the search folder and search criteria using $storeEntryId and $searchFolderEntryId.
+										$Store = $GLOBALS["mapisession"]->openMessageStore(hex2bin((string) $storeEntryId));
+										$searchFolder = mapi_msgstore_openentry($Store, hex2bin((string) $searchFolderEntryId));
+										$searchCriteria = mapi_folder_getsearchcriteria($searchFolder);
+
+										// Get FINDERS_ROOT folder from store.
+										$finderRootFolder = mapi_getprops($Store, [PR_FINDER_ENTRYID]);
+										$searchFolderRoot = mapi_msgstore_openentry($Store, $finderRootFolder[PR_FINDER_ENTRYID]);
+
+										// Create new search folder in FINDERS_ROOT folder and set the search
+										// criteria in newly created search folder.
+										$newSearchFolder = mapi_folder_createfolder($searchFolderRoot, $action["props"]["display_name"], '', 0, FOLDER_SEARCH);
+										$subfolder_flag = 0;
+										if (isset($action["subfolders"]) && $action["subfolders"] == "true") {
+											$subfolder_flag = RECURSIVE_SEARCH;
+										}
+										mapi_folder_setsearchcriteria($newSearchFolder, $searchCriteria['restriction'], $searchCriteria['folderlist'], $subfolder_flag);
+
+										// Sleep for 1 seconds initially, since it usually takes ~  1 seconds to fill the search folder.
+										sleep(1);
+										$this->createLinkedSearchFolder($newSearchFolder);
+									}
+								}
+								else {
+									$this->addFolder($store, $parententryid, $action["props"]["display_name"], $action["props"]["container_class"]);
+								}
+							}
+							if ($action["props"]["container_class"] === "IPF.Contact") {
+								$GLOBALS["bus"]->notify(ADDRESSBOOK_ENTRYID, OBJECT_SAVE);
+							}
+						}
+						break;
+
+					case "closesharedfolder":
+						if (isset($action["folder_type"]) && $action["folder_type"] != "all") {
+							// We're closing a Shared folder, check if we still have other
+							// folders for the same user opened, if not we can safely close
+							// the usrstore.
+							$stores = $GLOBALS["settings"]->get("zarafa/v1/contexts/hierarchy/shared_stores/" . strtolower(bin2hex((string) $action["user_name"])));
+							if (!isset($stores) || empty($stores) || (count($stores) == 1 && isset($stores[$action["folder_type"]]))) {
+								$entryid = $GLOBALS["mapisession"]->removeUserStore($action["user_name"]);
+							}
+							else {
+								$entryid = $GLOBALS["mapisession"]->getStoreEntryIdOfUser($action["user_name"]);
+								$this->removeFromFavorite(hex2bin((string) $action["entryid"]), $store, PR_WLINK_ENTRYID, false);
+							}
 						}
 						else {
-							$entryid = $GLOBALS["mapisession"]->getStoreEntryIdOfUser($action["user_name"]);
-							$this->removeFromFavorite(hex2bin($action["entryid"]), $store, PR_WLINK_ENTRYID, false);
+							// We're closing a Shared Store, simply remove it from the session.
+							$entryid = $GLOBALS["mapisession"]->removeUserStore($action["user_name"]);
+
+							if (isset($action["remove_favorites"]) && $action["remove_favorites"]) {
+								$this->removeFromFavorite(hex2bin((string) $action["store_entryid"]), $store, PR_WLINK_STORE_ENTRYID, false);
+							}
 						}
-					}
-					else {
-						// We're closing a Shared Store, simply remove it from the session.
-						$entryid = $GLOBALS["mapisession"]->removeUserStore($action["user_name"]);
 
-						if (isset($action["remove_favorites"]) && $action["remove_favorites"]) {
-							$this->removeFromFavorite(hex2bin($action["store_entryid"]), $store, PR_WLINK_STORE_ENTRYID, false);
+						$data = [];
+						$data["store_entryid"] = bin2hex((string) $entryid);
+						if (isset($action["folder_type"])) {
+							$data["folder_type"] = $action["folder_type"];
 						}
-					}
 
-					$data = [];
-					$data["store_entryid"] = bin2hex($entryid);
-					if (isset($action["folder_type"])) {
-						$data["folder_type"] = $action["folder_type"];
-					}
-
-					$this->addActionData("delete", $data);
-					$GLOBALS["bus"]->addData($this->getResponseData());
-					$GLOBALS["bus"]->notify(ADDRESSBOOK_ENTRYID, OBJECT_SAVE);
-					break;
-
-				case "opensharedfolder":
-					$username = strtolower($action["user_name"]);
-					$store = $GLOBALS["mapisession"]->addUserStore($username);
-					if (!$store) {
+						$this->addActionData("delete", $data);
+						$GLOBALS["bus"]->addData($this->getResponseData());
+						$GLOBALS["bus"]->notify(ADDRESSBOOK_ENTRYID, OBJECT_SAVE);
 						break;
-					}
 
-					$options = [$username => [$action["folder_type"] => $action]];
-					$data = $GLOBALS["operations"]->getHierarchyList($this->list_properties, HIERARCHY_GET_ONE, $store, $options, $username);
-
-					if (empty($data["item"][0]["folders"]["item"])) {
-						throw new MAPIException(null, MAPI_E_NO_ACCESS);
-					}
-
-					$folders = count($data["item"][0]["folders"]["item"]);
-					if ($folders === 0) {
-						throw new MAPIException(null, MAPI_E_NO_ACCESS);
-					}
-
-					$noPermissionFolders = array_filter($data['item'][0]['folders']['item'], function ($item) {
-						return $item['props']['access'] === 0;
-					});
-					if (count($noPermissionFolders) >= $folders) {
-						// Throw an exception that we couldn't open the shared store,
-						// lets have processException() fill in our error message.
-						throw new MAPIException(null, MAPI_E_NO_ACCESS);
-					}
-
-					$this->addActionData("list", $data);
-					$GLOBALS["bus"]->addData($this->getResponseData());
-					$GLOBALS["bus"]->notify(ADDRESSBOOK_ENTRYID, OBJECT_SAVE);
-					break;
-
-				case "sharedstoreupdate":
-					$supported_types = ['inbox' => 1, 'all' => 1];
-					$users = $GLOBALS["settings"]->get("zarafa/v1/contexts/hierarchy/shared_stores", []);
-
-					foreach ($users as $username => $data) {
-						$key = array_keys($data)[0];
-						$folder_type = $data[$key]['folder_type'];
-
-						if (!isset($supported_types[$folder_type])) {
-							continue;
+					case "opensharedfolder":
+						$username = strtolower((string) $action["user_name"]);
+						$store = $GLOBALS["mapisession"]->addUserStore($username);
+						if (!$store) {
+							break;
 						}
 
-						$GLOBALS["bus"]->notify(REQUEST_ENTRYID, HIERARCHY_UPDATE, [strtolower(hex2bin($username)), $folder_type]);
-					}
+						$options = [$username => [$action["folder_type"] => $action]];
+						$data = $GLOBALS["operations"]->getHierarchyList($this->list_properties, HIERARCHY_GET_ONE, $store, $options, $username);
 
-					$this->sendFeedback(true);
-					break;
+						if (empty($data["item"][0]["folders"]["item"])) {
+							throw new MAPIException(null, MAPI_E_NO_ACCESS);
+						}
 
-				default:
-					$this->handleUnknownActionType($actionType);
+						$folders = count($data["item"][0]["folders"]["item"]);
+						if ($folders === 0) {
+							throw new MAPIException(null, MAPI_E_NO_ACCESS);
+						}
+
+						$noPermissionFolders = array_filter($data['item'][0]['folders']['item'], fn ($item) => $item['props']['access'] === 0);
+						if (count($noPermissionFolders) >= $folders) {
+							// Throw an exception that we couldn't open the shared store,
+							// lets have processException() fill in our error message.
+							throw new MAPIException(null, MAPI_E_NO_ACCESS);
+						}
+
+						$this->addActionData("list", $data);
+						$GLOBALS["bus"]->addData($this->getResponseData());
+						$GLOBALS["bus"]->notify(ADDRESSBOOK_ENTRYID, OBJECT_SAVE);
+						break;
+
+					case "sharedstoreupdate":
+						$supported_types = ['inbox' => 1, 'all' => 1];
+						$users = $GLOBALS["settings"]->get("zarafa/v1/contexts/hierarchy/shared_stores", []);
+
+						foreach ($users as $username => $data) {
+							$key = array_keys($data)[0];
+							$folder_type = $data[$key]['folder_type'];
+
+							if (!isset($supported_types[$folder_type])) {
+								continue;
+							}
+
+							$GLOBALS["bus"]->notify(REQUEST_ENTRYID, HIERARCHY_UPDATE, [strtolower(hex2bin((string) $username)), $folder_type]);
+						}
+
+						$this->sendFeedback(true);
+						break;
+
+					default:
+						$this->handleUnknownActionType($actionType);
 				}
 			}
 			catch (MAPIException $e) {
@@ -369,6 +373,7 @@ class HierarchyModule extends Module {
 	 * @param string     $entryid       entryid of the folder
 	 * @param array      $action        the action data, sent by the client
 	 */
+	#[Override]
 	public function handleException(&$e, $actionType = null, $store = null, $parententryid = null, $entryid = null, $action = null) {
 		if (is_null($e->displayMessage)) {
 			switch ($actionType) {
@@ -453,35 +458,21 @@ class HierarchyModule extends Module {
 							}
 							else {
 								// Exception generated while renaming folder.
-								switch ($e->getCode()) {
-									case MAPI_E_NO_ACCESS:
-										$e->setDisplayMessage(_("You have insufficient privileges to rename this folder."));
-										break;
-
-									case MAPI_E_COLLISION:
-										$e->setDisplayMessage(_("A folder with this name already exists. Use another name."));
-										break;
-
-									default:
-										$e->setDisplayMessage(_("Could not rename folder."));
-								}
+								match ($e->getCode()) {
+									MAPI_E_NO_ACCESS => $e->setDisplayMessage(_("You have insufficient privileges to rename this folder.")),
+									MAPI_E_COLLISION => $e->setDisplayMessage(_("A folder with this name already exists. Use another name.")),
+									default => $e->setDisplayMessage(_("Could not rename folder.")),
+								};
 							}
 						}
 					}
 					else {
 						// Exception generated while creating new folder.
-						switch ($e->getCode()) {
-							case MAPI_E_NO_ACCESS:
-								$e->setDisplayMessage(_("You have insufficient privileges to create this folder."));
-								break;
-
-							case MAPI_E_COLLISION:
-								$e->setDisplayMessage(_("A folder with this name already exists. Use another name."));
-								break;
-
-							default:
-								$e->setDisplayMessage(_("Could not create folder."));
-						}
+						match ($e->getCode()) {
+							MAPI_E_NO_ACCESS => $e->setDisplayMessage(_("You have insufficient privileges to create this folder.")),
+							MAPI_E_COLLISION => $e->setDisplayMessage(_("A folder with this name already exists. Use another name.")),
+							default => $e->setDisplayMessage(_("Could not create folder.")),
+						};
 					}
 					break;
 
@@ -518,7 +509,7 @@ class HierarchyModule extends Module {
 	}
 
 	/**
-	 * Add folder's properties to response data. This function doesn't add persmission details yet.
+	 * Add folder's properties to response data. This function doesn't add permission details yet.
 	 *
 	 * @param resource $store      mapi store of the folder
 	 * @param string   $entryid    entryid of the folder
@@ -577,7 +568,7 @@ class HierarchyModule extends Module {
 
 		// replace "IPM_SUBTREE" with the display name of the store, and use the store message size
 		$store_props = mapi_getprops($store, [PR_IPM_SUBTREE_ENTRYID]);
-		if ($data["entryid"] == bin2hex($store_props[PR_IPM_SUBTREE_ENTRYID])) {
+		if ($data["entryid"] == bin2hex((string) $store_props[PR_IPM_SUBTREE_ENTRYID])) {
 			$store_props = mapi_getprops($store, [PR_DISPLAY_NAME, PR_MESSAGE_SIZE_EXTENDED,
 				PR_CONTENT_COUNT, PR_QUOTA_WARNING_THRESHOLD, PR_PROHIBIT_SEND_QUOTA, PR_PROHIBIT_RECEIVE_QUOTA, ]);
 			$data["props"]["display_name"] = $store_props[PR_DISPLAY_NAME];
@@ -644,9 +635,9 @@ class HierarchyModule extends Module {
 
 			if ($hide !== true) {
 				array_push($subfolders, [
-					"entryid" => bin2hex($row[PR_ENTRYID]),
-					"parent_entryid" => bin2hex($row[PR_PARENT_ENTRYID]),
-					"store_entryid" => bin2hex($row[PR_STORE_ENTRYID]),
+					"entryid" => bin2hex((string) $row[PR_ENTRYID]),
+					"parent_entryid" => bin2hex((string) $row[PR_PARENT_ENTRYID]),
+					"store_entryid" => bin2hex((string) $row[PR_STORE_ENTRYID]),
 					"props" => [
 						"folder_pathname" => $subpath, // This equals PR_FOLDER_PATHNAME, which is not supported by Gromox
 						"display_name" => $row[PR_DISPLAY_NAME],
@@ -673,7 +664,7 @@ class HierarchyModule extends Module {
 	public function save($store, $folder, $action) {
 		// Rename folder
 		if (isset($action["props"]["display_name"])) {
-			$this->modifyFolder($store, hex2bin($action["entryid"]), $action["props"]["display_name"]);
+			$this->modifyFolder($store, hex2bin((string) $action["entryid"]), $action["props"]["display_name"]);
 		}
 
 		if (isset($action["props"]["comment"])) {
@@ -697,9 +688,9 @@ class HierarchyModule extends Module {
 	}
 
 	public function getFolderPermissions($folder) {
-		$eidObj = $GLOBALS["entryid"]->createMsgStoreEntryIdObj(hex2bin($this->store_entryid));
-		$cnUserPos = strrpos($eidObj['MailboxDN'], '/cn=');
-		$cnUserBase = ($cnUserPos !== false) ? substr($eidObj['MailboxDN'], 0, $cnUserPos) : '';
+		$eidObj = $GLOBALS["entryid"]->createMsgStoreEntryIdObj(hex2bin((string) $this->store_entryid));
+		$cnUserPos = strrpos((string) $eidObj['MailboxDN'], '/cn=');
+		$cnUserBase = ($cnUserPos !== false) ? substr((string) $eidObj['MailboxDN'], 0, $cnUserPos) : '';
 		$grants = mapi_zarafa_getpermissionrules($folder, ACCESS_TYPE_GRANT);
 		foreach ($grants as $id => $grant) {
 			// The mapi_zarafa_getpermissionrules returns the entryid in the userid key
@@ -736,9 +727,9 @@ class HierarchyModule extends Module {
 
 		// first, get the current permissions because we need to delete all current acl's
 		$curAcls = mapi_zarafa_getpermissionrules($folder, ACCESS_TYPE_GRANT);
-		$eidObj = $GLOBALS["entryid"]->createMsgStoreEntryIdObj(hex2bin($this->store_entryid));
-		$cnUserPos = strrpos($eidObj['MailboxDN'], '/cn=');
-		$cnUserBase = ($cnUserPos !== false) ? substr($eidObj['MailboxDN'], 0, $cnUserPos) : '';
+		$eidObj = $GLOBALS["entryid"]->createMsgStoreEntryIdObj(hex2bin((string) $this->store_entryid));
+		$cnUserPos = strrpos((string) $eidObj['MailboxDN'], '/cn=');
+		$cnUserBase = ($cnUserPos !== false) ? substr((string) $eidObj['MailboxDN'], 0, $cnUserPos) : '';
 		foreach ($curAcls as &$curAcl) {
 			$curAcl = $this->getUserInfo($curAcl, $cnUserBase);
 		}
@@ -746,7 +737,7 @@ class HierarchyModule extends Module {
 		// First check which permissions should be removed from the existing list
 		if (isset($permissions['remove']) && !empty($permissions['remove'])) {
 			foreach ($permissions['remove'] as $i => &$delAcl) {
-				$userid = hex2bin($delAcl['entryid']);
+				$userid = hex2bin((string) $delAcl['entryid']);
 				foreach ($curAcls as $aclIndex => &$curAcl) {
 					// do not remove default and anonymous grants
 					if ($curAcl['userid'] === $userid && $curAcl['memberid'] != 0 && $curAcl['memberid'] != 0xFFFFFFFF) {
@@ -774,7 +765,7 @@ class HierarchyModule extends Module {
 					array_push($permissions['add'], $modAcl);
 				}
 				else {
-					$userid = hex2bin($entryid);
+					$userid = hex2bin((string) $entryid);
 					foreach ($curAcls as $aclIndex => &$curAcl) {
 						if ($curAcl['userid'] === $userid) {
 							$curAcl['rights'] = $modAcl['rights'];
@@ -796,7 +787,7 @@ class HierarchyModule extends Module {
 			foreach ($permissions['add'] as $i => &$addAcl) {
 				$curAcls[$cnt++] = [
 					'type' => ACCESS_TYPE_GRANT,
-					'userid' => hex2bin($addAcl['entryid']),
+					'userid' => hex2bin((string) $addAcl['entryid']),
 					'rights' => $addAcl['rights'],
 					'state' => RIGHT_NEW | RIGHT_AUTOUPDATE_DENIED,
 					'memberid' => 0, // for new permissions memberid may be any number
@@ -839,7 +830,7 @@ class HierarchyModule extends Module {
 			$grant["fullname"] = _("default");
 			$grant["username"] = _("default");
 			$grant["entryid"] = $entryid;
-			$grant["userid"] = hex2bin($entryid);
+			$grant["userid"] = hex2bin((string) $entryid);
 
 			return $grant;
 		}
@@ -849,7 +840,7 @@ class HierarchyModule extends Module {
 			$grant["fullname"] = _("anonymous");
 			$grant["username"] = _("anonymous");
 			$grant["entryid"] = $entryid;
-			$grant["userid"] = hex2bin($entryid);
+			$grant["userid"] = hex2bin((string) $entryid);
 
 			return $grant;
 		}
@@ -862,12 +853,12 @@ class HierarchyModule extends Module {
 
 			$grant["fullname"] = $props[PR_DISPLAY_NAME];
 			$grant["username"] = $props[PR_ACCOUNT];
-			$grant["entryid"] = bin2hex($grant["userid"]);
+			$grant["entryid"] = bin2hex((string) $grant["userid"]);
 
 			return $grant;
 		}
 
-		error_log(sprintf("No user with the entryid %s found (memberid: %s)", bin2hex($grant["userid"]), $grant["memberid"]));
+		error_log(sprintf("No user with the entryid %s found (memberid: %s)", bin2hex((string) $grant["userid"]), $grant["memberid"]));
 
 		// default return stuff
 		return [
@@ -934,7 +925,7 @@ class HierarchyModule extends Module {
 				$hierarchyTable = mapi_folder_gethierarchytable($finderFolder, MAPI_DEFERRED_ERRORS);
 				$finderHierarchyTables[$props[PR_FINDER_ENTRYID]] = $hierarchyTable;
 			}
-			catch (Exception $e) {
+			catch (Exception) {
 			}
 		}
 
@@ -952,7 +943,7 @@ class HierarchyModule extends Module {
 					if (isset($message[$prop]) && $GLOBALS['entryid']->compareEntryIds($message[$prop], $entryid)) {
 						mapi_folder_deletemessages($commonViewsFolder, [$message[PR_ENTRYID]]);
 						if ($doNotify) {
-							$GLOBALS["bus"]->notify(bin2hex($message[PR_ENTRYID]), OBJECT_SAVE, $message);
+							$GLOBALS["bus"]->notify(bin2hex((string) $message[PR_ENTRYID]), OBJECT_SAVE, $message);
 						}
 					}
 					elseif (isset($message[PR_WLINK_STORE_ENTRYID])) {
@@ -1001,7 +992,7 @@ class HierarchyModule extends Module {
 
 		if (!empty($messages)) {
 			foreach ($messages as $message) {
-				if (bin2hex($message[PR_WB_SF_ID]) === $searchFolderId) {
+				if (bin2hex((string) $message[PR_WB_SF_ID]) === $searchFolderId) {
 					mapi_folder_deletemessages($commonViewsFolder, [$message[PR_ENTRYID]]);
 				}
 			}
@@ -1044,7 +1035,7 @@ class HierarchyModule extends Module {
 		$props = mapi_getprops($folder, [PR_EXTENDED_FOLDER_FLAGS]);
 		// for more information about PR_EXTENDED_FOLDER_FLAGS go through this link
 		// https://msdn.microsoft.com/en-us/library/ee203919(v=exchg.80).aspx
-		$flags = unpack("H2ExtendedFlags-Id/H2ExtendedFlags-Cb/H8ExtendedFlags-Data/H2SearchFolderTag-Id/H2SearchFolderTag-Cb/H8SearchFolderTag-Data/H2SearchFolderId-Id/H2SearchFolderId-Cb/H32SearchFolderId-Data", $props[PR_EXTENDED_FOLDER_FLAGS]);
+		$flags = unpack("H2ExtendedFlags-Id/H2ExtendedFlags-Cb/H8ExtendedFlags-Data/H2SearchFolderTag-Id/H2SearchFolderTag-Cb/H8SearchFolderTag-Data/H2SearchFolderId-Id/H2SearchFolderId-Cb/H32SearchFolderId-Data", (string) $props[PR_EXTENDED_FOLDER_FLAGS]);
 		$searchFolderId = $flags["SearchFolderId-Data"];
 		$this->removeSearchLinkMessage($searchFolderId);
 
@@ -1125,7 +1116,7 @@ class HierarchyModule extends Module {
 	public function deleteFolder($store, $parententryid, $entryid, $action) {
 		$props = [];
 		$pubStore = $GLOBALS["mapisession"]->isPublicStore($action['store_entryid'] ?? '');
-		$result = $GLOBALS["operations"]->deleteFolder($store, $parententryid, $entryid, $props, isset($action['soft_delete']) ? $action['soft_delete'] : false, $pubStore ? true : false);
+		$result = $GLOBALS["operations"]->deleteFolder($store, $parententryid, $entryid, $props, $action['soft_delete'] ?? false, $pubStore ? true : false);
 
 		// Indicate if the delete succeedded
 		$this->sendFeedback($result);
@@ -1267,7 +1258,7 @@ class HierarchyModule extends Module {
 				// if move folder then refresh parent of source folder
 				$sourcefolder = mapi_msgstore_openentry($store, $parententryid);
 				$folderProps = mapi_getprops($sourcefolder, [PR_ENTRYID, PR_STORE_ENTRYID]);
-				$GLOBALS["bus"]->notify(bin2hex($folderProps[PR_ENTRYID]), OBJECT_SAVE, $folderProps);
+				$GLOBALS["bus"]->notify(bin2hex((string) $folderProps[PR_ENTRYID]), OBJECT_SAVE, $folderProps);
 			}
 			else {
 				$this->sendFeedback(true);
@@ -1309,14 +1300,14 @@ class HierarchyModule extends Module {
 				foreach ($subfolders as $subfolder) {
 					$folderObject = mapi_msgstore_openentry($deststore, $subfolder[PR_ENTRYID]);
 					$folderProps = mapi_getprops($folderObject, [PR_ENTRYID, PR_STORE_ENTRYID]);
-					$GLOBALS["bus"]->notify(bin2hex($subfolder[PR_ENTRYID]), OBJECT_SAVE, $folderProps);
+					$GLOBALS["bus"]->notify(bin2hex((string) $subfolder[PR_ENTRYID]), OBJECT_SAVE, $folderProps);
 				}
 			}
 
 			// Now update destination folder
 			$folder = mapi_msgstore_openentry($deststore, $destfolderentryid);
 			$folderProps = mapi_getprops($folder, [PR_ENTRYID, PR_STORE_ENTRYID]);
-			$GLOBALS["bus"]->notify(bin2hex($folderProps[PR_ENTRYID]), OBJECT_SAVE, $folderProps);
+			$GLOBALS["bus"]->notify(bin2hex((string) $folderProps[PR_ENTRYID]), OBJECT_SAVE, $folderProps);
 		}
 		else {
 			if ($moveFolder) {
