@@ -76,6 +76,7 @@ class ListModule extends Module {
 	/**
 	 * Executes all the actions in the $data variable.
 	 */
+	#[Override]
 	public function execute() {
 		foreach ($this->data as $actionType => $action) {
 			if (isset($actionType)) {
@@ -94,10 +95,7 @@ class ListModule extends Module {
 							$this->handleUnknownActionType($actionType);
 					}
 				}
-				catch (MAPIException $e) {
-					$this->processException($e, $actionType, $store, $parententryid, $entryid, $action);
-				}
-				catch (SearchException $e) {
+				catch (MAPIException|SearchException $e) {
 					$this->processException($e, $actionType, $store, $parententryid, $entryid, $action);
 				}
 			}
@@ -116,6 +114,7 @@ class ListModule extends Module {
 	 * @param string     $entryid       entryid of the message/folder
 	 * @param array      $action        the action data, sent by the client
 	 */
+	#[Override]
 	public function handleException(&$e, $actionType = null, $store = null, $parententryid = null, $entryid = null, $action = null) {
 		if (is_null($e->displayMessage)) {
 			$hexEntryid = $entryid != null ? bin2hex($entryid) : 'null';
@@ -165,7 +164,7 @@ class ListModule extends Module {
 		}
 
 		$isSearchFolder = isset($action['search_folder_entryid']);
-		$entryid = $isSearchFolder ? hex2bin($action['search_folder_entryid']) : $entryid;
+		$entryid = $isSearchFolder ? hex2bin((string) $action['search_folder_entryid']) : $entryid;
 
 		// Get the table and merge the arrays
 		$data = $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $this->sort, $this->start, $limit, $this->restriction);
@@ -222,7 +221,7 @@ class ListModule extends Module {
 	 * @param string $actionType the action type, sent by the client
 	 */
 	public function search($store, $entryid, $action, $actionType) {
-		$useSearchFolder = isset($action["use_searchfolder"]) ? $action["use_searchfolder"] : false;
+		$useSearchFolder = $action["use_searchfolder"] ?? false;
 		if (!$useSearchFolder) {
 			/*
 			 * store doesn't support search folders so we can't use this
@@ -280,18 +279,11 @@ class ListModule extends Module {
 			// if error in creating search folder then send error to client
 			$errorInfo = [];
 
-			switch (mapi_last_hresult()) {
-				case MAPI_E_NO_ACCESS:
-					$errorInfo["error_message"] = _("Unable to perform search query, no permissions to create search folder.");
-					break;
-
-				case MAPI_E_NOT_FOUND:
-					$errorInfo["error_message"] = _("Unable to perform search query, search folder not found.");
-					break;
-
-				default:
-					$errorInfo["error_message"] = _("Unable to perform search query, store might not support searching.");
-			}
+			$errorInfo["error_message"] = match (mapi_last_hresult()) {
+				MAPI_E_NO_ACCESS => _("Unable to perform search query, no permissions to create search folder."),
+				MAPI_E_NOT_FOUND => _("Unable to perform search query, search folder not found."),
+				default => _("Unable to perform search query, store might not support searching."),
+			};
 
 			$errorInfo["original_error_message"] = _("Error in creating search folder.");
 
@@ -321,14 +313,14 @@ class ListModule extends Module {
 				// get entryids of original folders, and use it to set new search criteria
 				$entryids = [];
 				for ($index = 0; $index < count($this->sessionData['searchOriginalEntryids']); ++$index) {
-					$entryids[] = hex2bin($this->sessionData['searchOriginalEntryids'][$index]);
+					$entryids[] = hex2bin((string) $this->sessionData['searchOriginalEntryids'][$index]);
 				}
 			}
 			else {
 				// store entryids of original folders, so that can be used for re-setting the search criteria if needed
 				$this->sessionData['searchOriginalEntryids'] = [];
 				for ($index = 0, $len = count($entryids); $index < $len; ++$index) {
-					$this->sessionData['searchOriginalEntryids'][] = bin2hex($entryids[$index]);
+					$this->sessionData['searchOriginalEntryids'][] = bin2hex((string) $entryids[$index]);
 				}
 			}
 
@@ -337,7 +329,7 @@ class ListModule extends Module {
 		}
 
 		if (isset($this->sessionData['searchCriteriaCheck']) || $restrictionCheck == $this->sessionData['searchCriteriaCheck']) {
-			$folderEntryid = bin2hex($entryid);
+			$folderEntryid = bin2hex((string) $entryid);
 			if ($this->sessionData['searchOriginalEntryids'][0] !== $folderEntryid) {
 				$this->sessionData['searchOriginalEntryids'][0] = $folderEntryid;
 				mapi_folder_setsearchcriteria($searchFolder, $this->restriction, [$entryid], $subfolder_flag);
@@ -375,7 +367,7 @@ class ListModule extends Module {
 		}
 
 		// Get the table and merge the arrays
-		$table = $GLOBALS["operations"]->getTable($store, hex2bin($searchFolderEntryId), $this->properties, $this->sort, $this->start);
+		$table = $GLOBALS["operations"]->getTable($store, hex2bin((string) $searchFolderEntryId), $this->properties, $this->sort, $this->start);
 		$data = array_merge($data, $table);
 
 		$this->getDelegateFolderInfo($store);
@@ -464,7 +456,7 @@ class ListModule extends Module {
 			foreach ($items as $props) {
 				$sendItemToClient = false;
 
-				if (!array_key_exists(bin2hex($props[PR_ENTRYID]), $searchResults)) {
+				if (!array_key_exists(bin2hex((string) $props[PR_ENTRYID]), $searchResults)) {
 					$sendItemToClient = true;
 				}
 				else {
@@ -475,7 +467,7 @@ class ListModule extends Module {
 					 * that item has been modified since we have sent it to client
 					 */
 					// TODO if any item is deleted from search folder it will be not notified to client
-					if ($searchResults[bin2hex($props[PR_ENTRYID])] < $props[PR_LAST_MODIFICATION_TIME]) {
+					if ($searchResults[bin2hex((string) $props[PR_ENTRYID])] < $props[PR_LAST_MODIFICATION_TIME]) {
 						$sendItemToClient = true;
 					}
 				}
@@ -486,7 +478,7 @@ class ListModule extends Module {
 					array_push($listData, $GLOBALS["operations"]->getProps($message, $this->properties));
 
 					// store entryid => last_modification_time mapping
-					$searchResults[bin2hex($props[PR_ENTRYID])] = $props[PR_LAST_MODIFICATION_TIME];
+					$searchResults[bin2hex((string) $props[PR_ENTRYID])] = $props[PR_LAST_MODIFICATION_TIME];
 				}
 
 				// when we have more results then fit in the client, we break here,
@@ -541,7 +533,7 @@ class ListModule extends Module {
 	 */
 	public function stopSearch($store, $entryid, $action) {
 		// if no entryid is present in the request then get the search folder entryid from session data
-		$entryid = !empty($entryid) ? $entryid : (!empty($action['search_folder_entryid']) ? hex2bin($action['search_folder_entryid']) : null);
+		$entryid = !empty($entryid) ? $entryid : (!empty($action['search_folder_entryid']) ? hex2bin((string) $action['search_folder_entryid']) : null);
 
 		if (empty($entryid)) {
 			// still no entryid? sorry i can't help you anymore
@@ -638,7 +630,7 @@ class ListModule extends Module {
 					return $searchFolder;
 				}
 			}
-			catch (MAPIException $e) {
+			catch (MAPIException) {
 				// ignore error and continue creation of search folder
 				unset($this->sessionData['searchFolderEntryId']);
 			}
@@ -659,7 +651,7 @@ class ListModule extends Module {
 			$table = mapi_folder_gethierarchytable($searchFolderRoot, 0);
 			$rows = mapi_table_queryrows($table, [PR_DISPLAY_NAME, PR_ENTRYID], 0, 0xFFFF);
 			foreach ($rows as $row) {
-				if (strcasecmp($folderName, $row[PR_DISPLAY_NAME]) == 0) {
+				if (strcasecmp($folderName, (string) $row[PR_DISPLAY_NAME]) == 0) {
 					mapi_folder_deletefolder($searchFolderRoot, $row[PR_ENTRYID], DEL_FOLDERS | DEL_MESSAGES | DELETE_HARD_DELETE);
 					break;
 				}
@@ -667,7 +659,7 @@ class ListModule extends Module {
 			$searchFolder = mapi_folder_createfolder($searchFolderRoot, $folderName, '', OPEN_IF_EXISTS, FOLDER_SEARCH);
 
 			$props = mapi_getprops($searchFolder, [PR_ENTRYID]);
-			$this->sessionData['searchFolderEntryId'] = bin2hex($props[PR_ENTRYID]);
+			$this->sessionData['searchFolderEntryId'] = bin2hex((string) $props[PR_ENTRYID]);
 
 			// we have created new search folder so search criteria check should be removed
 			unset($this->sessionData['searchCriteriaCheck']);
@@ -724,7 +716,7 @@ class ListModule extends Module {
 	 */
 	public function sendSearchErrorToClient($store, $entryid, $action, $errorInfo) {
 		if ($errorInfo) {
-			$exception = new SearchException(isset($errorInfo["original_error_message"]) ? $errorInfo["original_error_message"] : $errorInfo['error_message'], mapi_last_hresult());
+			$exception = new SearchException($errorInfo["original_error_message"] ?? $errorInfo['error_message'], mapi_last_hresult());
 			$exception->setDisplayMessage($errorInfo['error_message']);
 
 			// after sending error, remove error data
@@ -951,7 +943,7 @@ class ListModule extends Module {
 							$userFound = false;
 							$seePrivate = false;
 							foreach ($localFreeBusyMessageProps[PR_SCHDINFO_DELEGATE_ENTRYIDS] as $key => $entryId) {
-								if ($GLOBALS['entryid']->compareEntryIds(bin2hex($userEntryId), bin2hex($entryId))) {
+								if ($GLOBALS['entryid']->compareEntryIds(bin2hex((string) $userEntryId), bin2hex((string) $entryId))) {
 									$userFound = true;
 									$seePrivate = $localFreeBusyMessageProps[PR_DELEGATE_FLAGS][$key];
 									break;
