@@ -40,6 +40,7 @@ class MailListModule extends ListModule {
 	/**
 	 * Executes all the actions in the $data variable.
 	 */
+	#[Override]
 	public function execute() {
 		$GLOBALS['PluginManager']->triggerHook("server.module.maillistmodule.execute.before", ['moduleObject' => &$this]);
 
@@ -86,10 +87,7 @@ class MailListModule extends ListModule {
 							$this->handleUnknownActionType($actionType);
 					}
 				}
-				catch (MAPIException $e) {
-					$this->processException($e, $actionType);
-				}
-				catch (SearchException $e) {
+				catch (MAPIException|SearchException $e) {
 					$this->processException($e, $actionType);
 				}
 			}
@@ -131,7 +129,7 @@ class MailListModule extends ListModule {
 
 			try {
 				$inboxProps = mapi_getprops($inbox, [PR_ENTRYID]);
-				$this->_inboxEntryId = bin2hex($inboxProps[PR_ENTRYID]);
+				$this->_inboxEntryId = bin2hex((string) $inboxProps[PR_ENTRYID]);
 			}
 			catch (MAPIException $e) {
 				// don't propagate this error to parent handlers, if store doesn't support it
@@ -169,7 +167,7 @@ class MailListModule extends ListModule {
 	 *
 	 * @param mixed $force
 	 *
-	 * @return int the numer of unread items in the Inbox folder
+	 * @return int the number of unread items in the Inbox folder
 	 */
 	public function getInboxTotalUnread($force = false) {
 		if ($this->_inboxTotalUnread === null || $force) {
@@ -191,6 +189,7 @@ class MailListModule extends ListModule {
 	 * @param string     $entryid       entryid of the message
 	 * @param array      $action        the action data, sent by the client
 	 */
+	#[Override]
 	public function handleException(&$e, $actionType = null, $store = null, $parententryid = null, $entryid = null, $action = null) {
 		if (is_null($e->displayMessage)) {
 			switch ($actionType) {
@@ -237,6 +236,7 @@ class MailListModule extends ListModule {
 	 * @param array|bool a custom set of properties to use instead of the properties stored in module
 	 * @param mixed $properties
 	 */
+	#[Override]
 	public function parseSortOrder($action, $map = false, $allow_multi_instance = false, $properties = false) {
 		if (isset($action['sort'])) {
 			// Check if the user wants to sort the maillist on flags.
