@@ -7,21 +7,11 @@ require_once __DIR__ . '/../exceptions/class.SearchException.php';
  * Superclass of every module. Many default functions are defined in this class.
  */
 class Module {
-	/**
-	 * @var int unique id of the class
-	 */
-	public $id;
-
 	/**
 	 * @var string entryid, which will be registered by the bus object
 	 */
 	public $entryid;
 
-	/**
-	 * @var array list of all actions, which is received from the client
-	 */
-	public $data;
-
 	/**
 	 * @var array list of the results, which is send to the client
 	 */
@@ -58,9 +48,7 @@ class Module {
 	 * @param int   $id   unique id
 	 * @param array $data list of all actions
 	 */
-	public function __construct($id, $data) {
-		$this->id = $id;
-		$this->data = $data;
+	public function __construct(public $id, public $data) {
 		$this->errors = [];
 		$this->responseData = [];
 		$this->sessionState = false;
@@ -72,7 +60,7 @@ class Module {
 		// It is requires for multi server environment where namespace differs.
 		// e.g. 'categories' => -2062020578, 'categories' => -2062610402,
 		if (isset($GLOBALS['properties'])) {
-			$GLOBALS['properties']->setStore($this->getActionStore($this->getActionData($data)));
+			$GLOBALS['properties']->setStore($this->getActionStore($this->getActionData($this->data)));
 		}
 	}
 
@@ -192,9 +180,7 @@ class Module {
 			}
 			Log::Write(
 				LOGLEVEL_ERROR,
-				"Module::handleException():" . $actionType . ": " . $e->displayMessage,
-				$e,
-				$action
+				"Module::handleException():" . $actionType . ": " . $e->displayMessage
 			);
 		}
 	}
@@ -360,15 +346,15 @@ class Module {
 				if (is_array($action["store_entryid"])) {
 					$store = [];
 					foreach ($action["store_entryid"] as $store_id) {
-						array_push($store, $GLOBALS["mapisession"]->openMessageStore(hex2bin($store_id)));
+						array_push($store, $GLOBALS["mapisession"]->openMessageStore(hex2bin((string) $store_id)));
 					}
 				}
-				elseif (ctype_xdigit($action["store_entryid"])) {
-					$store = $GLOBALS["mapisession"]->openMessageStore(hex2bin($action["store_entryid"]));
+				elseif (ctype_xdigit((string) $action["store_entryid"])) {
+					$store = $GLOBALS["mapisession"]->openMessageStore(hex2bin((string) $action["store_entryid"]));
 				}
 			}
 		}
-		catch (Exception $e) {
+		catch (Exception) {
 		}
 
 		return $store;
@@ -386,7 +372,7 @@ class Module {
 		$parententryid = false;
 
 		if (isset($action["parent_entryid"]) && !empty($action["parent_entryid"])) {
-			$parententryid = hex2bin($action["parent_entryid"]);
+			$parententryid = hex2bin((string) $action["parent_entryid"]);
 		}
 
 		return $parententryid;
@@ -407,11 +393,11 @@ class Module {
 			if (is_array($action["entryid"])) {
 				$entryid = [];
 				foreach ($action["entryid"] as $action_entryid) {
-					array_push($entryid, hex2bin($action_entryid));
+					array_push($entryid, hex2bin((string) $action_entryid));
 				}
 			}
 			else {
-				$entryid = hex2bin($action["entryid"]);
+				$entryid = hex2bin((string) $action["entryid"]);
 			}
 		}
 
@@ -473,7 +459,7 @@ class Module {
 	 * @return string module name
 	 */
 	public function getModuleName() {
-		return strtolower(get_class($this));
+		return strtolower(static::class);
 	}
 
 	/**
@@ -494,8 +480,7 @@ class Module {
 		);
 		Log::Write(
 			LOGLEVEL_ERROR,
-			"Module::handleUnknownActionType(): ERROR_ZARAFA : " . _("Could not process request data properly."),
-			sprintf(_("Unknown action type specified - %s"), $actionType)
+			"Module::handleUnknownActionType(): ERROR_ZARAFA : " . _("Could not process request data properly.")
 		);
 	}
 
