@@ -24,6 +24,7 @@ class ReminderItemModule extends ItemModule {
 	 * @param string $entryid       entryid of the message
 	 * @param array  $action        the action data, sent by the client
 	 */
+	#[Override]
 	public function save($store, $parententryid, $entryid, $action) {
 		$this->properties = $GLOBALS['properties']->getMailProperties();
 		$result = false;
@@ -38,7 +39,7 @@ class ReminderItemModule extends ItemModule {
 
 			// Set message flags
 			if (isset($action['props'], $action['props']['message_flags']) && $entryid) {
-				$msg_action = isset($action['message_action']) ? $action['message_action'] : false;
+				$msg_action = $action['message_action'] ?? false;
 				$result = $GLOBALS['operations']->setMessageFlag($store, $entryid, $action['props']['message_flags'], $msg_action, $messageProps);
 			}
 
@@ -59,6 +60,7 @@ class ReminderItemModule extends ItemModule {
 	 * @param string $entryid       entryid of the message
 	 * @param array  $action        the action data, sent by the client
 	 */
+	#[Override]
 	public function delete($store, $parententryid, $entryid, $action) {
 		$this->properties = $GLOBALS["properties"]->getReminderProperties();
 
@@ -107,7 +109,7 @@ class ReminderItemModule extends ItemModule {
 			}
 
 			$reminderTime = time() + ($snoozeTime * 60);
-			if (stripos($props[$this->properties["message_class"]], "IPM.Appointment") === 0) {
+			if (stripos((string) $props[$this->properties["message_class"]], "IPM.Appointment") === 0) {
 				if (isset($props[$this->properties["appointment_recurring"]]) && $props[$this->properties["appointment_recurring"]]) {
 					$recurrence = new Recurrence($store, $message);
 					$nextReminder = $recurrence->getNextReminderTime(time());
@@ -161,7 +163,7 @@ class ReminderItemModule extends ItemModule {
 			$newProps = [];
 			$props = mapi_getprops($message, $this->properties);
 
-			if (stripos($props[$this->properties["message_class"]], "IPM.Appointment") === 0) {
+			if (stripos((string) $props[$this->properties["message_class"]], "IPM.Appointment") === 0) {
 				if (isset($props[$this->properties["appointment_recurring"]]) && $props[$this->properties["appointment_recurring"]]) {
 					$recurrence = new Recurrence($store, $message);
 					// check for next reminder after "now" for the next instance
@@ -177,7 +179,7 @@ class ReminderItemModule extends ItemModule {
 					$newProps[$this->properties["reminder"]] = false;
 				}
 			}
-			elseif (stripos($props[$this->properties["message_class"]], "IPM.Task") === 0) {
+			elseif (stripos((string) $props[$this->properties["message_class"]], "IPM.Task") === 0) {
 				$newProps[$this->properties["reminder"]] = false;
 
 				if (isset($props[$this->properties['task_recurring']]) && $props[$this->properties['task_recurring']] == 1) {
@@ -220,6 +222,7 @@ class ReminderItemModule extends ItemModule {
 	 * @param string     $entryid       entryid of the message
 	 * @param array      $action        the action data, sent by the client
 	 */
+	#[Override]
 	public function handleException(&$e, $actionType = null, $store = null, $parententryid = null, $entryid = null, $action = null) {
 		if (is_null($e->displayMessage)) {
 			switch ($actionType) {
