@@ -20,6 +20,7 @@ class ReminderListModule extends ListModule {
 		$this->properties = $GLOBALS["properties"]->getReminderProperties();
 	}
 
+	#[Override]
 	public function execute() {
 		foreach ($this->data as $actionType => $action) {
 			$store = $GLOBALS["mapisession"]->getDefaultMessageStore();
@@ -27,14 +28,10 @@ class ReminderListModule extends ListModule {
 
 			if (isset($actionType)) {
 				try {
-					switch ($actionType) {
-						case "list":
-							$this->getReminders();
-							break;
-
-						default:
-							$this->handleUnknownActionType($actionType);
-					}
+					match ($actionType) {
+						"list" => $this->getReminders(),
+						default => $this->handleUnknownActionType($actionType),
+					};
 				}
 				catch (MAPIException $e) {
 					$this->processException($e, $actionType, $store, null, null, $action);
@@ -46,12 +43,9 @@ class ReminderListModule extends ListModule {
 	public function getReminderFolderEntryId($store) {
 		$root = mapi_msgstore_openentry($store);
 		$rootProps = mapi_getprops($root, [PR_REM_ONLINE_ENTRYID]);
-		if (isset($rootProps[PR_REM_ONLINE_ENTRYID])) {
-			return $rootProps[PR_REM_ONLINE_ENTRYID];
-		}
 
 		// Reminder folder didn't exist, create one
-		return $this->createReminderFolder($store);
+		return $rootProps[PR_REM_ONLINE_ENTRYID] ?? $this->createReminderFolder($store);
 	}
 
 	public function createReminderFolder($store) {
