@@ -26,6 +26,7 @@ class RulesModule extends Module {
 	/**
 	 * Executes all the actions in the $data variable.
 	 */
+	#[Override]
 	public function execute() {
 		foreach ($this->data as $actionType => $action) {
 			// Determine if the request contains multiple items or not. We couldn't add the storeEntryId to
@@ -46,7 +47,7 @@ class RulesModule extends Module {
 					// the user still tries this (probably hacking) we will not allow this
 					throw new MAPIException(_('Setting mail filters on the stores of other users is not allowed.'));
 				}
-				$store = $GLOBALS['mapisession']->openMessageStore(hex2bin($storeEntryid));
+				$store = $GLOBALS['mapisession']->openMessageStore(hex2bin((string) $storeEntryid));
 
 				switch ($actionType) {
 					case 'list':
@@ -308,6 +309,7 @@ class RulesModule extends Module {
 	 * @param string     $entryid       entryid of the message/folder
 	 * @param array      $action        the action data, sent by the client
 	 */
+	#[Override]
 	public function handleException(&$e, $actionType = null, $store = null, $parententryid = null, $entryid = null, $action = null) {
 		if (is_null($e->displayMessage)) {
 			switch ($actionType) {
