@@ -30,6 +30,7 @@ class StickyNoteListModule extends ListModule {
 	/**
 	 * Executes all the actions in the $data variable.
 	 */
+	#[Override]
 	public function execute() {
 		foreach ($this->data as $actionType => $action) {
 			if (isset($actionType)) {
@@ -37,26 +38,13 @@ class StickyNoteListModule extends ListModule {
 					$store = $this->getActionStore($action);
 					$entryid = $this->getActionEntryID($action);
 
-					switch ($actionType) {
-						case "list":
-							$this->messageList($store, $entryid, $action, $actionType);
-							break;
-
-						case "search":
-							$this->search($store, $entryid, $action, $actionType);
-							break;
-
-						case "updatesearch":
-							$this->updatesearch($store, $entryid, $action);
-							break;
-
-						case "stopsearch":
-							$this->stopSearch($store, $entryid, $action);
-							break;
-
-						default:
-							$this->handleUnknownActionType($actionType);
-					}
+					match ($actionType) {
+						"list" => $this->messageList($store, $entryid, $action, $actionType),
+						"search" => $this->search($store, $entryid, $action, $actionType),
+						"updatesearch" => $this->updatesearch($store, $entryid, $action),
+						"stopsearch" => $this->stopSearch($store, $entryid, $action),
+						default => $this->handleUnknownActionType($actionType),
+					};
 				}
 				catch (MAPIException $e) {
 					$this->processException($e, $actionType);
@@ -74,6 +62,7 @@ class StickyNoteListModule extends ListModule {
 	 *
 	 * @return object item properties if its non private item otherwise empty array
 	 */
+	#[Override]
 	public function processPrivateItem($item) {
 		return $item;
 	}
