@@ -1,4 +1,5 @@
 <?php
+
 /**
  * suggestEmailAddressModule.
  *
@@ -19,6 +20,7 @@ class suggestEmailAddressModule extends Module {
 		parent::__construct($id, $data);
 	}
 
+	#[Override]
 	public function execute() {
 		try {
 			// Retrieve the recipient history
@@ -64,9 +66,9 @@ class suggestEmailAddressModule extends Module {
 		if ($a['count'] > $b['count']) {
 			return -1;
 		}
-		$l_iReturnVal = strnatcasecmp($a['display_name'], $b['display_name']);
+		$l_iReturnVal = strnatcasecmp((string) $a['display_name'], (string) $b['display_name']);
 		if ($l_iReturnVal == 0) {
-			$l_iReturnVal = strnatcasecmp($a['smtp_address'], $b['smtp_address']);
+			$l_iReturnVal = strnatcasecmp((string) $a['smtp_address'], (string) $b['smtp_address']);
 		}
 
 		return $l_iReturnVal;
@@ -77,7 +79,7 @@ class suggestEmailAddressModule extends Module {
 	 * in mapi property. it searches for deleteRecipients key in the action array which will
 	 * contain email addresses of recipients that should be deleted in semicolon separated format.
 	 *
-	 * @param array $action action data in associative array format
+	 * @param array $action            action data in associative array format
 	 * @param array $recipient_history recipient history stored in mapi property
 	 */
 	public function deleteRecipient($action, $recipient_history) {
@@ -114,25 +116,26 @@ class suggestEmailAddressModule extends Module {
 	 * Function is used to get recipient history from mapi property based
 	 * on the query specified by the client in action array.
 	 *
-	 * @param array $action action data in associative array format
+	 * @param array $action            action data in associative array format
 	 * @param array $recipient_history recipient history stored in mapi property
+	 *
 	 * @returns {Array} data holding recipients that matched the query.
 	 */
 	public function getRecipientList($action, $recipient_history) {
 		if (!empty($action["query"]) && !empty($recipient_history) && !empty($recipient_history['recipients'])) {
 			// Setup result array with match levels
 			$l_aResult = [
-				0 => [],	// Matches on whole string
-				1 => [],	// Matches on part of string
+				0 => [],
+				1 => [],
 			];
 
 			// Loop through all the recipients
 
 			for ($i = 0, $len = count($recipient_history['recipients']); $i < $len; ++$i) {
 				// Prepare strings for case sensitive search
-				$l_sName = strtolower($recipient_history['recipients'][$i]['display_name']);
-				$l_sEmail = strtolower($recipient_history['recipients'][$i]['smtp_address']);
-				$l_sSearchString = strtolower($action["query"]);
+				$l_sName = strtolower((string) $recipient_history['recipients'][$i]['display_name']);
+				$l_sEmail = strtolower((string) $recipient_history['recipients'][$i]['smtp_address']);
+				$l_sSearchString = strtolower((string) $action["query"]);
 
 				// Check for the presence of the search string
 				$l_ibPosName = strpos($l_sName, $l_sSearchString);
@@ -141,7 +144,7 @@ class suggestEmailAddressModule extends Module {
 				// Check if the string is present in name or email fields
 				if ($l_ibPosName !== false || $l_ibPosEmail !== false) {
 					// Check if the found string matches from the start of the word
-					if ($l_ibPosName === 0 || substr($l_sName, ($l_ibPosName - 1), 1) == ' ' || $l_ibPosEmail === 0 || substr($l_sEmail, ($l_ibPosEmail - 1), 1) == ' ') {
+					if ($l_ibPosName === 0 || substr($l_sName, $l_ibPosName - 1, 1) == ' ' || $l_ibPosEmail === 0 || substr($l_sEmail, $l_ibPosEmail - 1, 1) == ' ') {
 						array_push($l_aResult[0], [
 							'display_name' => $recipient_history['recipients'][$i]['display_name'],
 							'smtp_address' => $recipient_history['recipients'][$i]['smtp_address'],
@@ -168,7 +171,7 @@ class suggestEmailAddressModule extends Module {
 			}
 
 			// Prevent the displaying of the exact match of the whole email address when only one item is found.
-			if (count($l_aResult[0]) == 1 && empty($l_aResult[1]) && $l_sSearchString == strtolower($l_aResult[0][0]['smtp_address'])) {
+			if (count($l_aResult[0]) == 1 && empty($l_aResult[1]) && $l_sSearchString == strtolower((string) $l_aResult[0][0]['smtp_address'])) {
 				$recipientList = [];
 			}
 			else {
@@ -188,13 +191,13 @@ class suggestEmailAddressModule extends Module {
 				 */
 				$l_iMaxNumListItems = 10;
 				$l_aSortedList = [];
-				usort($l_aResult[0], [$this, 'cmpSortResultList']);
+				usort($l_aResult[0], [self::class, 'cmpSortResultList']);
 				for ($i = 0, $len = min($l_iMaxNumListItems, count($l_aResult[0])); $i < $len; ++$i) {
 					$l_aSortedList[] = $l_aResult[0][$i];
 				}
 				if (count($l_aSortedList) < $l_iMaxNumListItems) {
 					$l_iMaxNumRemainingListItems = $l_iMaxNumListItems - count($l_aSortedList);
-					usort($l_aResult[1], [$this, 'cmpSortResultList']);
+					usort($l_aResult[1], [self::class, 'cmpSortResultList']);
 					for ($i = 0, $len = min($l_iMaxNumRemainingListItems, count($l_aResult[1])); $i < $len; ++$i) {
 						$l_aSortedList[] = $l_aResult[1][$i];
 					}
