@@ -2,7 +2,7 @@
 
 /**
  * Task ItemModule
- * Module which openes, creates, saves and deletes an item. It
+ * Module which opens, creates, saves and deletes an item. It
  * extends the Module class.
  */
 class TaskItemModule extends ItemModule {
@@ -20,6 +20,7 @@ class TaskItemModule extends ItemModule {
 		$this->plaintext = true;
 	}
 
+	#[Override]
 	public function open($store, $entryid, $action) {
 		$data = [];
 
@@ -92,6 +93,7 @@ class TaskItemModule extends ItemModule {
 	 * @param array  $action        the action data, sent by the client
 	 * @param mixed  $entryid
 	 */
+	#[Override]
 	public function save($store, $parententryid, $entryid, $action) {
 		if (isset($action["props"])) {
 			if (!$store && !$parententryid) {
@@ -110,7 +112,7 @@ class TaskItemModule extends ItemModule {
 				$messageProps = $this->saveTask($store, $parententryid, $entryid, $action);
 
 				if ($messageProps) {
-					$send = isset($action["message_action"]["send"]) ? $action["message_action"]["send"] : false;
+					$send = $action["message_action"]["send"] ?? false;
 					$message = $GLOBALS['operations']->openMessage($store, $messageProps[PR_ENTRYID]);
 					$data = $GLOBALS['operations']->getMessageProps($store, $message, $this->properties, $this->plaintext);
 
@@ -144,6 +146,7 @@ class TaskItemModule extends ItemModule {
 	 * @param mixed  $entryids
 	 * @param array  $action        the action data, sent by the client
 	 */
+	#[Override]
 	public function delete($store, $parententryid, $entryids, $action) {
 		if ($store && $parententryid) {
 			$props = [];
@@ -183,7 +186,7 @@ class TaskItemModule extends ItemModule {
 	public function deleteTask($store, $parententryid, $entryids, $action) {
 		$result = false;
 		$message = mapi_msgstore_openentry($store, $entryids);
-		$messageAction = isset($action["message_action"]["action_type"]) ? $action["message_action"]["action_type"] : false;
+		$messageAction = $action["message_action"]["action_type"] ?? false;
 		// If user wants to delete only occurrence then delete this occurrence
 		if (!is_array($entryids) && $messageAction) {
 			if ($message) {
@@ -214,12 +217,12 @@ class TaskItemModule extends ItemModule {
 				$taskReq = new TaskRequest($store, $message, $GLOBALS["mapisession"]->getSession());
 				$result = $taskReq->deleteReceivedTR();
 				if ($result) {
-					$GLOBALS["bus"]->notify(bin2hex($result[PR_PARENT_ENTRYID]), TABLE_DELETE, $result);
+					$GLOBALS["bus"]->notify(bin2hex((string) $result[PR_PARENT_ENTRYID]), TABLE_DELETE, $result);
 				}
 			}
 
 			// If softdelete is set then set it in softDelete variable and pass it for deleting message.
-			$softDelete = isset($action['message_action']['soft_delete']) ? $action['message_action']['soft_delete'] : false;
+			$softDelete = $action['message_action']['soft_delete'] ?? false;
 			$result = $GLOBALS["operations"]->deleteMessages($store, $parententryid, $entryids, $softDelete);
 		}
 		else {
@@ -246,7 +249,7 @@ class TaskItemModule extends ItemModule {
 	public function saveTask($store, $parententryid, $entryid, $action) {
 		$properties = $this->properties;
 		$messageProps = [];
-		$send = isset($action["message_action"]["send"]) ? $action["message_action"]["send"] : false;
+		$send = $action["message_action"]["send"] ?? false;
 
 		if ($store && $parententryid) {
 			if (isset($action["props"])) {
@@ -261,7 +264,7 @@ class TaskItemModule extends ItemModule {
 				}
 
 				if (isset($action["entryid"]) && !empty($action["entryid"])) {
-					$message = mapi_msgstore_openentry($store, hex2bin($action["entryid"]));
+					$message = mapi_msgstore_openentry($store, hex2bin((string) $action["entryid"]));
 					if ($message) {
 						$messageProps = mapi_getprops($message, [PR_ENTRYID, PR_PARENT_ENTRYID, PR_STORE_ENTRYID, $properties['recurring']]);
 
@@ -280,7 +283,7 @@ class TaskItemModule extends ItemModule {
 
 						$messageProps = Conversion::mapXML2MAPI($properties, $props);
 
-						$message = $GLOBALS["operations"]->saveMessage($store, $entryid, $parententryid, $messageProps, $messageProps, $recips, isset($action['attachments']) ? $action['attachments'] : [], []);
+						$message = $GLOBALS["operations"]->saveMessage($store, $entryid, $parententryid, $messageProps, $messageProps, $recips, $action['attachments'] ?? [], []);
 
 						if (isset($msgProps) && $msgProps) {
 							$messageProps = $msgProps;
@@ -297,7 +300,7 @@ class TaskItemModule extends ItemModule {
 					// we need to copy the original attachments when create task from message.
 					if (isset($action['message_action'], $action['message_action']['source_entryid'])) {
 						$copyFromMessage = hex2bin($action['message_action']['source_entryid']);
-						$copyFromStore = hex2bin($action['message_action']['source_store_entryid']);
+						$copyFromStore = hex2bin((string) $action['message_action']['source_store_entryid']);
 						$copyAttachments = true;
 
 						// get resources of store and message
@@ -305,7 +308,7 @@ class TaskItemModule extends ItemModule {
 						$copyFromMessage = $GLOBALS['operations']->openMessage($copyFromStore, $copyFromMessage);
 					}
 
-					$message = $GLOBALS["operations"]->saveMessage($store, $entryid, $parententryid, $messageProps, $messageProps, $recips, isset($action['attachments']) ? $action['attachments'] : [], [], $copyFromMessage, $copyAttachments, false, false, false);
+					$message = $GLOBALS["operations"]->saveMessage($store, $entryid, $parententryid, $messageProps, $messageProps, $recips, $action['attachments'] ?? [], [], $copyFromMessage, $copyAttachments, false, false, false);
 
 					// Set recurrence
 					if (isset($action['props']['recurring']) && $action['props']['recurring'] == 1) {
@@ -329,7 +332,7 @@ class TaskItemModule extends ItemModule {
 					if (isset($action["message_action"]["action_type"]) && $action["message_action"]["action_type"] === "restoreToTaskList") {
 						$deleteTRProps = $tr->deleteReceivedTR();
 						if ($deleteTRProps) {
-							$GLOBALS["bus"]->notify(bin2hex($deleteTRProps[PR_PARENT_ENTRYID]), TABLE_DELETE, $deleteTRProps);
+							$GLOBALS["bus"]->notify(bin2hex((string) $deleteTRProps[PR_PARENT_ENTRYID]), TABLE_DELETE, $deleteTRProps);
 						}
 
 						return $messageProps;
