@@ -34,6 +34,7 @@ class HierarchyNotifier extends Notifier {
 	 *                by this notifier. The bitmask can consist of the
 	 *                OBJECT_SAVE, OBJECT_DELETE, TABLE_SAVE, TABLE_DELETE, REQUEST_START and REQUEST_END flags
 	 */
+	#[Override]
 	public function getEvents() {
 		return OBJECT_SAVE | OBJECT_DELETE | TABLE_SAVE | TABLE_DELETE | REQUEST_START | REQUEST_END;
 	}
@@ -46,6 +47,7 @@ class HierarchyNotifier extends Notifier {
 	 * @param string $entryid entryid
 	 * @param mixed  $props
 	 */
+	#[Override]
 	public function update($event, $entryid, $props) {
 		switch ($event) {
 			case REQUEST_START:
@@ -129,7 +131,7 @@ class HierarchyNotifier extends Notifier {
 					$data["folderdelete"] = 1;
 					$data["entryid"] = bin2hex($props[PR_ENTRYID]);
 					$data["parent_entryid"] = bin2hex($props[PR_PARENT_ENTRYID]);
-					$data["store_entryid"] = bin2hex($props[PR_STORE_ENTRYID]);
+					$data["store_entryid"] = bin2hex((string) $props[PR_STORE_ENTRYID]);
 
 					$this->addNotificationActionData("folders", ["item" => $data]);
 					$GLOBALS["bus"]->addData($this->createNotificationResponseData());
@@ -163,12 +165,12 @@ class HierarchyNotifier extends Notifier {
 					if ($this->storeSize != $storeSize) {
 						$data = [];
 						$data["props"] = [];
-						$data["store_entryid"] = bin2hex($storeProps[PR_STORE_ENTRYID]);
+						$data["store_entryid"] = bin2hex((string) $storeProps[PR_STORE_ENTRYID]);
 						$data["props"]["object_type"] = $storeProps[PR_OBJECT_TYPE];
 						$data["props"]["store_size"] = $storeSize;
-						$data["props"]["quota_warning"] = isset($storeProps[PR_QUOTA_WARNING_THRESHOLD]) ? $storeProps[PR_QUOTA_WARNING_THRESHOLD] : 0;
-						$data["props"]["quota_soft"] = isset($storeProps[PR_PROHIBIT_SEND_QUOTA]) ? $storeProps[PR_PROHIBIT_SEND_QUOTA] : 0;
-						$data["props"]["quota_hard"] = isset($storeProps[PR_PROHIBIT_RECEIVE_QUOTA]) ? $storeProps[PR_PROHIBIT_RECEIVE_QUOTA] : 0;
+						$data["props"]["quota_warning"] = $storeProps[PR_QUOTA_WARNING_THRESHOLD] ?? 0;
+						$data["props"]["quota_soft"] = $storeProps[PR_PROHIBIT_SEND_QUOTA] ?? 0;
+						$data["props"]["quota_hard"] = $storeProps[PR_PROHIBIT_RECEIVE_QUOTA] ?? 0;
 
 						$this->addNotificationActionData("stores", ["item" => [$data]]);
 						$GLOBALS["bus"]->addData($this->createNotificationResponseData());
