@@ -9,6 +9,7 @@ class NewTodoTaskNotifier extends Notifier {
 	/**
 	 * @return Number the event which this module handles
 	 */
+	#[Override]
 	public function getEvents() {
 		return OBJECT_SAVE;
 	}
@@ -19,15 +20,15 @@ class NewTodoTaskNotifier extends Notifier {
 	 *
 	 * @param int    $event   event
 	 * @param string $entryid entryid
-	 * @param array  $data    array of data
 	 * @param mixed  $props
 	 */
+	#[Override]
 	public function update($event, $entryid, $props) {
 		switch ($event) {
 			case OBJECT_SAVE:
 				$data['item'][] = [
 					'entryid' => $entryid,
-					'store_entryid' => bin2hex($props[PR_STORE_ENTRYID]),
+					'store_entryid' => bin2hex((string) $props[PR_STORE_ENTRYID]),
 				];
 				$this->addNotificationActionData("newtodotask", $data);
 				$GLOBALS["bus"]->addData($this->createNotificationResponseData());
