@@ -34,7 +34,7 @@ function appendDefaultDomain($user) {
 	if (empty($user)) {
 		return '';
 	}
-	if (!defined('DEFAULT_DOMAIN') || empty(DEFAULT_DOMAIN) || strpos($user, '@') !== false) {
+	if (!defined('DEFAULT_DOMAIN') || empty(DEFAULT_DOMAIN) || str_contains((string) $user, '@')) {
 		return $user;
 	}
 
@@ -49,7 +49,7 @@ function appendDefaultDomain($user) {
  * @param mixed $className
  */
 function sessionNotifierLoader($className) {
-	$className = strtolower($className); // for PHP5 set className to lower case to find the file (see ticket #839 for more information)
+	$className = strtolower((string) $className); // for PHP5 set className to lower case to find the file (see ticket #839 for more information)
 
 	switch ($className) {
 		case "bus":
@@ -107,13 +107,13 @@ function getMaxUploadSize($as_string = false) {
 	 */
 
 	// calculate upload_max_value value to bytes
-	if (strpos($upload_max_value, "K") !== false) {
+	if (str_contains($upload_max_value, "K")) {
 		$upload_max_value = ((int) $upload_max_value) * 1024;
 	}
-	elseif (strpos($upload_max_value, "M") !== false) {
+	elseif (str_contains($upload_max_value, "M")) {
 		$upload_max_value = ((int) $upload_max_value) * 1024 * 1024;
 	}
-	elseif (strpos($upload_max_value, "G") !== false) {
+	elseif (str_contains($upload_max_value, "G")) {
 		$upload_max_value = ((int) $upload_max_value) * 1024 * 1024 * 1024;
 	}
 
@@ -153,13 +153,13 @@ function getMaxPostRequestSize() {
 	$post_max_value = strtoupper(ini_get('post_max_size'));
 
 	// calculate post_max_value value to bytes
-	if (strpos($post_max_value, "K") !== false) {
+	if (str_contains($post_max_value, "K")) {
 		$post_max_value = ((int) $post_max_value) * 1024;
 	}
-	elseif (strpos($post_max_value, "M") !== false) {
+	elseif (str_contains($post_max_value, "M")) {
 		$post_max_value = ((int) $post_max_value) * 1024 * 1024;
 	}
-	elseif (strpos($post_max_value, "G") !== false) {
+	elseif (str_contains($post_max_value, "G")) {
 		$post_max_value = ((int) $post_max_value) * 1024 * 1024 * 1024;
 	}
 
@@ -305,7 +305,7 @@ function browserDependingHTTPHeaderEncode($input) {
 		return $input;
 	}
 
-	return rawurlencode($input);
+	return rawurlencode((string) $input);
 }
 
 /**
@@ -314,7 +314,7 @@ function browserDependingHTTPHeaderEncode($input) {
  * @return bool true if Edge is the requester, position of the word otherwise
  */
 function isEdge() {
-	return strpos($_SERVER['HTTP_USER_AGENT'], 'Edge') !== false;
+	return str_contains((string) $_SERVER['HTTP_USER_AGENT'], 'Edge');
 }
 
 /**
@@ -354,13 +354,13 @@ function mb_basename($filepath, $suffix = '') {
 function storeURLDataToSession() {
 	$data = [];
 
-	$urlData = urldecode($_SERVER['QUERY_STRING']);
+	$urlData = urldecode((string) $_SERVER['QUERY_STRING']);
 	if (!empty($_GET['action']) && $_GET['action'] === 'mailto') {
 		$data['mailto'] = $_GET['to'];
 
 		// There may be some data after to field, like cc, subject, body
 		// So add them in the urlData string as well
-		$pos = stripos($urlData, $_GET['to']) + strlen($_GET['to']);
+		$pos = stripos($urlData, (string) $_GET['to']) + strlen((string) $_GET['to']);
 		$subString = substr($urlData, $pos);
 		$data['mailto'] .= $subString;
 	}
@@ -393,7 +393,7 @@ function isContinueRedirectAllowed($url) {
 	}
 
 	// Check if the domain is white listed
-	$allowedDomains = explode(' ', preg_replace('/\s+/', ' ', REDIRECT_ALLOWED_DOMAINS));
+	$allowedDomains = explode(' ', (string) preg_replace('/\s+/', ' ', REDIRECT_ALLOWED_DOMAINS));
 	if (count($allowedDomains) && !empty($allowedDomains[0])) {
 		foreach ($allowedDomains as $domain) {
 			$parsedDomain = parse_url($domain);
@@ -432,7 +432,7 @@ define("FILENAME_REGEX", "/^[^\\/\\:\\*\\?\"\\<\\>\\|]+$/im");
  * @param string $regex   regex to validate values based on type of value passed
  */
 function sanitizeValue($value, $default = '', $regex = false) {
-	$result = addslashes($value);
+	$result = addslashes((string) $value);
 	if ($regex) {
 		$match = preg_match_all($regex, $result);
 		if (!$match) {
@@ -475,13 +475,12 @@ function sanitizePostValue($key, $default = '', $regex = false) {
 	return $default;
 }
 
-function parse_smime__join_xph(&$prop, $msg)
-{
+function parse_smime__join_xph(&$prop, $msg) {
 	$a = mapi_getprops($msg, [PR_TRANSPORT_MESSAGE_HEADERS]);
 	$a = $a === false ? "" : ($a[PR_TRANSPORT_MESSAGE_HEADERS] ?? "");
 	$prop[PR_TRANSPORT_MESSAGE_HEADERS] =
-		"# Outer headers:\n".($prop[PR_TRANSPORT_MESSAGE_HEADERS] ?? "").
-		"# Inner headers:\n".$a;
+		"# Outer headers:\n" . ($prop[PR_TRANSPORT_MESSAGE_HEADERS] ?? "") .
+		"# Inner headers:\n" . $a;
 }
 
 /**
@@ -492,12 +491,12 @@ function parse_smime__join_xph(&$prop, $msg)
  */
 function parse_smime($store, $message) {
 	$props = mapi_getprops($message, [PR_MESSAGE_CLASS, PR_MESSAGE_FLAGS,
-	PR_SENT_REPRESENTING_NAME, PR_SENT_REPRESENTING_ENTRYID, PR_SENT_REPRESENTING_SEARCH_KEY,
-	PR_SENT_REPRESENTING_EMAIL_ADDRESS, PR_SENT_REPRESENTING_SMTP_ADDRESS,
-	PR_SENT_REPRESENTING_ADDRTYPE, PR_CLIENT_SUBMIT_TIME, PR_TRANSPORT_MESSAGE_HEADERS]);
+		PR_SENT_REPRESENTING_NAME, PR_SENT_REPRESENTING_ENTRYID, PR_SENT_REPRESENTING_SEARCH_KEY,
+		PR_SENT_REPRESENTING_EMAIL_ADDRESS, PR_SENT_REPRESENTING_SMTP_ADDRESS,
+		PR_SENT_REPRESENTING_ADDRTYPE, PR_CLIENT_SUBMIT_TIME, PR_TRANSPORT_MESSAGE_HEADERS]);
 	$read = $props[PR_MESSAGE_FLAGS] & MSGFLAG_READ;
 
-	if (isset($props[PR_MESSAGE_CLASS]) && stripos($props[PR_MESSAGE_CLASS], 'IPM.Note.SMIME.MultipartSigned') !== false) {
+	if (isset($props[PR_MESSAGE_CLASS]) && stripos((string) $props[PR_MESSAGE_CLASS], 'IPM.Note.SMIME.MultipartSigned') !== false) {
 		// this is a signed message. decode it.
 		$atable = mapi_message_getattachmenttable($message);
 
@@ -546,11 +545,11 @@ function parse_smime($store, $message) {
 				PR_SENT_REPRESENTING_SMTP_ADDRESS => $props[PR_SENT_REPRESENTING_SMTP_ADDRESS] ?? '',
 				PR_SENT_REPRESENTING_ADDRTYPE => $props[PR_SENT_REPRESENTING_ADDRTYPE] ?? 'SMTP',
 				PR_CLIENT_SUBMIT_TIME => $props[PR_CLIENT_SUBMIT_TIME] ?? time(),
-				PR_TRANSPORT_MESSAGE_HEADERS => ($props[PR_TRANSPORT_MESSAGE_HEADERS] ?? "").$inner_headers,
+				PR_TRANSPORT_MESSAGE_HEADERS => ($props[PR_TRANSPORT_MESSAGE_HEADERS] ?? "") . $inner_headers,
 			]);
 		}
 	}
-	elseif (isset($props[PR_MESSAGE_CLASS]) && stripos($props[PR_MESSAGE_CLASS], 'IPM.Note.SMIME') !== false) {
+	elseif (isset($props[PR_MESSAGE_CLASS]) && stripos((string) $props[PR_MESSAGE_CLASS], 'IPM.Note.SMIME') !== false) {
 		// this is a encrypted message. decode it.
 		$attachTable = mapi_message_getattachmenttable($message);
 
@@ -585,7 +584,7 @@ function parse_smime($store, $message) {
 			// deleting an attachment removes an actual attachment of the message
 			$mprops = mapi_getprops($message, [PR_MESSAGE_CLASS]);
 			if (isSmimePluginEnabled() && isset($mprops[PR_MESSAGE_CLASS]) &&
-				stripos($mprops[PR_MESSAGE_CLASS], 'IPM.Note.SMIME') !== false) {
+				stripos((string) $mprops[PR_MESSAGE_CLASS], 'IPM.Note.SMIME') !== false) {
 				mapi_message_deleteattach($message, $attnum);
 			}
 
@@ -637,9 +636,9 @@ function streamProperty($mapiobj, $proptag) {
  * Function will decode JSON string into objects.
  *
  * @param string $jsonString JSON data that should be decoded
- * @param bool $toAssoc flag to indicate that associative arrays should be
- * returned as objects or arrays, true means it will return associative array as arrays and
- * false will return associative arrays as objects
+ * @param bool   $toAssoc    flag to indicate that associative arrays should be
+ *                           returned as objects or arrays, true means it will return associative array as arrays and
+ *                           false will return associative arrays as objects
  *
  * @return object decoded data
  */
@@ -683,7 +682,7 @@ function json_decode_data($jsonString, $toAssoc = false) {
  * @param resource $store the store to retrieve IPM subtree from
  *
  * @return mixed false if the subtree is broken beyond quick repair,
- * the IPM subtree resource otherwise
+ *               the IPM subtree resource otherwise
  */
 function getSubTree($store) {
 	$storeProps = mapi_getprops($store, [PR_IPM_SUBTREE_ENTRYID]);
@@ -707,8 +706,8 @@ function getSubTree($store) {
  * the user has permission on the inbox folder, but no folder visible
  * rights on the rest of the store.
  *
- * @param string $username the user who's store to retrieve hierarchy counters from.
- * If no username is given, the currently logged in user's store will be used.
+ * @param string $username   the user who's store to retrieve hierarchy counters from.
+ *                           If no username is given, the currently logged in user's store will be used.
  * @param string $folderType if inbox use the inbox as root folder
  *
  * @return array folderStatCache a cache of the hierarchy folders
@@ -751,11 +750,11 @@ function updateHierarchyCounters($username = '', $folderType = '') {
 	$folderStatCache = [];
 	foreach ($rows as $folder) {
 		$folderStatCache[$folder[PR_DISPLAY_NAME]] = [
-			'commit_time' => isset($folder[PR_LOCAL_COMMIT_TIME_MAX]) ? $folder[PR_LOCAL_COMMIT_TIME_MAX] : "0000000000",
-			'entryid' => bin2hex($folder[PR_ENTRYID]),
-			'store_entryid' => bin2hex($folder[PR_STORE_ENTRYID]),
-			'content_count' => isset($folder[PR_CONTENT_COUNT]) ? $folder[PR_CONTENT_COUNT] : -1,
-			'content_unread' => isset($folder[PR_CONTENT_UNREAD]) ? $folder[PR_CONTENT_UNREAD] : -1,
+			'commit_time' => $folder[PR_LOCAL_COMMIT_TIME_MAX] ?? "0000000000",
+			'entryid' => bin2hex((string) $folder[PR_ENTRYID]),
+			'store_entryid' => bin2hex((string) $folder[PR_STORE_ENTRYID]),
+			'content_count' => $folder[PR_CONTENT_COUNT] ?? -1,
+			'content_unread' => $folder[PR_CONTENT_UNREAD] ?? -1,
 		];
 	}
 
